#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title:	EnginePostUninstallConfigure_3.0.0.2.sh
##   Description: Handles the post Uninstall configure actions for the 
##                TS_Engine_3.0.0.2 IU
##
#############################################################################

ECHO="echo"
PLATFORM=`uname`

AWK_EQUAL="awk -F "=""
if [ "$PLATFORM" = "SunOS" ];then
    AWK_EQUAL="awk -F="
fi

usage()
{
	echo "	USAGE: ./EnginePostUninstallConfigure_3.0.0.2.sh"
	echo "                          [-ts_home=<TS install location>]"
	echo "                          [-was_admin_user=<WAS admin password>]"
	echo "                          [-was_admin_password=<WAS admin password>]"
	echo "                          [-ws_user=<web services password>]"
	echo "                          [-ws_password=<web services password>]"
	echo "                          [-action=[rollback/uninstall]]"
}

#### Main starts here ####
#### Input Arguments Verification #####		
for item in $*
	do
		if [ `expr match "$item" '-ts_home='` != 0 ];then
			ts_home=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_user='` != 0 ];then
			was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_password='` != 0 ];then
			was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ws_user='` != 0 ];then
			ws_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ws_password='` != 0 ];then
			ws_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-action='` != 0 ];then
			action=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		else
			usage
			exit 1
		fi
	done
	
### Remove compiled jython classes to force recompilation of any changed jython
rm -f $ts_home/bin/jython/*.class

### Remove any files left over from LA fixes.
rm -f $ts_home/*-LA*
rm -f $ts_home/VersionInfo/*-LA*

### Call updateTS.sh to update the ear's based on the action and/or configuration status of TS

createProfRetCode=0
updateTSRetCode=0
retCode=0

echo "Post Uninstall Configure"
echo "action: $action"
echo "ts_home: $ts_home"
echo "was_admin_user: $was_admin_user"
###echo "was_admin_password: $was_admin_password"
echo "ws_user: $ws_user"
###echo "ws_password: $ws_password"   

if [ $action = "rollback" ];then

	# include the RFIDIC environment settings
	# utils.sh is not there after during an uninstall so only do this for a rollback
	scriptDir=`dirname $0`
	if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
  		. ${RFIDIC_HOME}/bin/utils.sh
	else
  		. ${scriptDir}/utils.sh
	fi

	### Setup the log file
	logFileName=TSPostRollbackLog_`date "+%Y%m%d%H%M%S"`
	assignLogFile ${scriptDir}/../logs/$logFileName

	## Defect 97184 - preserve bin/configureTS.properties
	## On a rollback, if configureTS.properties_bak exists, restore to configureTS.properties
	if [ -f "$ts_home/bin/configureTS.properties_bak" ];then
		mv -f $ts_home/bin/configureTS.properties_bak $ts_home/bin/configureTS.properties
	fi
	

	## If RFIDICServer.xml has been backed up, then restore the backed up version
	if [ -f "$ts_home/etc/RFIDICServer.xml_3000" ];then
		mv -f "$ts_home/etc/RFIDICServer.xml_3000" "$ts_home/etc/RFIDICServer.xml"
	fi
	
	## The fixpack files get copied during the FP's pre_uninstall phase
	##  If the upgrade/rollback fails before this phase, these files won't be copied 
	##  so check for the files before calling
	
	if [ -f "$ts_home/bin/createUserProfileFP.sh" ];then
	
		##--------------------
		# Need to modify the copied fix pack files so they call the correct
		#   version of utils.sh and jython scripts
		##--------------------
		
		# change references to utils.sh to utilsFP.sh
		for fname in $ts_home/bin/*FP.sh
 		  do

		    #$ECHO "fname: $fname"
		    sed 's#utils.sh#utilsFP.sh#' $fname > $ts_home/bin/1.$$
		    if [ $? -eq 0 ];then
		        mv -f $ts_home/bin/1.$$ $fname
    		fi

 		  done
		
 		$ECHO "Updating setWebServicesBindingInfoMainFP.sh to call *FP.py"
 		fname=$ts_home/bin/setWebServicesBindingInfoMainFP.sh
 		##$ECHO "fname: $fname"
	 	sed 's#getWebServicesPort.py#getWebServicesPortFP.py#' $fname > $ts_home/bin/1.$$
	 	if [ $? -eq 0 ];then
		    mv -f $ts_home/bin/1.$$ $fname
 		fi

 		$ECHO "Updating updateTSFP.sh to call setWebServicesBindingInfoMainFP.sh"
 		fname=$ts_home/bin/updateTSFP.sh
 		##$ECHO "fname: $fname"
 		sed 's#setWebServicesBindingInfoMain.sh#setWebServicesBindingInfoMainFP.sh#' $fname > $ts_home/bin/1.$$
 		if [ $? -eq 0 ];then
    		mv -f $ts_home/bin/1.$$ $fname
 		fi
 		
 		chmod 755 $ts_home/bin/*FP.sh
			
		### Call createUserProfile to set permissions
		echo "Setting permissions using FP script"
		log "Setting permissions using FP script"
		$ts_home/bin/createUserProfileFP.sh -SET_PERMISSIONS_ONLY >> $utilsLogFile 2>&1
		createProfRetCode=$?
		
		if [ "$createProfRetCode" -eq "0" ];then
			echo "-------- Permissions have been successfully set --------"
			log "-------- Permissions have been successfully set --------"
		fi
		
		#inform user to turn off security during rollback as we cannot take credentials during rollback
		echo "Updating TS using FP script"
		log "Updating TS using FP script"
		$ts_home/bin/updateTSFP.sh -was_admin_user=$was_admin_user -was_admin_password=$was_admin_password -ws_user=$ws_user -ws_password=$ws_password -log=$utilsLogFile
		updateTSRetCode=$?
		
		if [ $createProfRetCode -ne 0 ];then	
    		retCode=$createProfRetCode
		elif [ $updateTSRetCode -ne 0 ];then
    		retCode=$updateTSRetCode
		fi	
		
		if [ "$retCode" -eq "0" ];then
			echo "-------- Script completed successfully --------"
			log "-------- Script completed successfully --------"
		else
			echo "-------- Script did not complete successfully --------"
			log "-------- Script did not complete successfully --------"
		fi	
	else
		echo "fix pack files do not exist"
		log "fix pack files do not exist"
	fi
			
elif [ $action = "uninstall" ];then
	rm -rf $ts_home/MEDATA
	
	## On an uninstall remove configureTS.properties.bak
	if [ -f "$ts_home/bin/configureTS.properties.bak" ];then
		rm -f $ts_home/bin/configureTS.properties.bak
	fi
fi

## Remove the saved FP's files since they are not needed and if This script
##  fails will just gum up things if left behind
rm -f "$ts_home/bin/updateTSFP.sh"
rm -f "$ts_home/bin/createUserProfileFP.sh"
rm -f "$ts_home/bin/setWebServicesBindingInfoMainFP.sh"
rm -f "$ts_home/bin/utilsFP.sh"
rm -f "$ts_home/bin/jython/updateTSFP.py"
rm -f "$ts_home/bin/jython/getWebServicesPortFP.py"
		
exit $retCode