#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
# config.sh - configure IBM InfoSphere Traceability Server
###############################################################################################################

sDir=`dirname ${0}`
scriptDir=`cd $sDir && pwd`
. ${scriptDir}/utils.sh
. ${scriptDir}/prereqChecks.sh

logFileName=TSConfigLog_`date "+%Y%m%d%H%M%S"`
assignLogFile ${scriptDir}/../logs/$logFileName

parseArgs()
{
	#### Input Arguments Verification #####

	clean=$FALSE
	components="DB,MQ,WAS,TSAR"
    

	for item in $*
	do
		if [ `expr match "$item" '-components='` != 0 ];then
			componentsOnCommandLine=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-log='` != 0 ];then
			customLogFile=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-input_file='` != 0 ];then
			inputFile=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-dba_user'` != 0 ]; then
			DBMS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-dba_password'` != 0 ]; then
			DBMS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ts_admin_user'` != 0 ]; then
			TS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ts_admin_password'` != 0 ]; then
			TS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-mq_user_name'` != 0 ]; then
			MQ_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-mq_user_password'` != 0 ]; then
			MQ_USER_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_user'` != 0 ]; then
			was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_password'` != 0 ]; then
			was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-clean'` != 0 ]; then
			clean=$TRUE
		else
			usage
			return $FALSE
		fi
	done
	
    if [ "$clean" = "$TRUE" ];then
        . ${scriptDir}/tsEnv.sh
    fi

	if [ -f "$inputFile" ];then
		. $inputFile
	else
        if [ "$clean" = "$FALSE" ];then
            if [ -f "${scriptDir}/configureTS.properties" ];then
                . ${scriptDir}/configureTS.properties
            else
                isVerbose=$TRUE
                getMessage TSIN01118E
                log $msg
                #log "Install >> Error"
                
                log "--------------------------------------------------"
                
                getMessage TSIN02217E $scriptDir
                log "\n$msg"
                #log "\nCould not find configureTS.properties in $scriptDir. Ensure that the file is in the same directory as the config.sh script and retry the configuration."
                
                getMessage TSIN02218E $scriptDir
                log "\n$msg"
                #log "\nVerify configureTS.properties is in the directory $scriptDir and retry."
                return 1
            fi
        fi
    fi

    if [ -n "$componentsOnCommandLine" ];then
        components=$componentsOnCommandLine
    elif [ -n "$CONFIGURE_COMPONENTS" ];then
        components=$CONFIGURE_COMPONENTS
    fi

    components=`echo "$components" | tr "," "\n" | tr "[a-z]" "[A-Z]"`
    
    ## Put the components in order for easy looping later
    for item in $components
	do
		case "$item" in
			DB)
                dbSelected=$TRUE
				;;
			MQ)
                mqSelected=$TRUE
				;;
			WAS)
                wasSelected=$TRUE
				;;
			TSAR)
                tsarSelected=$TRUE
                ;;
            *)
            	getMessage TSIN01133E $item
            	log $msg 
				#log "No such product: $item"
				;;
		esac
	done

    components=""
    
    if [ "$dbSelected" = "$TRUE" ];then
        components="${components},DB"
    fi
    if [ "$mqSelected" = "$TRUE" ];then
        components="${components},MQ"
    fi
    if [ "$wasSelected" = "$TRUE" ];then
        components="${components},WAS"
    fi
    if [ "$tsarSelected" = "$TRUE" ];then
        components="${components},TSAR"
    fi

    components=`echo "$components" | tr "," "\n"`

	if [ -z "$TS_HOME" -o ! -d "$TS_HOME" ]; then
		if [ -n "$RFIDIC_HOME" -a -d "$RFIDIC_HOME" ];then
			TS_HOME=$RFIDIC_HOME
		else
            if [ -f $scriptDir"/../etc/RFIDICServer.xml" ];then
                TS_HOME="`( cd \"${scriptDir}"/.."\" && pwd )`"
            fi
            if [ -z "$TS_HOME" -o ! -d "$TS_HOME" ]; then
                isVerbose=$TRUE
                getMessage TSIN02273E "TS_HOME"
                log $msg
                #log "The TS_HOME environment variable was not set."
                isVerbose=$FALSE
                return $FALSE
            fi
		fi
	fi
    
    RFIDIC_HOME=$TS_HOME

	if [ -n "$customLogFile" ];then
		assignLogFile $customLogFile
	fi
    
    setDefaults
    exportVariables

	return $TRUE
}

setDefaults()
{
    if [ -z "$WAS_HOME" -o ! -d "$WAS_HOME" ];then
        getWASHome
        WAS_HOME=$returnString
    fi

    if [ -z "$RFIDIC_BUS_NAME" ];then
        RFIDIC_BUS_NAME=RFIDICBus
    fi
    
    if [ -z "$TS_ADMIN_USER" ];then
        TS_ADMIN_USER=$CURRENT_USER
    fi

    if [ -z "$TS_ADMIN_GROUP" ];then
        TS_ADMIN_GROUP=$CURRENT_GROUP
    fi

    if [ -z "$was_runas_user" ];then
        was_runas_user=$TS_ADMIN_USER
    fi

    if [ -z "$was_runas_group" ]; then
        was_runas_group=$TS_ADMIN_GROUP
    fi

    if [ -z "$was_runas_password" ]; then
        was_runas_password=$TS_ADMIN_PASSWORD
    fi

    if [ -z "$TS_BUS_NAME" ];then
	TS_BUS_NAME=RFIDICBus
    fi
	
    if [ -z "$TS_ADMIN_USER_HOME" ];then
	if [ "$PLATFORM" = "SunOS" ];then
		TS_ADMIN_USER_HOME="/export/home/${TS_ADMIN_USER}"
	else
		TS_ADMIN_USER_HOME="/home/${TS_ADMIN_USER}"
	fi
    fi
	
    if [ -z "$WAS_PROFILE" ];then
        WAS_PROFILE=AppSrv01
    fi
    
    if [ -z "$CELLNAME" ];then
        CELLNAME=$HOSTNAME"Node01Cell"
    fi
    
    if [ -z "$NODENAME" ];then
        NODENAME=$HOSTNAME"Node01"
    fi
    
    if [ -z "$SERVERNAME" ];then
        SERVERNAME=server1
    fi
    
    if [ -z "$MQ_HOME" ];then
        MQ_HOME=/opt/mqm
    fi
    
    if [ -z "$MQ_HOST" ];then
        MQ_HOST=$HOSTNAMEFULL
    fi
    
    if [ -z "$QUEUE_MANAGER" ];then
        QUEUE_MANAGER=TS.QUEUE.MANAGER
    fi
    
    if [ -z "$MQ_LOG_FILE_PAGES" ];then
        MQ_LOG_FILE_PAGES=65535
    fi
    
    if [ -z "$MQ_LOG_TYPE" ];then
        MQ_LOG_TYPE=CIRCULAR
    fi
    
    if [ -z "$MQ_LOG_PRIMARY_FILES" ];then
        MQ_LOG_PRIMARY_FILES=3
    fi
    
    if [ -z "$MQ_LOG_SECONDARY_FILES" ];then
        MQ_LOG_SECONDARY_FILES=2
    fi
    
    if [ -z "$MQ_TS_CHANNEL" ];then
        MQ_TS_CHANNEL=TS.CHANNEL
    fi
    
    if [ -z "$QUEUE_NAME" ];then
        QUEUE_NAME=EPCEVENT
    fi
    
    if [ -z "$ALERTS_ENGINE_INPUT_QUEUE_NAME" ];then
        ALERTS_ENGINE_INPUT_QUEUE_NAME=ALERTSENGINEINPUTQUEUE
    fi
    
    if [ -z "$MDM_CHANGE_NOTIF_QUEUE_NAME" ];then
        MDM_CHANGE_NOTIF_QUEUE_NAME=MDMCHANGENOTIFICATION
    fi
    
    if [ -z "$AS2DELIVERY_QUEUE_NAME" ];then
        AS2DELIVERY_QUEUE_NAME=AS2DELIVERY
    fi
    
    if [ -z "$AS2REQUEST_QUEUE_NAME" ];then
        AS2REQUEST_QUEUE_NAME=AS2REQUEST
    fi
    
    if [ -z "$AS2RESPONSE_QUEUE_NAME" ];then
        AS2RESPONSE_QUEUE_NAME=AS2RESPONSE
    fi
    
    if [ -z "$CAPTURE_NOTIF_QUEUE_NAME" ];then
        CAPTURE_NOTIF_QUEUE_NAME=RFIDICCAPTURENOTIF
    fi
    
    if [ -z "$MQ_LSR_PORT" ];then
        MQ_LSR_PORT=1414
    fi
    
    if [ -z "$DBMS_HOST" ];then
        DBMS_HOST=$HOSTNAMEFULL
    fi
    
    if [ -z "$DBMS_PORT_NUMBER" ];then
        if [ "$DB_TYPE" = "DB2" ];then
            DBMS_PORT_NUMBER=50000
        elif [ "$DB_TYPE" = "ORACLE" ];then
            DBMS_PORT_NUMBER=1521
        fi
    fi
    
    if [ -z "$DB_TYPE" ];then
        DB_TYPE=DB2
    fi

    if [ -z "$DBMS_DB_NAME" ];then
        DBMS_DB_NAME=tsdb
    fi
    
    if [ -z "$DBMS_TABLE_SPACE" ];then
        DBMS_TABLE_SPACE=
    fi
    
    if [ -z "$DBMS_JDBC_LIB_PATH" ];then
        if [ -n "$DBMS_HOME" ];then
            if [ "$DB_TYPE" = "DB2" ];then
                DBMS_JDBC_LIB_PATH=$DBMS_HOME"/java"
            elif [ "$DB_TYPE" = "ORACLE" ];then
                DBMS_JDBC_LIB_PATH=$DBMS_HOME"/jdbc/lib"
            fi
        fi
    fi
    
    if [ -z "$TSAR" ];then
        TSAR=$TS_HOME/samples/tsar/standard_sample.tsar
    fi

    if [ -z "$HELP_TYPE" ];then
	HELP_TYPE="internet"
    fi

}

exportVariables()
{
    export TS_HOME
    export TS_ADMIN_USER
    export TS_ADMIN_PASSWORD
    export TS_ADMIN_GROUP
    export RFIDIC_HOME
    export RFIDIC_BUS_NAME
    export CONFIGURE_COMPONENTS
    export WAS_HOME
    export WAS_PROFILE
    export WAS_PORT_NO
    export CELLNAME
    export NODENAME
    export SERVERNAME
    export CLUSTERNAME
    export was_admin_user
    export was_admin_password
    export was_runas_user
    export was_runas_password
    export was_runas_group
    export WS_UI_USER
    export WS_UI_PWD
    export WS_UI_SSL
    export MQ_HOME
    export MQ_HOST
    export QUEUE_MANAGER
    export MQ_LOG_FILE_PAGES
    export MQ_LOG_TYPE
    export MQ_LOG_PRIMARY_FILES
    export MQ_LOG_SECONDARY_FILES
    export MQ_TS_CHANNEL
    export QUEUE_NAME
    export ALERTS_ENGINE_INPUT_QUEUE_NAME
    export MDM_CHANGE_NOTIF_QUEUE_NAME
    export AS2DELIVERY_QUEUE_NAME
    export AS2REQUEST_QUEUE_NAME
    export AS2RESPONSE_QUEUE_NAME
    export CAPTURE_NOTIF_QUEUE_NAME
    export MQ_LSR_PORT
    export MQ_USER
    export MQ_USER_PASSWORD
    export R_QUEUE_MANAGER
    export R_MQ_HOST
    export R_MQ_LSR_PORT
    export MQ_CLUSTER
    export QUEUE_MANAGER_TYPE
    export DB_TYPE
    export DBMS_HOME
    export DBMS_ADMIN_USER
    export DBMS_ADMIN_PASSWORD
    export DBMS_HOST
    export DBMS_PORT_NUMBER
    export DB2_INSTANCE
    export DB2_INSTANCE_OWNER
    export DBMS_DB_NAME
    export DBMS_TABLE_SPACE
    export DBMS_JDBC_LIB_PATH
    export ORACLE_OWNER
    export ORACLE_GROUP
    export ORACLE_JDBC_URL
    export TSAR
}

usage()
{
	echo "	USAGE: ./config.sh"
	echo "                          [-clean]"
	echo "                          [-components=[MQ,DB,WAS,TSAR]]"
	echo "                          [-input_file=<Path to configureTS.properties file>]"
	echo "                          [-dba_user=<value>]"
	echo "                          [-dba_password=<value>]"
	echo "                          [-ts_admin_user=<value>]"
	echo "                          [-ts_admin_password=<value>]"
	echo "                          [-mq_user_name=<value>]"
	echo "                          [-mq_user_password=<value>]"
	echo "                          [-was_admin_user=<value>]"
	echo "                          [-was_admin_password=<value>]"
	echo "                          [-log=<Path to custom log file>]"
	return 1
}

isSystemValid()
{
	prereqCheckStatus=$TRUE
	
	# Need to call these functions when configuring, not cleaning up
	if [ "$clean" = "$FALSE" ];then

		isOSValid
		if [ "$?" = "$FALSE" ];then
			prereqCheckStatus=$FALSE
		fi
	
		isHostnameValid
		if [ "$?" = "$FALSE" ];then
			prereqCheckStatus=$FALSE
		fi
	
		isDiskSpaceValid
		if [ "$?" = "$FALSE" ];then
			prereqCheckStatus=$FALSE
		fi
	fi
	
	isUserPermissionValid
	if [ "$?" = "$FALSE" ];then
		prereqCheckStatus=$FALSE
	fi
	
    for item in $components
	do
		case "$item" in
			DB)
                isDBValid
                if [ "$?" = "$FALSE" ];then
                    prereqCheckStatus=$FALSE
                fi
				;;
			MQ)
                isMQValid
                if [ "$?" = "$FALSE" ];then
                    prereqCheckStatus=$FALSE
                fi
				;;
			WAS)
                isWASValid
                if [ "$?" = "$FALSE" ];then
                    prereqCheckStatus=$FALSE
                fi
				;;
			TSAR)
		if [ "$clean" = "$FALSE" ];then

	                isTSARValid
			if [ "$?" = "$FALSE" ];then
				prereqCheckStatus=$FALSE
			fi
		fi
				;;
			*)
				getMessage TSIN01133E $item
				log $msg
				#log "No such product: $item"
				;;
		esac
	done
	
	return $prereqCheckStatus
}

isSystemReady()
{
	isSystemReadyStatus=$TRUE
    
    for item in $components
	do
		case "$item" in
			DB)
                # Checking if DB is running
                getMessage TSIN02219I
                $ECHO $msg
                log $msg
                #log "Checking database status"
                isDBRunning
                DBRetVal=$?
                if [ "$DBRetVal" = "$TRUE" ];then
                    getMessage TSIN01077I
                    $ECHO $msg
                    log $msg
                    #log "\nDB - RUNNING"
                    getMessage TSIN02196I
                    log $msg
                    #log "Validation of the database complete"
                else
                    isSystemReadyStatus=$FALSE
                    getMessage TSIN01078E
                    $ECHO $msg
                    log $msg
                    #log "\nDB - NOT RUNNING"
                fi
                isVerbose=$FALSE
				;;
			MQ)
                # Checking if MQ is installed
                getMessage TSIN02220I
                $ECHO $msg
                log $msg
                #log "Checking MQ status"
                isHostnameRemote $MQ_HOST
                mqRemote=$?
                if [ "$mqRemote" = "$FALSE" ];then
                    isMQInstalled
                    if [ "$?" = "$TRUE" ];then
                        getMessage TSIN01058I
                        $ECHO $msg
                        log $msg
                        #log "\nMQ - INSTALLED"
                    else
                        isSystemReadyStatus=$FALSE
                        getMessage TSIN01059E
                        $ECHO $msg
                        log $msg
                        #log "\nMQ - NOT INSTALLED"
                    fi
                fi
                isVerbose=$FALSE
				;;
			WAS)
                # Checking if WAS is running
                getMessage TSIN02221I
				$ECHO $msg
                log $msg
                #log "Checking WAS status"
                isWASRunning
                wasRetVal=$?
                if [ "$wasRetVal" = "$TRUE" ];then
                    getMessage TSIN01075I
                    $ECHO $msg
                    log $msg
                    #log "\nWAS - RUNNING"
                else
                    isSystemReadyStatus=$FALSE
                    getMessage TSIN01076E
                    $ECHO $msg
                    log $msg
                    #log "\nWAS - NOT RUNNING"
                fi
                isVerbose=$FALSE
				;;
			TSAR)
				;;
			*)
				getMessage TSIN01133E $item
				$ECHO $msg
				log $msg
				#log "No such product: $item"
				;;
		esac
	done
	
	if [ "$isSystemReadyStatus" = "$FALSE" ];then
		getMessage TSIN01079E
        isVerbose=$TRUE
        log $msg
		#log "\nOne or more pre-requisite software services might not be started. Start the service(s) and retry install."
        isVerbose=$FALSE
	fi
	
	return $isSystemReadyStatus
}

createUserID()
{
	${TS_HOME}/bin/createUserProfile.sh >> $utilsLogFile	2>&1
	if [ "$?" != "0" ];then
		return $FALSE
	fi
	return $TRUE
}

configureDB()
{
	if [ "$clean" != "$TRUE" ];then
		# Configure the DB chosen. If oracle, add the oracle admin to "tsgroup" group and deploy the metadata
		${TS_HOME}/bin/configureDB.sh >> $utilsLogFile	2>&1
		if [ "$?" != "0" ];then
			return $FALSE
		fi
		if [ "$DB_TYPE" = "ORACLE" ];then
			if [ -n "$ORACLE_GROUP" ];then
                addGroupToUser $ORACLE_GROUP $TS_ADMIN_USER
			fi
		fi
	fi
	return $TRUE
}

configureMQ()
{
    # The R_QUEUE_MANAGER is a required variable when setting up a clustered MQ instance. 
    # We can use that to determine if a cluster is being configured.
    mqCluster=$FALSE
    if [ -n "$R_QUEUE_MANAGER" ];then
        mqCluster=$TRUE
    fi

	isHostnameRemote $MQ_HOST
	if [ "$?" = "$FALSE" ];then
		if [ -s "$MQ_HOME" ];then
			getMessage TSIN01114I
			log $msg
			#log "Configuring WebSphere MQ..."

            #Clean MQ first before configuring.
            if [ "$mqCluster" = "$TRUE" ];then
                ${TS_HOME}/bin/configureMQHA.sh -clean >> $utilsLogFile 2>&1
            else
                ${TS_HOME}/bin/configureMQ.sh -clean >> $utilsLogFile 2>&1
            fi

			if [ "$clean" != "$TRUE" ];then
                            if [ "$mqCluster" = "$TRUE" ];then
				${TS_HOME}/bin/configureMQHA.sh >> $utilsLogFile 2>&1
                            else
				${TS_HOME}/bin/configureMQ.sh >> $utilsLogFile 2>&1
                            fi
			fi

			if [ "$?" != "0" ];then
				return $FALSE
			fi
			
			getMessage TSIN01115I
			log $msg
			#log "WebSphere MQ configured."
            return $TRUE
        else
            getMessage TSIN01088E $MQ_HOME
            log $msg
            return $FALSE
		fi
	fi
}

configureWAS()
{
	if [ -s "$WAS_HOME" ];then
		getMessage TSIN01116I
		log $msg
		#log "Configuring WebSphere Application Server..."
		if [ "$clean" != "$TRUE" ];then
			${TS_HOME}/bin/configureWAS.sh >> $utilsLogFile 2>&1
		else
			${TS_HOME}/bin/configureWAS.sh -clean >> $utilsLogFile 2>&1
		fi
		if [ "$?" != "0" ];then
			return $FALSE
		fi
	fi
	
	if [ -z "$was_admin_group" ];then
		# If was_admin_group is not specified then add the was_admin_user to 
        # the TS_ADMIN_GROUP if it's a local user, otherwise IVT would fail
		if [ -n "$was_admin_user" ];then
            WAS_ADMIN_USER_EXIST=`cat /etc/passwd | grep ^$was_admin_user | ${AWK_COLON} '{print($1)}'` 
            if [ -z "$WAS_ADMIN_USER_EXIST" ];then
                addGroupToUser $TS_ADMIN_GROUP $was_admin_user
            fi
		fi
		was_admin_group=${TS_ADMIN_GROUP}
	fi
	
	if [ "$?" != "0" ];then
		return $FALSE
	else
		getMessage TSIN01117I
		log $msg
		#log "WebSphere Application Server configured."
		return $TRUE
	fi
}

deployArtifacts()
{
    if [ "$clean" != "$TRUE" ];then
        $TS_HOME/bin/importReplaceTSAR.sh -force -file $TSAR >> $utilsLogFile 2>&1
        if [ "$?" = "0" ];then
            return $TRUE
        else
            return $FALSE
        fi
    fi
    
    return $TRUE
}

configureComponents()
{
	for item in $components
	do
		case "$item" in
			DB)
                isVerbose=$TRUE
                getMessage TSIN02222I
                log $msg
                #log "Starting database configuration"
                isVerbose=$FALSE
				configureDB
				if [ "$?" = "$TRUE" ];then
					getMessage TSIN01138I
                    isVerbose=$TRUE
					log $msg
					#log "\nConfiguration SUCCESSFUL: Database"
                    isVerbose=$FALSE
				else
					getMessage TSIN01139E
					log $msg
					#log "\nConfiguration NOT SUCCESSFUL: Database"
					return $FALSE
				fi
				;;
			MQ)
                isVerbose=$TRUE
                getMessage TSIN02223I
                log $msg
                #log "Starting MQ configuration"
                isVerbose=$FALSE
				configureMQ
				if [ "$?" = "$TRUE" ];then
					getMessage TSIN01140I
                    isVerbose=$TRUE
					log $msg
					#log "\nConfiguration SUCCESSFUL: WebSphere MQ"
                    isVerbose=$FALSE
				else
					getMessage TSIN01142E
                    isVerbose=$TRUE
					log $msg
					#log "\nConfiguration NOT SUCCESSFUL: WebSphere MQ"
                    isVerbose=$FALSE
					return $FALSE
				fi
				;;
			WAS)
                isVerbose=$TRUE
                getMessage TSIN02224I
                log $msg
                #log "Starting WAS configuration"
                isVerbose=$FALSE
				configureWAS
				was=$?
				if [ "$was" = "$TRUE" ];then
					getMessage TSIN01141I
                    isVerbose=$TRUE
					log $msg
                    isVerbose=$FALSE
					#log "\nConfiguration SUCCESSFUL: WebSphere Application Server"
				else
					getMessage TSIN01143E
                    isVerbose=$TRUE
					log $msg
					#log "\nConfiguration NOT SUCCESSFUL: WebSphere Application Server"
                    isVerbose=$FALSE
					return $FALSE
				fi
				;;
            TSAR)
                if [ "$clean" != "$TRUE" ];then
                    isVerbose=$TRUE
                    getMessage TSIN02225I
                    log $msg
                    #log "Deploying Artifacts"
                    isVerbose=$FALSE
                    deployArtifacts
                    if [ "$?" = "0" ];then
                        getMessage TSIN02227I
                        echo $msg
                        #echo "Artifacts imported successfully."
                    else
                        getMessage TSIN02228E
                        echo $msg
                        #echo "Problem importing artifacts."
                        return $FALSE
                    fi
                fi
                ;;
			*)
				getMessage TSIN01133E $item
				log $msg
				#log "No such product: $item"
				;;
		esac
	done
}

verifyWASVariables()
{
    if [ -z "$WAS_HOME" ];then
        getMessage TSIN01050E
        missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'WAS_HOME' is empty"
        return $FALSE
    else
        getActualWASConfig
        isWASSecurityEnabled
        securityEnabled=$?
        if [ "$securityEnabled" = "$TRUE" ];then
            WAS_PORT_NO=`grep WC_defaulthost_secure= $WAS_PROFILE_HOME/properties/portdef.props | sed 's/WC_defaulthost_secure=//'`
        else
            WAS_PORT_NO=`grep WC_defaulthost= $WAS_PROFILE_HOME/properties/portdef.props | sed 's/WC_defaulthost=//'`
        fi
    fi

	if [ "$clean" = "$FALSE" -a "$wasSelected" = "$TRUE" -a "$securityEnabled" = "$TRUE" ];then
        if [ -z "$was_admin_user" ];then
            #missing_info=$missing_info"\nThe value for 'was_admin_user' is empty"
            getMessage TSIN02273E "was_admin_user"
            missing_info=$missing_info"\n$msg"
        fi
		if [ -z "$WS_UI_USER" ];then
			#missing_info=$missing_info"\nThe value for 'WS_UI_USER' is empty"
			getMessage TSIN01310E
			missing_info=$missing_info"\n$msg"
		fi
		if [ -z "$WS_UI_PWD" ];then
			#missing_info=$missing_info"\nThe value for 'WS_UI_PWD' is empty"
			getMessage TSIN01311E
			missing_info=$missing_info"\n$msg"
		fi
		if [ -z "$WS_UI_SSL" ];then
			#missing_info=$missing_info"\nThe value for 'WS_UI_SSL' is empty"
			getMessage TSIN01312E
			missing_info=$missing_info"\n$msg"
		fi
	fi


	if [ -z "$WAS_PROFILE" ];then
		WAS_PROFILE=AppSrv01
	fi

	if [ -z "$WAS_PORT_NO" ];then
		WAS_PORT_NO=9080
	fi
	
	if [ -z "$was_runas_user" ];then
		was_runas_user=$TS_ADMIN_USER
	fi
	
	if [ -z "$was_runas_group" ]; then
		was_runas_group=$TS_ADMIN_GROUP
	fi

	if [ -z "$was_runas_password" ]; then
		was_runas_password=$TS_ADMIN_PASSWORD
	fi
	
	if [ -z "$SERVERNAME" ];then
		SERVERNAME=server1
	fi
	
	if [ -z "$NODENAME" ];then
		NODENAME="$HOSTNAME"Node01
	fi
	
	if [ -z "$CELLNAME" ];then
		CELLNAME="$HOSTNAME"Node01Cell
	fi

	if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
		getMessage TSIN01018I $was_admin_user
		$ECHO $msg
		#log "Enter the password for the WAS Administrative user: $was_admin_user"
		stty -echo
		read was_admin_password
		stty echo
        export was_admin_password
		echo
	fi

	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
		credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
		creds="-user $was_admin_user -password $was_admin_password"
	fi
}

verifyMQVariables()
{
	isHostnameRemote $MQ_HOST
	mq_dist=$?

	if  [ -z "$MQ_HOME" ];then
		if [ "$mq_dist" = "$FALSE" ];then
			getMessage TSIN01065E
			missing_info=$missing_info"\n$msg"
        	#missing_info=$missing_info"\nThe value for 'MQ_HOME' is empty"
		else
			MQ_HOME=/opt/mqm
		fi
	fi
	if  [ ! "$MQ_LOG_TYPE" = "LINEAR" -a ! "$MQ_LOG_TYPE" = "CIRCULAR" ];then
		getMessage TSIN01066E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'MQ_LOG_TYPE' is invalid , valid values are LINEAR/CIRCULAR"
	fi
	if  [ "$MQ_LOG_FILE_PAGES" -lt 64 -o "$MQ_LOG_FILE_PAGES" -gt 65535 ];then
		getMessage TSIN01067E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'MQ_LOG_FILE_PAGES' is invalid , valid range is 64 - 65535 "
	fi
	if  [ "$MQ_LOG_PRIMARY_FILES" -lt 3 -o "$MQ_LOG_PRIMARY_FILES" -gt 510 ];then
		getMessage TSIN01068E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'MQ_LOG_PRIMARY_FILES' is invalid , valid range is 3 - 510 "
	fi
	if  [ "$MQ_LOG_SECONDARY_FILES" -lt 2 -o "$MQ_LOG_SECONDARY_FILES" -gt 509 ];then
		getMessage TSIN01069E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'MQ_LOG_SECONDARY_FILES' is invalid , valid range is 2 - 509 "
	fi

	if  [ -z "$MQ_USER" ];then
		getMessage TSIN01070E
		missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'MQ_USER' is empty"
	fi
    
	if  [ -z "$MQ_USER_PASSWORD" ];then
        if [ -n "$MQ_USER" -a "$clean" = "$TRUE" ];then
            getMessage RFID05047I $MQ_USER
            $ECHO $msg
            stty -echo
            read MQ_USER_PASSWORD
            stty echo
            echo
            export MQ_USER_PASSWORD
        else
            getMessage TSIN01071E
            missing_info=$missing_info"\n$msg"
            #missing_info=$missing_info"\nThe value for 'MQ_USER_PASSWORD' is empty"
        fi
	fi

	if [ -z "$MQ_HOST" ];then
		MQ_HOST=$HOSTNAMEFULL
	fi
	
	if [ -z "$MQ_QUEUE_MANAGER" ];then
		MQ_QUEUE_MANAGER=TS.QUEUE.MANAGER
	fi
	
	if [ -z "$MQ_LOG_FILE_PAGES" ];then
		MQ_LOG_FILE_PAGES=65535
	fi
	
	if [ -z "$MQ_LOG_TYPE" ];then
		MQ_LOG_TYPE=CIRCULAR
	fi
	
	if [ -z "$MQ_LOG_PRIMARY_FILES" ];then
		MQ_LOG_PRIMARY_FILES=3
	fi
	
	if [ -z "$MQ_LOG_SECONDARY_FILES" ];then
		MQ_LOG_SECONDARY_FILES=2
	fi
	
	if [ -z "$MQ_TS_CHANNEL" ];then
		MQ_TS_CHANNEL=TS.CHANNEL
	fi
	
	if [ -z "$MQ_LSR_PORT" ];then
		MQ_LSR_PORT=1414
	fi
	
	if [ -z "$QUEUE_NAME" ];then
		QUEUE_NAME=EPCEVENT
	fi
	
	if [ -z "$ALERTS_ENGINE_INPUT_QUEUE_NAME" ];then
		ALERTS_ENGINE_INPUT_QUEUE_NAME=AlertsEngineInputQueue
	fi
	
	if [ -z "$MDM_CHANGE_NOTIF_QUEUE_NAME" ];then
		MDM_CHANGE_NOTIF_QUEUE_NAME=MDMChangeNotification
	fi
	
	if [ -z "$AS2DELIVERY_QUEUE_NAME" ];then
		AS2DELIVERY_QUEUE_NAME=AS2Delivery
	fi
	
	if [ -z "$AS2REQUEST_QUEUE_NAME" ];then
		AS2REQUEST_QUEUE_NAME=AS2Request
	fi
	
	if [ -z "$AS2RESPONSE_QUEUE_NAME" ];then
		AS2RESPONSE_QUEUE_NAME=AS2Response
	fi
	
	if [ -z "$CAPTURE_NOTIF_QUEUE_NAME" ];then
		CAPTURE_NOTIF_QUEUE_NAME=RFIDICCAPTURENOTIF
	fi

    if [ -n "$R_QUEUE_MANAGER" -o -n "$R_MQ_HOST" -o -n "$R_MQ_LSR_PORT" -o -n "$MQ_CLUSTER" -o -n "$QUEUE_MANAGER_TYPE" ];then
        if  [ -z "$R_QUEUE_MANAGER" ];then
            getMessage TSIN02273E R_QUEUE_MANAGER
            missing_info=$missing_info"\n$msg"
        fi

        if  [ -z "$R_MQ_HOST" ];then
            getMessage TSIN02273E R_MQ_HOST 
            missing_info=$missing_info"\n$msg"
        fi

        if  [ -z "$QUEUE_MANAGER_TYPE" ];then
            getMessage TSIN02273E QUEUE_MANAGER_TYPE
            missing_info=$missing_info"\n$msg"
        fi

        if  [ -z "$R_MQ_LSR_PORT" ];then
            R_MQ_LSR_PORT=1414
        fi

        if  [ -z "$MQ_CLUSTER" ];then
            MQ_CLUSTER=TRACEABILITY
        fi
    fi
}

verifyOracleVariables()
{
	isHostnameRemote $DBMS_HOST
	db_dist=$?

	if  [ -z "$DBMS_PORT_NUMBER" ];then
		getMessage TSIN01061E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'ORACLE_PORT_NUMBER' is empty"
	fi

    getDBVersion
    if [ "$?" != "0" ];then
        getMessage TSIN02209E $DBMS_HOST $logFileName
        missing_info=$missing_info"\n$msg"
        return 1
    fi

    dbVersion=$returnString

	if [ -n "$DBMS_JDBC_LIB_PATH" -a -n "$WAS_HOME" -a -n "$DBMS_ADMIN_USER" -a -n "$DBMS_ADMIN_PASSWORD" -a -n "$DBMS_PORT_NUMBER" ];then
		#ojdbc5.jar will work with Oracle11G - which in turns works with jdk1.5 supported by WAS 6.1
		#The minimal Oracle version supported by Charlie is 11.2 
		if [ `echo $dbVersion | ${AWK_PERIOD} '{print($1)}'` = "11" ];then
			if [ ! -f "$DBMS_JDBC_LIB_PATH/ojdbc5.jar" ];then
				getMessage TSIN01056E $DBMS_JDBC_LIB_PATH
				missing_info=$missing_info"\n$msg"
				#missing_info=$missing_info"\nOne or more required JDBC drivers not present under $DBMS_JDBC_LIB_PATH."
				getMessage TSIN01057E
				missing_info=$missing_info"\n$msg"
				#missing_info=$missing_info"\nSpecify the correct value for 'DBMS_JDBC_LIB_PATH'"
			fi
		fi	
	fi
	
	if [ "$db_dist" = "$FALSE" ];then
		if [ -z "$ORACLE_GROUP" ];then
			getMessage TSIN01060E
			missing_info=$missing_info"\n$msg"
			#missing_info=$missing_info"\nThe value for 'ORACLE_GROUP' is empty"
		fi
	else
		DBMS_HOME=$TS_HOME/Oracle
	fi
}

verifyDB2Variables()
{
	isHostnameRemote $DBMS_HOST
	db_dist=$?

	if  [ -z "$DB_TYPE" ];then
		getMessage TSIN01051E
		missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'DB_TYPE' is empty"
	fi
	
	if  [ -z "$DBMS_HOME" ];then
		if [ "$db_dist" = "$FALSE" ];then
			getMessage TSIN01052E
			missing_info=$missing_info"\n$msg"
        		#missing_info=$missing_info"\nThe value for 'DBMS_HOME' is empty"
		else
			DBMS_HOME=$TS_HOME/DB2
		fi
	fi
	
	if  [ -z "$DBMS_ADMIN_USER" ];then
		getMessage TSIN01053E
		missing_info=$missing_info"\n$msg"
        	#missing_info=$missing_info"\nThe value for 'DBMS_ADMIN_USER' is empty"
	fi
	
	if  [ -z "$DBMS_ADMIN_PASSWORD" ];then
        if [ -n "$DBMS_ADMIN_USER" -a "$clean" = "$TRUE" ];then
            getMessage RFID05047I $DBMS_ADMIN_USER
            $ECHO $msg
            stty -echo
            read DBMS_ADMIN_PASSWORD
            stty echo
            echo
            export DBMS_ADMIN_PASSWORD
        else
            getMessage TSIN01054E
            missing_info=$missing_info"\n$msg"
            #missing_info=$missing_info"\nThe value for 'DBMS_ADMIN_PASSWORD' is empty"
        fi
	fi
	
	if [ -z "$DBMS_JDBC_LIB_PATH" ];then
		getMessage TSIN01055E
		missing_info=$missing_info"\n$msg"
        	#missing_info=$missing_info"\nThe value for 'DBMS_JDBC_LIB_PATH' is empty"
	fi

	if [ -z "$DBMS_PORT_NUMBER" ];then
		DBMS_PORT_NUMBER=$DBMS_PORT_NUMBER
	fi
	
	getDBVersion
    if [ "$?" != "0" ];then
        getMessage TSIN02209E $DBMS_HOST $logFileName
        missing_info=$missing_info"\n$msg"
        return 1
    fi

	dbVersion=$returnString

	if [ -n "$DBMS_JDBC_LIB_PATH" -a -n "$WAS_HOME" -a -n "$DBMS_ADMIN_USER" -a -n "$DBMS_ADMIN_PASSWORD" -a -n "$DBMS_PORT_NUMBER" ];then
		license_file=`ls $DBMS_JDBC_LIB_PATH | grep "db2jcc_license"`
		if [ ! -f "$DBMS_JDBC_LIB_PATH/db2jcc.jar" -o -z "$license_file" ];then
			getMessage TSIN01056E $DBMS_JDBC_LIB_PATH
			missing_info=$missing_info"\n$msg"
			#missing_info=$missing_info"\nOne or more required JDBC drivers not present under $DBMS_JDBC_LIB_PATH."
			getMessage TSIN01057E
			missing_info=$missing_info"\n$msg"
			#missing_info=$missing_info"\nSpecify the correct value for 'DBMS_JDBC_LIB_PATH'"
		fi
			
		if [ `echo $dbVersion | ${AWK_PERIOD} '{print($2)}'` = "1" ];then
			if [ ! -f "$DBMS_JDBC_LIB_PATH/db2jcc_javax.jar" ];then
				getMessage TSIN01056E $DBMS_JDBC_LIB_PATH
				missing_info=$missing_info"\n$msg"
				#missing_info=$missing_info"\nOne or more required JDBC drivers not present under $DBMS_JDBC_LIB_PATH."
				getMessage TSIN01057E
				missing_info=$missing_info"\n$msg"
				#missing_info=$missing_info"\nSpecify the correct value for 'DBMS_JDBC_LIB_PATH'"
			fi
		fi
	fi

	if [ -z "$DBMS_PORT_NUMBER" ];then
		getMessage TSIN01062E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'DB2_PORT_NUMBER' is empty"
	fi
	if  [ -z "$DB2_INSTANCE_OWNER" ];then
		getMessage TSIN01063E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'DB2_INSTANCE_OWNER' is empty"
	fi
	if  [ -z "$DB2_INSTANCE" ];then
		getMessage TSIN01064E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'DB2_INSTANCE' is empty"
	fi

	DB_TYPE=`echo "$DB_TYPE" | tr "[a-z]" "[A-Z]"`
	if [ -z "$DBMS_DB_NAME" ]; then
		DBMS_DB_NAME=tsdb
	fi

	if [ -z "$DBMS_HOST" ];then
		DBMS_HOST=$HOSTNAMEFULL
	fi

	isHostnameRemote $DBMS_HOST
	db_dist=$?
	
	if [ -z "$DBMS_JDBC_LIB_PATH" ];then
		if [ "$db_dist" = "$FALSE" ];then
			if [ -n "$DBMS_HOME" ];then
				if [ "$DB_TYPE" = "ORACLE" ];then
					DBMS_JDBC_LIB_PATH=$DBMS_HOME/jdbc/lib
				elif [ "$DB_TYPE" = "DB2" ];then
					DBMS_JDBC_LIB_PATH=$DBMS_HOME/java
				fi
			fi
		fi
	fi
}

verifyDBVariables()
{
	if [ "$DB_TYPE" = "DB2" ];then
		verifyDB2Variables
	elif [ "$DB_TYPE" = "ORACLE" ];then
		verifyOracleVariables
	else
		getMessage TSIN02273E "DB_TYPE"
		missing_info=$missing_info"\n$msg"
	fi
		
}

verifyTSVariables()
{
	if [ -z "$TS_HOME" ]; then
		getMessage TSIN02273E "TS_HOME"
		missing_info=$missing_info"\n$msg"
	fi
	
	if [ -z "$TS_ADMIN_USER" ];then
		getMessage TSIN02273E "TS_ADMIN_USER"
		missing_info=$missing_info"\n$msg"
	fi
	
	if  [ -z "$TS_ADMIN_PASSWORD" ];then
	    if [ "$TS_ADMIN_USER" != "root" -o "$CURRENT_USER" != "root" ];then
            if [ -n "$TS_ADMIN_USER" -a "$clean" = "$TRUE" ];then
                getMessage RFID05047I $TS_ADMIN_USER
                $ECHO $msg
                stty -echo
                read TS_ADMIN_PASSWORD
                stty echo
                echo
                export TS_ADMIN_PASSWORD
            else
                getMessage TSIN02273E "TS_ADMIN_PASSWORD"
                missing_info=$missing_info"\n$msg"
            fi
	    fi
	fi

	if [ -z "$TS_ADMIN_GROUP" ];then
		getMessage TSIN02273E "TS_ADMIN_GROUP"
		missing_info=$missing_info"\n$msg"
	fi
	
	if [ -z "$TS_BUS_NAME" ];then
		getMessage TSIN02273E "TS_BUS_NAME"
		missing_info=$missing_info"\n$msg"
	fi
	
	if [ -z "$TS_ADMIN_USER_HOME" ];then
		getMessage TSIN02273E "TS_ADMIN_USER_HOME"
		missing_info=$missing_info"\n$msg"
	fi
	
	if [ -z "$HELP_TYPE" ];then
		getMessage TSIN02273E "HELP_TYPE"
		missing_info=$missing_info"\n$msg"
	fi
}

verifyVariables()
{
	verifyTSVariables
	for item in $components
	do
		case "$item" in
			DB)
                verifyDBVariables
				;;
			MQ)
                verifyMQVariables
				;;
			WAS)
                verifyWASVariables
                verifyWASVariablesPerformed=$TRUE
				;;
			TSAR)
                #We need all the WAS variables available when deploying artifacts.
                if [ -z "$verifyWASVariablesPerformed" ];then
                    . ${scriptDir}/tsEnv.sh
                    verifyWASVariables
                fi
				;;
			*)
				getMessage TSIN01133E $item
				log $msg
				#log "No such product: $item"
				;;
		esac
	done
}

main()
{
	parseArgs $*
	if [ "$?" = "$FALSE" ];then
		return $FALSE
	fi

	unset missing_info
	verifyVariables

	if [ -n "$missing_info" ];then
		log $missing_info
		$ECHO $missing_info
		return $FALSE
	fi

	isSystemValid
	if [ "$?" = "$FALSE" ];then
	    if [ -n "$missing_info" ];then
			log $missing_info
			$ECHO $missing_info
	    fi
		return $FALSE
	fi

	isSystemReady
	if [ "$?" = "$FALSE" ];then
		return $FALSE
	fi

	createUserID
	if [ "$?" = "$FALSE" ];then
		return $FALSE
	fi

	configureComponents
	if [ "$?" = "$FALSE" ];then
		return $FALSE
	fi
	return $TRUE
}

main $*
retcode=$?
if [ "$retcode" = "$FALSE" ];then
	getMessage TSIN01144E $utilsLogFile
	echo $msg
	log $msg
	#log "\nThe failure information can be found in the log file $LOG."
else
	getMessage TSIN02226I
	echo $msg
	#echo "Configuration successfull"
fi

exit $retcode
