#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
#
# 
# configureDB.sh -  (DESIGNED FOR LAUNCHPAD) updates tsEnv.sh and RFIDICServer.xml file with new DB values from user
###############################################################################################################
SCRIPT_DIR=`dirname $0`
. ${SCRIPT_DIR}/utils.sh

ECHO="echo"
PLATFORM=`uname`

AWK_EQUAL="awk -F "=""
if [ "$PLATFORM" = "SunOS" ];then
    AWK_EQUAL="awk -F="
fi

# First argument is the path to the jar (including file name) relative to the Oracle home directory
# Second argument is the location for the symbolic link
createSymbolicLinkForOracleJar()
{
    unset oracle_jar
    
    oracle_jar_name=`basename $1`
    oracle_jar_path=`dirname $1`
    
    if [ -n "$DBMS_HOME" ];then
        oracle_jar=$DBMS_HOME/$1
    fi
    
    if [ ! -e "$oracle_jar" ];then
        if [ -n "$DBMS_JDBC_LIB_PATH" ];then
            oracle_jar=$DBMS_JDBC_LIB_PATH/../../$1
            if [ ! -e "$oracle_jar" ];then
                oracle_jar=$DBMS_JDBC_LIB_PATH/$oracle_jar_name
                if [ ! -e "$oracle_jar" ];then
                    if [ -n "$DBMS_HOME" ];then
                        checked_dirs="$DBMS_HOME/$oracle_jar_path, $DBMS_JDBC_LIB_PATH/../../$oracle_jar_path, $DBMS_JDBC_LIB_PATH"
                    else
                        checked_dirs="$DBMS_JDBC_LIB_PATH/../../$oracle_jar_path, $DBMS_JDBC_LIB_PATH"
                    fi
                    echo "Cannot find $oracle_jar_name in the following locations: $checked_dirs"
                    return 1
                fi
            fi
        else
            echo "Cannot find $oracle_jar_name in the following locations: $DBMS_HOME/$oracle_jar_path"
            return 1
        fi
    fi
    
    if [ -e "$oracle_jar" ];then
        rm -f $2/$oracle_jar_name
        ln -sf $oracle_jar $2
        if [ $? -ne 0 ];then
            echo "Unable to create symbolic link from $oracle_jar to $2"
            return 1
        fi
    fi
    
    return 0
}

usage()
{
	echo "	USAGE: ./configureDB.sh"
	echo "                          [DB_TYPE=<DB2|ORACLE>]"
    echo "                          [DBMS_HOME=<Path where the database is installed>]"
	echo "                          [DBMS_ADMIN_USER=<value>]"
	echo "                          [TS_HOME=<Path where InfoSphere Traceability Server is installed>]"
	echo "                          [TS_ADMIN_USER=<value>]"
	echo "                          [DBMS_ADMIN_PASSWORD=<value>]"
	echo "                          [DBMS_HOST=<value>]"
	echo "                          [DBMS_PORT_NUMBER=<value of listener port>]"
	echo "                          [DB2_INSTANCE=<value>]"
	echo "                          [DB2_INSTANCE_OWNER=<value>]"
	echo "                          [DBMS_DB_NAME=<value>]"
	echo "                          [DBMS_TABLE_SPACE=<value>]"
	echo "                          [DBMS_JDBC_LIB_PATH=<value>]"
	echo "                          [ORACLE_OWNER=<value>]"
	echo "                          [ORACLE_GROUP=<value>]"
	echo "                          [ORACLE_JDBC_URL=<value>]"
	echo "                          [RESULT=<name of result file>]"	
}

#use inputs according to local or silent config
if [ `expr match "$1" '-input_file='` != 0 ];then        #silent install

	. ${scriptDir}/rfidic-cfg.prop

	# Use default values if they are not updated in properties file

	if [ -z "$TS_HOME" ];then
		TS_HOME=epedigree147
	fi
	if [ -z "$DB_TYPE" ];then
		DB_TYPE=DB2
	fi
	if [ -z "$DBMS_HOME" ];then
		DBMS_HOME=/opt/ibm/db2
	fi
	if [ -z "$DBMS_HOST" ];then
		DBMS_HOST=ePedigree167
	fi
	if [ -z "$DBMS_ADMIN_USER" ];then 
		DBMS_ADMIN_USER=dasusr1
	fi
	if [ -z "$DBMS_ADMIN_PASSWORD" ];then
		DBMS_ADMIN_PASSWORD=dasusr1
	fi
	if [ -z "$DBMS_PORT_NUMBER" ];then
		DBMS_PORT_NUMBER=50000
	fi
	if [ -z "$DB2_INSTANCE" ];then
		DB2_INSTANCE=db2inst1
	fi
	if [ -z "$DB2_INSTANCE_OWNER" ];then 
		DB2_INSTANCE_OWNER=db2inst1
	fi
	if [ -z "$DBMS_DB_NAME" ];then 
		DBMS_DB_NAME=tsdb
	fi
	if [ -z "$DBMS_JDBC_LIB_PATH" ];then 
		DBMS_LIB_PATH=/opt/ibm/db2/V9.1/java
	fi
	if [ -z "$ORACLE_OWNER" ];then 
		ORACLE_OWNER=oracle
	fi
	if [ -z "$ORACLE_GROUP" ];then 
		ORACLE_GROUP=system
	fi
	if [ -z "$ORACLE_JDBC_URL" ];then
		ORACLE_JDBC_URL=jdbc:oracle:thin:ePedigree167@in.ibm.com:1521:tsdb
	fi
else	#local install from launchpad..
	for item in $@
       do
		if [ `expr match "$item" '-DB_TYPE='` != 0 ];then
			DB_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_HOME='` != 0 ];then
			DBMS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_ADMIN_USER='` != 0 ];then
			DBMS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-TS_HOME='` != 0 ];then
			TS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
            RFIDIC_HOME=$TS_HOME
		elif [ `expr match "$item" '-TS_ADMIN_USER='` != 0 ];then
			TS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_ADMIN_PASSWORD='` != 0 ];then
			DBMS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_HOST='` != 0 ];then
			DBMS_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_PORT_NUMBER='` != 0 ];then
			DBMS_PORT_NUMBER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DB2_INSTANCE='` != 0 ];then
			DB2_INSTANCE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DB2_INSTANCE_OWNER='` != 0 ];then
			DB2_INSTANCE_OWNER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_DB_NAME='` != 0 ];then
			DBMS_DB_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_TABLE_SPACE='` != 0 ];then
			DBMS_TABLE_SPACE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_JDBC_LIB_PATH='` != 0 ];then
			DBMS_JDBC_LIB_PATH=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ORACLE_OWNER='` != 0 ];then
			ORACLE_OWNER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ORACLE_GROUP='` != 0 ];then
			ORACLE_GROUP=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ORACLE_JDBC_URL='` != 0 ];then
			ORACLE_JDBC_URL=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-RESULT='` != 0 ];then
			RESULT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-help'` != 0 ];then
			usage 
			exit 1
		else
			getMessage TSIN02215I
			echo $msg
			#echo "Unidentified argument passed"
			exit 1
        fi
	done
fi

scriptDir=$TS_HOME/bin
. $scriptDir/utils.sh

if [ "$DB_TYPE" = "ORACLE" ];then
    if [ -n "$ORACLE_GROUP" ];then
        addGroupToUser $ORACLE_GROUP $TS_ADMIN_USER
    fi
    
    createSymbolicLinkForOracleJar rdbms/jlib/xdb.jar $TS_HOME/ext_lib
    returnCode=$?
    if [ $returnCode -ne 0 ];then
        exit $returnCode
    fi
    
    createSymbolicLinkForOracleJar lib/xmlparserv2.jar $TS_HOME/ext_lib
    returnCode=$?
    if [ $returnCode -ne 0 ];then
        exit $returnCode
    fi
fi	

if [ "$DB_TYPE" = "DB2" ];then
	$scriptDir/updateEnv.sh -TS_HOME=$TS_HOME -CONFIG_TYPE=DB -DB_TYPE=$DB_TYPE -DBMS_HOME=$DBMS_HOME -DBMS_ADMIN_USER=$DBMS_ADMIN_USER -DBMS_ADMIN_PASSWORD=$DBMS_ADMIN_PASSWORD -DBMS_PORT_NUMBER=$DBMS_PORT_NUMBER -DBMS_HOST=$DBMS_HOST -DBMS_DB_NAME=$DBMS_DB_NAME -DBMS_TABLE_SPACE=$DBMS_TABLE_SPACE -DBMS_JDBC_LIB_PATH=$DBMS_JDBC_LIB_PATH -DB2_INSTANCE=$DB2_INSTANCE -DB2_INSTANCE_OWNER=$DB2_INSTANCE_OWNER -RESULT=$RESULT
elif [ "$DB_TYPE" = "ORACLE" ];then
	$scriptDir/updateEnv.sh -TS_HOME=$TS_HOME -CONFIG_TYPE=DB -DB_TYPE=$DB_TYPE -DBMS_HOME=$DBMS_HOME -DBMS_ADMIN_USER=$DBMS_ADMIN_USER -DBMS_ADMIN_PASSWORD=$DBMS_ADMIN_PASSWORD -DBMS_PORT_NUMBER=$DBMS_PORT_NUMBER -DBMS_HOST=$DBMS_HOST -DBMS_DB_NAME=$DBMS_DB_NAME -DBMS_TABLE_SPACE=$DBMS_TABLE_SPACE -DBMS_JDBC_LIB_PATH=$DBMS_JDBC_LIB_PATH -ORACLE_OWNER=$ORACLE_OWNER -ORACLE_GROUP=$ORACLE_GROUP -ORACLE_JDBC_URL=$ORACLE_JDBC_URL -RESULT=$RESULT
fi

returnCode=$?
if [ $returnCode -eq 0 ];then
	echo "SUCCESS"
	if [ ! -z "$RESULT" ];then
		$ECHO "SUCCESS" >> $RESULT
	fi
fi
exit $returnCode