#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title: configureMQHA.sh	
##   Description: Configures MQ Manager and Queues
##		
##   DESIGNED TO WORK WITH LAUNCHPAD OR SILENT INSTALL ONLY
#############################################################################
umask 0022
SCRIPT_DIR=`dirname $0`
. ${SCRIPT_DIR}/utils.sh

ECHO="echo"
AWK="awk -F ".""
TRUE=0
FALSE=1

PLATFORM=`/bin/uname`
	case $PLATFORM in
	SunOS)
		AWK="awk -F."
		;;
	esac

ID=`id`
CURRENT_USER=`expr "$ID" : ".*uid=[0-9]*(\([^)]*\)*"`

# runs a command and terminates if the return code is non-zero
run_cmd ()
{
	command="$*"
	"$@" 
	retcode=$?
	if [ "$retcode" -ne 0 ];then
		if [ ! -z "$RESULT" ];then
			#getMessage TSIN02229E $command
			#echo $msg >> $RESULT
			echo "$command returned a non zero return code" >> $RESULT
		fi
		#getMessage TSIN02229E $command
		#echo $msg
		echo "$command returned a non zero return code"
		return $retcode
	fi
}

usage()
{
	echo "	USAGE: ./configureMQHA.sh"
	echo "                          [-clean]"
	echo "                          [-input_file=<Path to rfidic-mq-cfg.prop file>]"
	echo "                          [-TS_HOME=<value>]"
    echo "                          [-TS_ADMIN_USER=<value>]"
    echo "                          [-TS_ADMIN_PASSWORD=<value>]"
	echo "                          [-MQ_HOST=<value>]"
	echo "                          [-MQ_HOME=<Path where MQ is installed>]"
	echo "                          [-QUEUE_MANAGER=<queue manager name>]"
	echo "                          [-MQ_TS_CHANNEL=<mq channel name>]"
	echo "                          [-MQ_LOG_FILE_PAGES=<value>]"
	echo "                          [-MQ_LOG_TYPE=<value>]"
	echo "                          [-MQ_LOG_PRIMARY_FILES=<value>]"
	echo "                          [-MQ_LOG_SECONDARY_FILES=<value>]"
	echo "                          [-MQ_QUEUE_NAME=<value>]"
	echo "                          [-ALERTS_ENGINE_INPUT_QUEUE_NAME=<value>]"
	echo "                          [-MDM_CHANGE_NOTIF_QUEUE_NAME=<value>]"
	echo "                          [-AS2DELIVERY_QUEUE_NAME=<value>]"
	echo "                          [-AS2REQUEST_QUEUE_NAME=<value>]"
	echo "                          [-AS2RESPONSE_QUEUE_NAME=<value>]"
	echo "                          [-CAPTURE_NOTIF_QUEUE_NAME=<value>]"
	echo "                          [-MQ_LSR_PORT=<value of listener port>]"
	echo "                          [-MQ_USER=<value>]"
	echo "                          [-MQ_USER_PASSWORD=<value>]"
	echo "				     [-MQ_CLUSTER=<value>]"
	echo "				     [-QUEUE_MANAGER_TYPE=<FULL/PARTIAL>]"
	echo "				     [-R_QUEUE_MANAGER=<value of queue maneger it is going to connect to>]"
	echo " 		            [-R_MQ_HOST=<value of host where the connecting qm resides>]"
	echo " 		            [-R_MQ_LSR_PORT=<value of port remote port when QM will connect>]"
	return 1
}

#use inputs according to local or remote config
if [ `expr match "$1" '-input_file='` != 0 ];then        #silent install for local and remote

	. ${SCRIPT_DIR}/configureTS.properties

	# Use default values if they are not updated in properties file

	if [ -z "$MQ_HOME" ];then
		MQ_HOME=/opt/mqm
	fi
	if [ -z "$QUEUE_MANAGER" ];then 
		QUEUE_MANAGER=TS.QUEUE.MANAGER
	fi
	if [ -z "$MQ_LOG_FILE_PAGES" ];then
		MQ_LOG_FILE_PAGES=65535
	fi
	if [ -z "$MQ_LOG_TYPE" ];then
		MQ_LOG_TYPE=CIRCULAR
	fi
	if [ -z "$MQ_LOG_PRIMARY_FILES" ];then
		MQ_LOG_PRIMARY_FILES=3
	fi
	if [ -z "$MQ_LOG_SECONDARY_FILES" ];then
		MQ_LOG_SECONDARY_FILES=2
	fi
	if [ -z "$MQ_TS_CHANNEL" ];then 
		MQ_TS_CHANNEL=TS.CHANNEL
	fi
	if [ -z "$QUEUE_NAME" ];then 
		QUEUE_NAME=EPCEVENT
	fi
	if [ -z "$ALERTS_ENGINE_INPUT_QUEUE_NAME" ];then 
		ALERTS_ENGINE_INPUT_QUEUE_NAME=ALERTSENGINEINPUTQUEUE
	fi
	if [ -z "$MDM_CHANGE_NOTIF_QUEUE_NAME" ];then 
		MDM_CHANGE_NOTIF_QUEUE_NAME=MDMCHANGENOTIFICATION
	fi
	if [ -z "$AS2DELIVERY_QUEUE_NAME" ];then 
		AS2DELIVERY_QUEUE_NAME=AS2DELIVERY
	fi
	if [ -z "$AS2REQUEST_QUEUE_NAME" ];then 
		AS2REQUEST_QUEUE_NAME=AS2REQUEST
	fi
	if [ -z "$AS2RESPONSE_QUEUE_NAME" ];then 
		AS2RESPONSE_QUEUE_NAME=AS2RESPONSE
	fi
	if [ -z "$CAPTURE_NOTIF_QUEUE_NAME" ];then 
		CAPTURE_NOTIF_QUEUE_NAME=RFIDICCAPTURENOTIF
	fi
	if [ -z "$MQ_LSR_PORT" ];then 
		MQ_LSR_PORT=1414
	fi
	if [ -z "$MQ_USER" ];then
		MQ_USER=mqm
	fi
	if [ -z "$QUEUE_MANAGER_TYPE" ];then
		QUEUE_MANAGER_TYPE=FULL
	fi
	if [ -z "$MQ_CLUSTER" ];then
		MQ_CLUSTER=TRACEABILITY
	fi
	if [ -z "$R_QUEUE_MANAGER" ];then
		if [ "$1" = "-clean" -o "$2" = "-clean" ];then
			#getMessage TSIN02245I
			#echo $msg
			echo "cleaning"
		else
			#getMessage TSIN02246E "R_QUEUE_MANAGER"
			#echo $msg
			echo "update the value of R_QUEUE_MANAGER and re-run the script"
			exit 1
		fi		
	fi
	if [ -z "$R_MQ_HOST" ];then
		if [ "$1" = "-clean" -o "$2" = "-clean" ];then
			#getMessage TSIN02245I
			#echo $msg
			echo "cleaning"
		else
			#getMessage TSIN02246E "R_HOST"
			#echo $msg
			echo "update the value of R_HOST and re-run the script"
			exit 1
		fi
	fi
	if [ -z "$R_MQ_LSR_PORT" ];then
		R_MQ_LSR_PORT=1414
	fi

else	#local install from launchpad..

	#. ${TS_HOME}/tsEnv.sh
	#take new user values
    for item in $@
    do
        if [ `expr match "$item" '-MQ_HOST='` != 0 ];then
            MQ_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_HOME='` != 0 ];then
            MQ_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-TS_HOME='` != 0 ];then
            TS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-TS_ADMIN_USER='` != 0 ];then
            TS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-TS_ADMIN_PASSWORD='` != 0 ];then
            TS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-QUEUE_MANAGER='` != 0 ];then
            QUEUE_MANAGER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_LOG_FILE_PAGES='` != 0 ];then
            MQ_LOG_FILE_PAGES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_LOG_TYPE='` != 0 ];then
            MQ_LOG_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_LOG_PRIMARY_FILES='` != 0 ];then
            MQ_LOG_PRIMARY_FILES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_LOG_SECONDARY_FILES='` != 0 ];then
            MQ_LOG_SECONDARY_FILES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_TS_CHANNEL='` != 0 ];then
            MQ_TS_CHANNEL=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-QUEUE_NAME='` != 0 ];then
            QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-ALERTS_ENGINE_INPUT_QUEUE_NAME='` != 0 ];then
            ALERTS_ENGINE_INPUT_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MDM_CHANGE_NOTIF_QUEUE_NAME='` != 0 ];then
            MDM_CHANGE_NOTIF_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-AS2DELIVERY_QUEUE_NAME='` != 0 ];then
            AS2DELIVERY_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-AS2REQUEST_QUEUE_NAME='` != 0 ];then
            AS2REQUEST_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-AS2RESPONSE_QUEUE_NAME='` != 0 ];then
            AS2RESPONSE_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-CAPTURE_NOTIF_QUEUE_NAME='` != 0 ];then
            CAPTURE_NOTIF_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_LSR_PORT='` != 0 ];then
            MQ_LSR_PORT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_USER='` != 0 ];then
            MQ_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_USER_PASSWORD='` != 0 ];then
            MQ_USER_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-SCRIPT_DIR='` != 0 ];then
            SCRIPT_DIR=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-R_QUEUE_MANAGER='` != 0 ];then
            R_QUEUE_MANAGER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-R_MQ_HOST='` != 0 ];then
            R_MQ_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-R_MQ_LSR_PORT='` != 0 ];then
            R_MQ_LSR_PORT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-QUEUE_MANAGER_TYPE='` != 0 ];then
            QUEUE_MANAGER_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-MQ_CLUSTER='` != 0 ];then
            MQ_CLUSTER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-RESULT='` != 0 ];then
            RESULT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-help'` != 0 ];then
            usage 
            exit
        elif [ `expr match "$item" '-clean'` != 0 ];then
            CLEAN_MQ="true"                    
        else
        	UNIDENTIFIED_ARGS="true"
        fi
    done
fi

if [ -f ${SCRIPT_DIR}/tsEnv.sh ];then
	. ${SCRIPT_DIR}/tsEnv.sh
elif [ -n "$TS_HOME" -a -d "$TS_HOME" ];then
    . ${TS_HOME}/bin/tsEnv.sh
fi

# If unidentified arguments found, show usage and get out
if [ -n "$UNIDENTIFIED_ARGS" ];then
	getMessage TSIN02215I
	echo $msg
	#echo "Unidentified argument passed"
	usage 
	exit 1
fi

if [ -z "$TS_ADMIN_USER" ];then
    TS_ADMIN_USER=$CURRENT_USER
fi
	
if [ -n "$TS_HOME" -a -d "$TS_HOME" ];then   #it is local
    addGroupToUser mqm $TS_ADMIN_USER
fi

#version of MQ installed
MQversion=`${MQ_HOME}/bin/dspmqver | grep "Version" | awk '{print($2)}'`	


if [ -n "$CLEAN_MQ" ];then       # for -clean, it will work the same way in both local and remote machine

	getMessage TSIN02245I
	#echo "cleaning"
	echo $msg
    
	MQRunning=`runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD dspmq | grep ${QUEUE_MANAGER} | awk '{print substr($2,7,9)}'`

   	retcode=$?
    if [ ! "$retcode" = "0" ];then
        exit $retcode
    fi

   	if [ "$MQRunning" = "(Running)" ];then	
   		#getMessage TSIN02239I
   		#echo $msg
		echo "Unconfiguring WebSphere MQ"
		#if [ `echo $MQversion | ${AWK} '{print($1)}'` = "6" ];then
		#	endmqbrk -m ${QUEUE_MANAGER}
		#elif [ `echo $MQversion | ${AWK} '{print($1)}'` = "7" ];then
        echo "ALTER QMGR PSMODE(COMPAT)" > /tmp/mq.cmd
        runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD "runmqsc ${QUEUE_MANAGER} < /tmp/mq.cmd"
        retcode=$?
        rm -f /tmp/mq.cmd
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi
		#fi
		runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD endmqlsr -m ${QUEUE_MANAGER}
        retcode=$?
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi

		runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD endmqm -w ${QUEUE_MANAGER}
        retcode=$?
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi
    fi
    
    
	MQEnded=`runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD dspmq | grep ${QUEUE_MANAGER} | awk '{print substr($2,7,9)}'`

   	retcode=$?
    if [ ! "$retcode" = "0" ];then
        exit $retcode
    fi

   	if [ "$MQEnded" = "(Ended" ];then	
		runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD dltmqm ${QUEUE_MANAGER}
        retcode=$?
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi
	fi
	
	if [ -n "$TS_HOME" -a -d "$TS_HOME" ];then   #it is local
		runCommandAsUser root:$TS_ADMIN_PASSWORD $TS_HOME/bin/configPort.sh cleanmq				
        retcode=$?
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi
		run_cmd rm -f ${TS_HOME}/logs/MQ/qmgr	
	else
		#getMessage TSIN02240I
		#echo $msg
		echo "Un-configuring port"
		mqport=$MQ_LSR_PORT
		temp_services=/tmp/rfidic-configPort-svcs.tmp
		runCommandAsUser root:$TS_ADMIN_PASSWORD sed '/mqm/d' /etc/services >| ${temp_services}
		runCommandAsUser root:$TS_ADMIN_PASSWORD mv -f ${temp_services} /etc/services
		runCommandAsUser root:$TS_ADMIN_PASSWORD chmod 644 /etc/services
	fi
else						
	if [ -n "$TS_HOME" -a -d "$TS_HOME" ];then   #it is local
		run_cmd mkdir -p "${TS_HOME}/logs/MQ"
		qmgr=`echo "$QUEUE_MANAGER" | tr "." "!"`
		
		if [ ! -e "${TS_HOME}/logs/MQ/MQ" ];then
			run_cmd ln -s "/var/mqm/log" "${TS_HOME}/logs/MQ/MQ"
		fi
		if [ ! -e "${TS_HOME}/logs/MQ/qmgr" ];then
			run_cmd ln -s "/var/mqm/qmgrs/${qmgr}/errors" "${TS_HOME}/logs/MQ/qmgr"
		fi

		runCommandAsUser root:$TS_ADMIN_PASSWORD $TS_HOME/bin/configPort.sh cleanmq				
		runCommandAsUser root:$TS_ADMIN_PASSWORD $TS_HOME/bin/configPort.sh mq $MQ_LSR_PORT		
        mqport=`grep mqm /etc/services | awk '{print($2)}' | ${AWK_SLASH} '{print($1)}'`
		if [ -n $mqport -a ! $mqport = "" ];then
			MQ_LSR_PORT=$mqport	
		fi
	else
		#######code to configure port on remote machine if this script is run there
		#getMessage TSIN02240I
		#echo $msg
		echo "un-configuring port"
		mqport=$MQ_LSR_PORT
		temp_services=/tmp/rfidic-configPort-svcs.tmp

		runCommandAsUser root:$TS_ADMIN_PASSWORD "sed '/mqm/d' /etc/services >| ${temp_services}"

		mv -f ${temp_services} /etc/services
		runCommandAsUser root:$TS_ADMIN_PASSWORD chmod 644 /etc/services

		#getMessage TSIN02241I
		#echo $msg
		echo "configuring port"
		while `grep -w $mqport/tcp /etc/services | grep -v '^#' | grep -v 'MQ' >/dev/null`
		do
			let mqport=mqport+1
		done
		if [ "$MQ_LSR_PORT" != "$mqport" ];then
			#getMessage TSIN02242E $MQ_LSR_PORT $mqport
			#echo $msg 
			echo "$MQ_LSR_PORT is already being used by other program, Use $mqport and create the configuration files again"
			exit 1
		else
			runCommandAsUser root:$TS_ADMIN_PASSWORD "echo  'mqm		$mqport/tcp			# MQ Series Port' >> /etc/services"

			#getMessage TSIN02243I $mqport
			#echo $msg
			echo  "mqm is configured at port: $mqport"
			MQ_LSR_PORT=$mqport
			export MQ_LSR_PORT
		fi
	fi
	if [ "$MQ_LOG_TYPE" = "LINEAR" ];then
   		runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD crtmqm -ll -lf ${MQ_LOG_FILE_PAGES} -lp ${MQ_LOG_PRIMARY_FILES} -ls ${MQ_LOG_SECONDARY_FILES} -q ${QUEUE_MANAGER}
   	else
		runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD crtmqm -lc -lf ${MQ_LOG_FILE_PAGES} -lp ${MQ_LOG_PRIMARY_FILES} -ls ${MQ_LOG_SECONDARY_FILES} -q ${QUEUE_MANAGER}
   	fi
    retcode=$?
    if [ ! "$retcode" = "0" ];then
        exit $retcode
    fi
	
	runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD strmqm ${QUEUE_MANAGER}
    retcode=$?
    if [ ! "$retcode" = "0" ];then
        exit $retcode
    fi
	
	if [ "$QUEUE_MANAGER_TYPE" = "FULL" ];then # configure full repository queue manager
        echo "ALTER QMGR REPOS($MQ_CLUSTER)" > /tmp/mq.cmd
        echo "ALTER QMGR DEADQ(SYSTEM.DEAD.LETTER.QUEUE)" >> /tmp/mq.cmd
        echo "DEFINE LISTENER(QMXITS01.TCP) TRPTYPE(TCP) CONTROL(QMGR) PORT(${MQ_LSR_PORT})" >> /tmp/mq.cmd
        echo "START LISTENER(QMXITS01.TCP)" >> /tmp/mq.cmd
        echo "DEFINE CHANNEL(TO.$QUEUE_MANAGER) CHLTYPE(CLUSRCVR) TRPTYPE(TCP) CONNAME($MQ_HOST) CLUSTER($MQ_CLUSTER) DESCR('TCP Cluster receiver channel for queue manager $QUEUE_MANAGER')" >> /tmp/mq.cmd
        echo "DEFINE CHANNEL(TO.$R_QUEUE_MANAGER) CHLTYPE(CLUSSDR) TRPTYPE(TCP) CONNAME('$R_MQ_HOST($R_MQ_LSR_PORT)') CLUSTER($MQ_CLUSTER) DESCR('TCP sender from $QUEUE_MANAGER to $R_QUEUE_MANAGER')" >> /tmp/mq.cmd
        runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD "runmqsc ${QUEUE_MANAGER} < /tmp/mq.cmd"
        retcode=$?
        rm -f /tmp/mq.cmd
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi

        echo "DEFINE QLOCAL ('${QUEUE_NAME}') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Input queue of the capture interface') SHARE REPLACE CLUSTER($MQ_CLUSTER)" > /tmp/mq.cmd
        echo "DEFINE QLOCAL ('$ALERTS_ENGINE_INPUT_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Input queue for alerts processing engine') SHARE REPLACE CLUSTER($MQ_CLUSTER)" >> /tmp/mq.cmd
        echo "DEFINE QLOCAL ('$MDM_CHANGE_NOTIF_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Output queue for Traceability Server MDM change notifications') SHARE REPLACE CLUSTER($MQ_CLUSTER)" >> /tmp/mq.cmd
        echo "DEFINE QLOCAL ('$AS2DELIVERY_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Delivery queue for AS2 subscription queries') SHARE REPLACE CLUSTER($MQ_CLUSTER)" >> /tmp/mq.cmd
        echo "DEFINE QLOCAL ('$AS2REQUEST_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Input queue for AS2 query requests') SHARE REPLACE CLUSTER($MQ_CLUSTER)" >> /tmp/mq.cmd
        echo "DEFINE QLOCAL ('$AS2RESPONSE_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Output queue for AS2 synchronous query results') SHARE REPLACE CLUSTER($MQ_CLUSTER)" >> /tmp/mq.cmd
        echo "DEFINE QLOCAL ('$CAPTURE_NOTIF_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Traceability Server capture notification queue') SHARE REPLACE CLUSTER($MQ_CLUSTER)" >> /tmp/mq.cmd
        echo "DEFINE CHANNEL('SYSTEM.ADMIN.SVRCONN') chltype(svrconn) TRPTYPE(TCP) mcauser('${MQ_USER}')" >> /tmp/mq.cmd
        echo "START CHANNEL('SYSTEM.ADMIN.SVRCONN')" >> /tmp/mq.cmd
        echo "DEFINE CHANNEL('$MQ_TS_CHANNEL') chltype(RCVR) TRPTYPE(TCP)" >> /tmp/mq.cmd
        echo "START CHANNEL('$MQ_TS_CHANNEL')" >> /tmp/mq.cmd
        runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD "runmqsc ${QUEUE_MANAGER} < /tmp/mq.cmd"
        retcode=$?
        rm -f /tmp/mq.cmd
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi

        #To enable publish/subscribe
        runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD "runmqsc ${QUEUE_MANAGER} < ${MQ_HOME}/java/bin/MQJMS_PSQ.mqsc"
        retcode=$?
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi

        echo "ALTER QMGR PSMODE(ENABLED)" > /tmp/mq.cmd
        echo "DISPLAY QMGR PSMODE" >> /tmp/mq.cmd
        echo "DISPLAY CLUSQMGR(*)" >> /tmp/mq.cmd
        echo "DISPLAY CHSTATUS(*)" >> /tmp/mq.cmd
        runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD "runmqsc ${QUEUE_MANAGER} < /tmp/mq.cmd"
        retcode=$?
        rm -f /tmp/mq.cmd
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi
	else	 # configure partial repository queue manager
        echo "DEFINE LISTENER(QMXITS01.TCP) TRPTYPE(TCP) CONTROL(QMGR) PORT(${MQ_LSR_PORT})" > /tmp/mq.cmd
        echo "START LISTENER(QMXITS01.TCP)" >> /tmp/mq.cmd
        echo "DEFINE CHANNEL(TO.$QUEUE_MANAGER) CHLTYPE(CLUSRCVR) TRPTYPE(TCP) CONNAME($MQ_HOST) CLUSTER($MQ_CLUSTER) DESCR('TCP Cluster receiver channel for queue manager $QUEUE_MANAGER')" >> /tmp/mq.cmd
        echo "DEFINE CHANNEL(TO.$R_QUEUE_MANAGER) CHLTYPE(CLUSSDR) TRPTYPE(TCP) CONNAME('$R_MQ_HOST($R_MQ_LSR_PORT)') CLUSTER($MQ_CLUSTER) DESCR('TCP sender from $QUEUE_MANAGER to $R_QUEUE_MANAGER')" >> /tmp/mq.cmd
        runCommandAsUser ${MQ_USER}:$TS_ADMIN_PASSWORD "runmqsc ${QUEUE_MANAGER} < /tmp/mq.cmd"
        retcode=$?
        rm -f /tmp/mq.cmd
        if [ ! "$retcode" = "0" ];then
            exit $retcode
        fi
	fi	

	if [ -n "$TS_HOME" -a -d "$TS_HOME" ];then   #it is local
		getMessage TSIN02248I
		echo $msg
		#echo "updating files"
		. $SCRIPT_DIR/updateEnv.sh -CONFIG_TYPE=MQ -MQ_HOST=$MQ_HOST -MQ_HOME=$MQ_HOME -QUEUE_MANAGER=$QUEUE_MANAGER -MQ_LOG_FILE_PAGES=$MQ_LOG_FILE_PAGES -MQ_LOG_TYPE=$MQ_LOG_TYPE -MQ_LOG_PRIMARY_FILES=$MQ_LOG_PRIMARY_FILES -MQ_LOG_SECONDARY_FILES=$MQ_LOG_SECONDARY_FILES -MQ_TS_CHANNEL=$MQ_TS_CHANNEL -QUEUE_NAME=$QUEUE_NAME -ALERTS_ENGINE_INPUT_QUEUE_NAME=$ALERTS_ENGINE_INPUT_QUEUE_NAME -MDM_CHANGE_NOTIF_QUEUE_NAME=$MDM_CHANGE_NOTIF_QUEUE_NAME -AS2DELIVERY_QUEUE_NAME=$AS2DELIVERY_QUEUE_NAME -AS2REQUEST_QUEUE_NAME=$AS2REQUEST_QUEUE_NAME -AS2RESPONSE_QUEUE_NAME=$AS2RESPONSE_QUEUE_NAME -CAPTURE_NOTIF_QUEUE_NAME=$CAPTURE_NOTIF_QUEUE_NAME -MQ_LSR_PORT=$MQ_LSR_PORT -MQ_USER=$MQ_USER -MQ_USER_PASSWORD=$MQ_USER_PASSWORD -RESULT=$RESULT -QUEUE_MANAGER_TYPE=$QUEUE_MANAGER_TYPE -MQ_CLUSTER=$MQ_CLUSTER -R_QUEUE_MANAGER=$R_QUEUE_MANAGER -R_MQ_HOST=$R_MQ_HOST -R_MQ_LSR_PORT=$R_MQ_LSR_PORT
	fi

fi
retCode=$?
if [ $retCode -eq 0 ];then
	echo "SUCCESS"
	if [ ! -z "$RESULT" ];then
		$ECHO "SUCCESS" >> $RESULT
	fi
fi
exit 0