#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
#
# 
# createPropFile.sh -  (DESIGNED FOR LAUNCHPAD) Copies scripts and property file to TS/mqconfig directory and updates property file with user input.
###############################################################################################################
sDir=`dirname ${0}`
. $sDir/utils.sh

ECHO="echo"

AWK="awk -F ".""
PLATFORM=`/bin/uname`
	case $PLATFORM in
	SunOS)
		AWK="awk -F."
		;;
	esac

asciiUpdate()
{
    # Takes an array of search and replace strings for a file, constructs the sed script and performs the update on the file
    index=0
    searchStr=$2
    replaceStr=$3
    count=${#searchStr[*]}
    command="{\n"
    while [ "$index" -lt "$count" ]
    do
        command=$command"s%"${searchStr[$index]}"%"${replaceStr[$index]}"%g\n"
        index=`expr $index + 1`
    done
    command=$command"}"
    $ECHO $command > $1.sed
    run_command sed -f $1.sed $1 > $1.tmp
    sedReturnCode=$?

    if [ $? -eq 0 ];then
        run_command mv -f $1.tmp $1
    else
        rm -f $1.tmp
    fi

    run_command rm -f $1.sed
    unset searchStr
    unset replaceStr

    return $sedReturnCode
}

run_command ()
{
	command="$*"
	"$@"
	retcode=$?
	if [ "$retcode" -ne 0 ]
	then	
		getMessage RFID05138E "$command"
        $ECHO $msg
		return $retcode
	fi
}

usage(){
	echo "	USAGE: ./createPropFile.sh"
	echo "                          [-TS_HOME=<TS_HOME value>]"
	echo "                          [-MQ_HOST=<value>]"
	echo "                          [-MQ_TS_CHANNEL=<value>]"
	echo "                          [-MQ_HOME=<Path where MQ is installed>]"
	echo "                          [-QUEUE_MANAGER=<queue manager name>]"
	echo "                          [-MQ_LOG_FILE_PAGES=<value>]"
	echo "                          [-MQ_LOG_TYPE=<value>]"
	echo "                          [-MQ_LOG_PRIMARY_FILES=<value>]"
	echo "                          [-MQ_LOG_SECONDARY_FILES=<value>]"
	echo "                          [-MQ_QUEUE_NAME=<value>]"
	echo "                          [-ALERTS_ENGINE_INPUT_QUEUE_NAME=<value>]"
	echo "                          [-MDM_CHANGE_NOTIF_QUEUE_NAME=<value>]"
	echo "                          [-AS2DELIVERY_QUEUE_NAME=<value>]"
	echo "                          [-AS2REQUEST_QUEUE_NAME=<value>]"
	echo "                          [-AS2RESPONSE_QUEUE_NAME=<value>]"
	echo "                          [-CAPTURE_NOTIF_QUEUE_NAME=<value>]"
	echo "                          [-MQ_LSR_PORT=<value of listener port>]"
	echo "                          [-MQ_USER=<value>]"
	echo "                          [-MQ_USER_PASSWORD=<value>]"
	echo "                          [-MQ_CLUSTER=<value>]"
	echo "                          [-R_MQ_HOST=<value of listener port>]"
	echo "                          [-R_QUEUE_MANAGER=<value>]"
	echo "                          [-QUEUE_MANAGER_TYPE=<value>]"

	return 1
}

updatePropFile()
{
	getMessage TSIN02259I
	echo $msg
	#echo "Updating the configureTS.properties file"
	
	searchStr[0]='MQ_HOME='
       searchStr[1]='QUEUE_MANAGER='
       searchStr[2]='MQ_LOG_FILE_PAGES='
       searchStr[3]='MQ_LOG_TYPE='
	searchStr[4]='MQ_LOG_PRIMARY_FILES='
       searchStr[5]='MQ_LOG_SECONDARY_FILES='
       searchStr[6]='QUEUE_NAME=.*'
	searchStr[7]='ALERTS_ENGINE_INPUT_QUEUE_NAME=.*'
	searchStr[8]='MDM_CHANGE_NOTIF_QUEUE_NAME=.*'
	searchStr[9]='AS2DELIVERY_QUEUE_NAME=.*'
	searchStr[10]='AS2REQUEST_QUEUE_NAME=.*'
	searchStr[11]='AS2RESPONSE_QUEUE_NAME=.*'
	searchStr[12]='CAPTURE_NOTIF_QUEUE_NAME=.*'
	searchStr[13]='MQ_LSR_PORT='
	searchStr[14]='MQ_USER='
	searchStr[15]='MQ_USER_PASSWORD='
	searchStr[16]='MQ_HOST='
	searchStr[17]='MQ_TS_CHANNEL='
	searchStr[18]='TS_HOME='

	if [ -n "$QUEUE_MANAGER_TYPE" ];then
		searchStr[19]='R_QUEUE_MANAGER=.*'
		searchStr[20]='R_MQ_HOST=.*'
		searchStr[21]='MQ_CLUSTER=.*'
		searchStr[22]='QUEUE_MANAGER_TYPE=.*'
		searchStr[23]='R_MQ_LSR_PORT=.*'
	fi
	
	replaceStr[0]="MQ_HOME=$MQ_HOME"
       replaceStr[1]="QUEUE_MANAGER=$QUEUE_MANAGER"
       replaceStr[2]="MQ_LOG_FILE_PAGES=$MQ_LOG_FILE_PAGES"
	replaceStr[3]="MQ_LOG_TYPE=$MQ_LOG_TYPE"
	replaceStr[4]="MQ_LOG_PRIMARY_FILES=$MQ_LOG_PRIMARY_FILES"
	replaceStr[5]="MQ_LOG_SECONDARY_FILES=$MQ_LOG_SECONDARY_FILES"
	replaceStr[6]="QUEUE_NAME=$QUEUE_NAME"
       replaceStr[7]="ALERTS_ENGINE_INPUT_QUEUE_NAME=$ALERTS_ENGINE_INPUT_QUEUE_NAME"
	replaceStr[8]="MDM_CHANGE_NOTIF_QUEUE_NAME=$MDM_CHANGE_NOTIF_QUEUE_NAME"
	replaceStr[9]="AS2DELIVERY_QUEUE_NAME=$AS2DELIVERY_QUEUE_NAME"
	replaceStr[10]="AS2REQUEST_QUEUE_NAME=$AS2REQUEST_QUEUE_NAME"
	replaceStr[11]="AS2RESPONSE_QUEUE_NAME=$AS2RESPONSE_QUEUE_NAME"
	replaceStr[12]="CAPTURE_NOTIF_QUEUE_NAME=$CAPTURE_NOTIF_QUEUE_NAME"
       replaceStr[13]="MQ_LSR_PORT=$MQ_LSR_PORT"
	replaceStr[14]="MQ_USER=$MQ_USER"
	replaceStr[15]="MQ_USER_PASSWORD=$MQ_USER_PASSWORD"
	replaceStr[16]="MQ_HOST=$MQ_HOST"
	replaceStr[17]="MQ_TS_CHANNEL=$MQ_TS_CHANNEL"
	replaceStr[18]="#TS_HOME=$TS_HOME"

	if [ -n "$QUEUE_MANAGER_TYPE" ];then
		replaceStr[19]="R_QUEUE_MANAGER=$R_QUEUE_MANAGER"
		replaceStr[20]="R_MQ_HOST=$R_MQ_HOST"
		replaceStr[21]="MQ_CLUSTER=$MQ_CLUSTER"
		replaceStr[22]="QUEUE_MANAGER_TYPE=$QUEUE_MANAGER_TYPE"
		replaceStr[23]="R_MQ_LSR_PORT=$R_MQ_LSR_PORT"
	fi
	
	asciiUpdate "${TS_HOME}/MQScripts/${DIR_NAME}/configureTS.properties" $searchStr $replaceStr
    $updateReturnCode=$?
    if [ $updateReturnCode -eq 0 ];then
        getMessage TSIN02260I
        echo $msg
        #echo "The configureTS.properties file has been updated"
    fi

    return $updateReturnCode
}

updateRFIDICFiles()
{
	. ${TS_HOME}/bin/tsEnv.sh

	getMessage TSIN02248I
	echo $msg
	#echo "updating files"
	
	if [ -n "$QUEUE_MANAGER_TYPE" ];then
	. $SCRIPT_DIR/updateEnv.sh -CONFIG_TYPE=MQ -MQ_HOST=$MQ_HOST -MQ_HOME=$MQ_HOME -QUEUE_MANAGER=$QUEUE_MANAGER -MQ_LOG_FILE_PAGES=$MQ_LOG_FILE_PAGES -MQ_LOG_TYPE=$MQ_LOG_TYPE -MQ_LOG_PRIMARY_FILES=$MQ_LOG_PRIMARY_FILES -MQ_LOG_SECONDARY_FILES=$MQ_LOG_SECONDARY_FILES -MQ_TS_CHANNEL=$MQ_TS_CHANNEL -QUEUE_NAME=$QUEUE_NAME -ALERTS_ENGINE_INPUT_QUEUE_NAME=$ALERTS_ENGINE_INPUT_QUEUE_NAME -MDM_CHANGE_NOTIF_QUEUE_NAME=$MDM_CHANGE_NOTIF_QUEUE_NAME -AS2DELIVERY_QUEUE_NAME=$AS2DELIVERY_QUEUE_NAME -AS2REQUEST_QUEUE_NAME=$AS2REQUEST_QUEUE_NAME -AS2RESPONSE_QUEUE_NAME=$AS2RESPONSE_QUEUE_NAME -CAPTURE_NOTIF_QUEUE_NAME=$CAPTURE_NOTIF_QUEUE_NAME -MQ_LSR_PORT=$MQ_LSR_PORT -MQ_USER=$MQ_USER -MQ_USER_PASSWORD=$MQ_USER_PASSWORD -RESULT=$RESULT -QUEUE_MANAGER_TYPE=$QUEUE_MANAGER_TYPE -MQ_CLUSTER=$MQ_CLUSTER -R_QUEUE_MANAGER=$R_QUEUE_MANAGER -R_MQ_HOST=$R_MQ_HOST -R_MQ_LSR_PORT=$R_MQ_LSR_PORT
	else
	. $SCRIPT_DIR/updateEnv.sh -CONFIG_TYPE=MQ -MQ_HOST=$MQ_HOST -MQ_HOME=$MQ_HOME -QUEUE_MANAGER=$QUEUE_MANAGER -MQ_LOG_FILE_PAGES=$MQ_LOG_FILE_PAGES -MQ_LOG_TYPE=$MQ_LOG_TYPE -MQ_LOG_PRIMARY_FILES=$MQ_LOG_PRIMARY_FILES -MQ_LOG_SECONDARY_FILES=$MQ_LOG_SECONDARY_FILES -MQ_TS_CHANNEL=$MQ_TS_CHANNEL -QUEUE_NAME=$QUEUE_NAME -ALERTS_ENGINE_INPUT_QUEUE_NAME=$ALERTS_ENGINE_INPUT_QUEUE_NAME -MDM_CHANGE_NOTIF_QUEUE_NAME=$MDM_CHANGE_NOTIF_QUEUE_NAME -AS2DELIVERY_QUEUE_NAME=$AS2DELIVERY_QUEUE_NAME -AS2REQUEST_QUEUE_NAME=$AS2REQUEST_QUEUE_NAME -AS2RESPONSE_QUEUE_NAME=$AS2RESPONSE_QUEUE_NAME -CAPTURE_NOTIF_QUEUE_NAME=$CAPTURE_NOTIF_QUEUE_NAME -MQ_LSR_PORT=$MQ_LSR_PORT -MQ_USER=$MQ_USER -MQ_USER_PASSWORD=$MQ_USER_PASSWORD -RESULT=$RESULT
	fi
}

for item in $@
do
	if [ `expr match "$item" '-TS_HOME='` != 0 ];then
             	TS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_HOST='` != 0 ];then
              MQ_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-MQ_HOME='` != 0 ];then
              MQ_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	
	elif [ `expr match "$item" '-TS_ADMIN_USER='` != 0 ];then
              TS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-TS_ADMIN_PASSWORD='` != 0 ];then
              TS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-QUEUE_MANAGER='` != 0 ];then
   	      	QUEUE_MANAGER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_TS_CHANNEL='` != 0 ];then
	      	MQ_TS_CHANNEL=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LOG_FILE_PAGES='` != 0 ];then
             	MQ_LOG_FILE_PAGES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LOG_TYPE='` != 0 ];then
              MQ_LOG_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-MQ_LOG_PRIMARY_FILES='` != 0 ];then
	       MQ_LOG_PRIMARY_FILES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LOG_SECONDARY_FILES='` != 0 ];then
          	MQ_LOG_SECONDARY_FILES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
     	elif [ `expr match "$item" '-QUEUE_NAME='` != 0 ];then
              QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-ALERTS_ENGINE_INPUT_QUEUE_NAME='` != 0 ];then
	       ALERTS_ENGINE_INPUT_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MDM_CHANGE_NOTIF_QUEUE_NAME='` != 0 ];then
         	MDM_CHANGE_NOTIF_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-AS2DELIVERY_QUEUE_NAME='` != 0 ];then
	       AS2DELIVERY_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-AS2REQUEST_QUEUE_NAME='` != 0 ];then
	       AS2REQUEST_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-AS2RESPONSE_QUEUE_NAME='` != 0 ];then
              AS2RESPONSE_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-CAPTURE_NOTIF_QUEUE_NAME='` != 0 ];then
	       CAPTURE_NOTIF_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LSR_PORT='` != 0 ];then
         	MQ_LSR_PORT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-MQ_USER='` != 0 ];then
	       MQ_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
      	elif [ `expr match "$item" '-MQ_USER_PASSWORD='` != 0 ];then
	       MQ_USER_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-RESULT='` != 0 ];then
            	RESULT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-SCRIPT_DIR='` != 0 ];then
            	SCRIPT_DIR=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-R_QUEUE_MANAGER='` != 0 ];then
	       R_QUEUE_MANAGER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-R_MQ_HOST='` != 0 ];then
	       R_MQ_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-R_MQ_LSR_PORT='` != 0 ];then
	       R_MQ_LSR_PORT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-QUEUE_MANAGER_TYPE='` != 0 ];then
	       QUEUE_MANAGER_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_CLUSTER='` != 0 ];then
	       MQ_CLUSTER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-help'` != 0 ];then
		usage 
		exit 1
	else
		getMessage TSIN02215I
		echo $msg
		#echo "Unidentified argument passed"
		usage 
		exit 1
    fi
done

#create a directory in TS_HOME and copy the silent mq-config files there
. ${TS_HOME}/bin/tsEnv.sh

if [ -n "$QUEUE_MANAGER_TYPE" ];then
	if [ "$QUEUE_MANAGER_TYPE" = "PARTIAL" ];then
		DIR_NAME="${MQ_HOST}"_P
	else
		DIR_NAME="${MQ_HOST}"_F
	fi
else
	DIR_NAME=${MQ_HOST}
fi
echo "storing files in $DIR_NAME"

if [ -d "${TS_HOME}/MQScripts/${DIR_NAME}" ];then
	rm -rf ${TS_HOME}/MQScripts/${DIR_NAME}
fi
run_command mkdir -p ${TS_HOME}/MQScripts/${DIR_NAME}
if [ -n "$QUEUE_MANAGER_TYPE" ];then
	cp ${SCRIPT_DIR}/configureMQHA.sh ${TS_HOME}/MQScripts/${DIR_NAME}/configureMQHA.sh
else
	cp ${SCRIPT_DIR}/configureMQ.sh ${TS_HOME}/MQScripts/${DIR_NAME}/configureMQ.sh
fi
cp ${SCRIPT_DIR}/configureTS.properties ${TS_HOME}/MQScripts/${DIR_NAME}/configureTS.properties
cp ${SCRIPT_DIR}/utils.sh ${TS_HOME}/MQScripts/${DIR_NAME}/utils.sh

#update the property file ${TS_HOME}/MQScripts/configureTS.properties with user values

updatePropFile
propFileCode=$?
updateRFIDICFiles
retCode=$?
if [ $retCode -eq 0 -a $propFileCode -eq 0 ];then
	echo "SUCCESS"
	if [ ! -z "$RESULT" ];then
		$ECHO "SUCCESS" >> $RESULT
	fi
fi
exit 0
