#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title:       exportTSAR.sh
##   Description: Utility to export Traceability Server artifacts to a TSAR file
##   Usage:       exportTSAR.sh  -file <TSAR_file> 
##
#############################################################################

SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
        . ${RFIDIC_HOME}/bin/tsEnv.sh
        . ${RFIDIC_HOME}/bin/utils.sh
else
        . ${SCRIPT_DIR}/tsEnv.sh
        . ${SCRIPT_DIR}/utils.sh
fi

checkLogs
appendClassPathWithWASJars

#Change SSL settings in tsEnv.sh file under the sslWASSettings function
SSL_SETTINGS=`sslWASSettings`

ALL_RFIDIC_DEFINES="-DRFIDIC_HOME=${RFIDIC_HOME} -DTS_HOME=${RFIDIC_HOME} $RFIDIC_MEDIUM_JAVA_HEAP $SSL_SETTINGS"

# Verifying 
java -classpath $CLASSPATH ${ALL_RFIDIC_DEFINES} com.ibm.ts.deployment.DeployCommand -export -verify $@
RET_CODE=$?

# Display usage if arguments are incorrect
if [ $RET_CODE -eq "14" ];then
  echo
  tsGetMessage.sh -noid RFID05264I
  echo
  exit 1
fi

# Display message if system is invalid 
if [ $RET_CODE -eq "12" ];then
  tsGetMessage.sh -noid RFID97077I
  promptUserYesNo
  if [ "$?" -eq "$NO" ];then
    echo
    tsGetMessage.sh -noid RFID97078I
    echo
    exit 1
  fi
fi

# Export the artifacts
echo
echo "-------- Exporting TS artifacts --------"
java -classpath $CLASSPATH ${ALL_RFIDIC_DEFINES} com.ibm.ts.deployment.DeployCommand -export $@
RET_CODE=$?

# If 0 'success' or 99 'success with warnings' then print a 
# message saying script completed successfully. The Java 
# code takes care of displaying export error messages. 
if [ $RET_CODE -eq "0" -o $RET_CODE -eq "99" ];then 
  echo
  tsGetMessage.sh -noid RFID97079I
  echo
fi

exit $RET_CODE
