#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
import sys
import os
import string
import codecs

from java import io;
from org.xml.sax.helpers import DefaultHandler
from javax.xml.parsers import SAXParserFactory
from javax.xml.parsers import ParserConfigurationException
from javax.xml.parsers import SAXParser

#Add TS jython scripts to jython's import path
def updatePath(p):
    sys.path.append(p)

updatePath(sys.argv[1])

#Now that the rfidic jython directory is on the path, import our modules
import rfidicCfgUtils
import recreateObjectCache


# Java SAX handler to find the entity names in the metadata files
class EntityNameHandler(DefaultHandler):

    def __init__ (self):
        self.inEntity=0
        self.inName=0
        self.entityNames=[]

    def startElement(self, uri, name, qName, attrs):
        if qName == 'Entity' or qName.endswith(':Entity'):
            self.inEntity=1
        if qName == 'Name' or qName.endswith(':Name'):
            self.inName=1

    def endElement(self, uri, name, qName):
        if qName == 'Entity' or qName.endswith(':Entity'):
            self.inEntity=0
        if qName == 'Name' or qName.endswith(':Name'):
            self.inName=0

    def characters(self, buffer, offset, length):
        content = java.lang.String(buffer, offset, length);
        if self.inEntity == 1 and self.inName == 1:
            if content.toLowerCase() not in self.entityNames:
                self.entityNames.append(content.toLowerCase())

# Gets the current scope
def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/CacheProvider:/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/CacheProvider:/'

    return ret

# Returns all of the current object caches
def getObjectCaches(p):
    return AdminConfig.list('CacheInstance', AdminConfig.getid(getScope(p)))

# Parses and returns a list of the JNDI names from the object caches
def getCacheJNDINames(caches):
    cacheList = AdminUtilities.convertToList(caches)
    jndiNames = []
    for cache in cacheList:
        jndiNames.append(AdminConfig.showAttribute(cache, 'jndiName'))

    return jndiNames


# Returns a list of all the entity names found in the metadata file
def getEntityNames(fileName):
    entityHandler = EntityNameHandler(); 
    factory = SAXParserFactory.newInstance();
    out = java.io.OutputStreamWriter(java.lang.System.out, "UTF8"); 
    saxParser = factory.newSAXParser();
    saxParser.parse( java.io.File(fileName), entityHandler ); 
    return entityHandler.entityNames


properties=rfidicCfgUtils.getProperties(sys.argv[0])
jndiNames = getCacheJNDINames(getObjectCaches(properties))

# Get the list of all metadata files loaded into the system
metadataDir=properties.get("TS_HOME")+"/tsar/tscontent/metadata"
files = os.listdir(metadataDir)

# Loop through the metadata files getting the entity names. Then loop through the entity 
# names and if the name doesn't exist in the current list of object caches, create it.
for fileName in files:
    entityNames = getEntityNames(metadataDir+"/"+fileName)
    for entityName in entityNames:
        cacheName = "ts/cache/"+entityName
        if cacheName not in jndiNames:
            recreateObjectCache.createCache( properties, entityName+' cache', 
                                    'User defined Vocabulary.', cacheName, 
                                    '2000', '1', 'RFIDICObjectCacheDomain' )
            jndiNames.append(cacheName)


AdminConfig.save()
