#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
import sys

from java.io import FileInputStream
from java.util import Properties
from jarray import array
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
from com.ibm.rfidic.utils.install import ReadMappedUserGroups

#Add TS jython scripts to jython's import path
def updatePath(p):
    sys.path.append(p)

updatePath(sys.argv[1])

#Now that the rfidic jython directory is on the path, import our modules
import rfidicCfgUtils
import createSchedTables
import resetVariables
import recreateDatasource
import recreateMQQCF
import recreateMQQ
import createTopicConfig
import recreateListener
import recreateWMQAS
import recreateObjectCache
import setLibrary
import reinstallApplication
import recreateAuditConfig
import recreateWorkManager
import recreateScheduler
import updateWSClientBindings
import addUsrOrGrpToSecurityRole
import setupInProcessWS

properties=rfidicCfgUtils.getProperties(sys.argv[0])
servers=rfidicCfgUtils.findServers(properties)
if ( len(sys.argv) > 2 ):
    clusterProperties=rfidicCfgUtils.getProperties(sys.argv[2])
    mqQueueManagers=rfidicCfgUtils.getQueueManagersFromProperties(clusterProperties)
    
    mqCluster=properties.get("MQ_CLUSTER")
    if ( mqCluster!=None and mqCluster!="" ):
        if ( len(servers) != len(mqQueueManagers) ):
            print "The number of queue managers defined does not match the number of WAS nodes in the cluster."
else:
    mqQueueManagers=[ [properties.get("MQ_HOST"),properties.get("QUEUE_MANAGER"),properties.get("MQ_LSR_PORT"),properties.get("MQ_HOME"),properties.get("MQ_USER"),properties.get("MQ_USER_PASSWORD")] ]

#Loop through both the WAS nodes and the MQ queue managers, setting a queue manager to each WAS node. 
#If we run out of queue managers, reset back to the first queue manager in the list and keep running.
c=0
for server in servers:
    server.append(mqQueueManagers[c])
    c+=1
    if (c >= len(mqQueueManagers)):
        c=0


#In the single server case the shell script already started the app server
if( properties.get("ISCLUSTER")=='true' ):
    rfidicCfgUtils.startServers(servers)


if( properties.get("MEMBERONLY")=='false' ):
    if( properties.get("CONFIG_OPTION")=='unconfigure' ):
        createSchedTables.run(properties, servers, 'RFIDICStandingQueryScheduler')
        createSchedTables.run(properties, servers, 'MDMCacheRefreshScheduler')
        createSchedTables.run(properties, servers, 'SerialIdScheduler')

if( properties.get("WAS_LOCAL_WS")=='true' ):
    setupInProcessWS.run(properties, servers)
resetVariables.run(properties, servers)

print "Saving..."
AdminConfig.save()

if( properties.get("MEMBERONLY")=='false' ):
    dbType=properties.get("DB_TYPE")
    if(dbType=="ORACLE"):
#        recreateDatasource.run(properties, 'true',
#                               'RFIDIC Oracle JDBC Provider',
#                               'Provider for RFIDIC data', "false",
#                               "Oracle Data Source", "Oracle database settings",
#                               "jdbc/rfidic/ifx" )
        recreateDatasource.run(properties, 'true',
                               'TS Scheduler JDBC Provider',
                               'Provider for Scheduler  data', "true",
                               "Scheduler Data Source",
                               "Scheduler database settings",
                               "jdbc/ts/schedulerDS" )

#        recreateDatasource.run(properties, 'false',
#                               'RFIDIC Oracle JDBC XA Provider',
#                               'Provider for RFIDIC data', "true",
#                               "rfidicXA", "Oracle database settings",
#                               "jdbc/rfidic/ifxXA" )
        recreateDatasource.run(properties, 'true',
                               'Traceability Server Oracle JDBC Provider',
                               'Provider for the Traceability Server repository',
                               "true", "traceabiltyDS", "Oracle Database settings",
                               "jdbc/ts/tsDS" )
    elif(dbType=="DB2"):
#        recreateDatasource.run(properties, 'true', 'RFIDIC DB2 JDBC Provider',
#                               'Provider for RFIDIC data', "false",
#                               "DB2 Data Source", "DB2 Database settings",
#                               "jdbc/rfidic/ifx" )
        recreateDatasource.run(properties, 'true',
                               'TS Scheduler JDBC Provider',
                               'Provider for Scheduler  data', "true",
                               "Scheduler Data Source",
                               "Scheduler database settings",
                               "jdbc/ts/schedulerDS" )

#        recreateDatasource.run(properties, 'false', 'RFIDIC DB2 JDBC XA Provider',
#                               'Provider for RFIDIC data', "true",
#                               "rfidicXA", "DB2 Database settings",
#                               "jdbc/rfidic/ifxXA" )
        recreateDatasource.run(properties, 'false',
                               'Traceability Server DB2 JDBC Provide',
                               'Provider for the Traceability Server repository',
                               "true", "traceabiltyDS", "DB2 Database settings",
                               "jdbc/ts/tsDS" )
#    if( properties.get("CONFIG_OPTION")=='configure'):
#        recreateDatasource.reload(properties, servers)
                
if( properties.get("MEMBERONLY")=='false' ):
    recreateMQQCF.run(properties, servers, 'true', 'RFIDICMQAlias', 'tsMQConnFactory',
                      "Traceability Server Capture-- JMS Binding",
                      "jms/ts/MQConnectionFactory", 'true')
    recreateMQQCF.run(properties, servers, 'false', 'RFIDICMQAlias', 'rfidicConnFac',
                      "RFIDIC XA QueueConnectionFactory",
                      "jms/rfidicQConnFac", 'true')
    recreateMQQCF.run(properties, servers, 'false', 'RFIDICMQAlias', 'rfidicQCF',
                      "RFIDIC Queue Connection Factory",
                      "jms/rfidicQCF", 'true')
    #From recreateAS2MQ
    recreateMQQCF.run(properties, servers, 'true', 'RFIDICAS2MQAlias',
                      'AS2 Queue Connection Factory',
                      "AS2 Queue Connection Factory for RFIDIC",
                      "jms/ts/AS2QCF", 'true')
    
    recreateMQQ.run( properties, servers, 'tsMQDest',
                     'Traceability Server Capture -- JMS Binding', 'jms/ts/MQDest',
                     properties.get("QUEUE_NAME") )
    recreateMQQ.run( properties, servers, 'tsPRTQueueDest',
                     'Traceability Server Capture -- PendingRecordTime Destination Queue', 'jms/ts/PRTNotification',
                     properties.get("CAPTURE_NOTIF_QUEUE_NAME") )
    recreateMQQ.run( properties, servers, 'rfidicAlertsInputMQDest',
                     'Input Queue for RFIDIC Alerts processing engine',
                     'jms/ts/alertsInputQueue',
                     properties.get("ALERTS_ENGINE_INPUT_QUEUE_NAME") )
    #From recreateAS2MQ
    recreateMQQ.run( properties, servers, 'AS2Delivery queue',
                     'AS2 Queue for delivery of subscription results',
                     'jms/ts/AS2Delivery',
                     properties.get("AS2DELIVERY_QUEUE_NAME") )
    recreateMQQ.run( properties, servers, 'AS2 Request queue',
                     'AS2 Queue for generic EPCIS requests',
                     'jms/ts/AS2Request',
                     properties.get("AS2REQUEST_QUEUE_NAME") )
    recreateMQQ.run( properties, servers, 'AS2 Response queue',
                     'AS2 Queue for generic EPCIS responses',
                     'jms/ts/AS2Response',
                     properties.get("AS2RESPONSE_QUEUE_NAME") )
    ###

    createTopicConfig.run( properties, servers, 'jms/ibm/epcis/TCF', 'RFIDICMQTCF',
                           'Topic connection factory for MDM change notification',
                           'RFIDICMQAdminTopic',
                           'jms/ibm/epcis/mdm/changeNotification' )


#XXX -- remove listener ports when EARs use activation specs
#XXX -- this listener refers to a queue that we don't create
#recreateListener.run( properties, servers, 'jms/rfidicMQDest',
#                      'rfidicMQListener', 'jms/rfidicQConnFac', 'STOP' )
#recreateListener.run( properties, servers, 'jms/rfidicAlertsInputMQDest',
#                      'rfidicAlertsMQListener', 'jms/rfidicQCF', 'START' )
##From recreateAS2MQ
#recreateListener.run( properties, servers, 'jms/ibm/rfidic/AS2/request/queue',
#                      'rfidicAS2MQListener',
#                      'jms/ibm/rfidic/AS2/QCF', 'START' )
#XXX -- end remove listener ports



if( properties.get("MEMBERONLY")=='false' ):
    #AS note: the auth aliases (arg 3) are created earlier with the QCFs
    recreateWMQAS.run( properties, servers, 'false', 'RFIDICMQAlias',
                       'tsCaptureActivation',
                       'Traceability Server Capture -- Main MQ Activation Spec',
                       'jms/ts/JMSActivation', 'jms/ts/MQDest' )
    #XXX -- from the listener rfidicMQListener -- queue isn't created
    # TS Capture -- JMS Binding Activation Spec
    recreateWMQAS.run( properties, servers, 'false', 'RFIDICMQAlias',
                       'tsCapturePRT',
                       'Traceability Server Capture -- MQ Activation Spec for Pending Record Time',
                       'jms/ts/PRTActivation', 'jms/ts/PRTNotification' )
    recreateWMQAS.run( properties, servers, 'false', 'RFIDICMQAlias',
                       'rfidicMQActivation',
                       'RFIDIC Something',
                       'jms/rfidicMQActivation', 'jms/jms/rfidicMQDest' )
    recreateWMQAS.run( properties, servers, 'false', 'RFIDICMQAlias',
                       'rfidicAlertsMQActivation',
                       'AS for input queue for Traceability Server alerts processing engine',
                       'jms/ts/alertsActivation',
                       'jms/ts/alertsInputQueue' )
    recreateWMQAS.run( properties, servers, 'false', 'RFIDICMQAlias',
                       'rfidicCaptureNotificationActivation',
                       'AS for queue for Traceability Server capture notification',
                       'jms/rfidic/CaptureActivation',
                       'jms/rfidic/CaptureNotification' )
    recreateWMQAS.run( properties, servers, 'false', 'RFIDICAS2MQAlias',
                       'tsAS2MQActivation',
                       'AS for AS2 Queue for generic EPCIS requests',
                       'jms/ts/AS2Activation',
                       'jms/ts/AS2Request' )

#    recreateObjectCache.run( properties, 'true', 'RFIDICObjectCacheDomain',
#                             properties.get("SNM_CACHE_NAME"),
#                             'Object cache instance fom SNM objects.',
#                             properties.get("SNM_CACHE_JNDI"),
#                             properties.get("SNM_CACHE_SIZE"),
#                             properties.get("SNM_CACHE_PRIORITY") )
    recreateObjectCache.run( properties, 'true', 'RFIDICObjectCacheDomain',
                             'Hierarchy Cache', 'User defined Vocabulary.',
                             'ts/mdm/hierarchies', '2000', '1' )
    recreateObjectCache.run( properties, 'true', 'RFIDICObjectCacheDomain',
                             'Set Cache', 'User defined Vocabulary.',
                             'ts/mdm/sets', '2000', '1' )
    recreateObjectCache.run( properties, 'true', 'RFIDICObjectCacheDomain',
                             'Vocabulary Cache', 'User defined Vocabulary.',
                             'ts/mdm/vocabularies', '2000', '1' )
    recreateObjectCache.run( properties, 'true', 'RFIDICObjectCacheDomain',
                             'Vocabulary Element Cache', 'User defined Vocabulary.',
                             'ts/cache/vocab_elements', '2000', '1' )
    recreateObjectCache.run( properties, 'false', 'RFIDICObjectCacheDomain',
                             'Product Cache', 'Product Vocabulary.',
                             'ts/cache/product', '2000', '1' )
    recreateObjectCache.run( properties, 'false', 'RFIDICObjectCacheDomain',
                             'Location Cache', 'Location Vocabulary.',
                             'ts/cache/location', '2000', '1' )
    recreateObjectCache.run( properties, 'false', 'RFIDICObjectCacheDomain',
                             'Partner Cache', 'Partner Vocabulary.',
                             'ts/cache/partner', '2000', '1' )
    recreateObjectCache.run( properties, 'false', 'RFIDICObjectCacheDomain',
                             'EventSource Cache', 'Partner Vocabulary.',
                             'ts/cache/sourceid', '2000', '1' )                             
    recreateObjectCache.run( properties, 'false', 'RFIDICObjectCacheDomain',
                             'ClassLoader Registry Cache', 'ClassLoader Registry.',
                             'ts/cache/classloader', '2000', '1' )
    recreateObjectCache.run( properties, 'false', 'RFIDICObjectCacheDomain',
                             'SNM Resource Cache',
                             'Object cache instance fom SNM Resource objects.',
                             'ts/cache/snm_resource', '1000', '1' )
    recreateObjectCache.run( properties, 'false', 'RFIDICObjectCacheDomain',
                             'SNM Rule Cache',
                             'Object cache instance fom SNM Rule objects.',
                             'ts/cache/snm_rule', '2000', '1' )

    recreateAuditConfig.run(properties)


    recreateWorkManager.run( properties, 'CaptureRetryWorkManager', 'wm/captureRetry' )
    

print "Saving..."
AdminConfig.save()

if( properties.get("ISCLUSTER")=='true' ):
    rfidicCfgUtils.syncNodes(servers)

#In the single server case, the shell script recycles the server
#No need to restart here for an unconfigure
if( properties.get("CONFIG_OPTION")!='unconfigure'):
    if( properties.get("ISCLUSTER")=='true' ):
        rfidicCfgUtils.stopServers(servers)
        rfidicCfgUtils.startServers(servers)
