#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities
import AdminJDBC

#remove the auth alias
def removeAlias(p):
    aName=p.get("DBMS_ALIAS")
    authEntries=AdminConfig.list('JAASAuthData')
    authEntryList=AdminUtilities.convertToList(authEntries)
    for authEntry in authEntryList:
        thisName=AdminConfig.showAttribute(authEntry, "alias")
        if( thisName == aName ):
            msg=RFIDICGetMessage.getMessage('RFID07066I', aName)
            print msg.getMessage()
            AdminConfig.remove(authEntry)
            return
        
    msg=RFIDICGetMessage.getMessage('RFID07017E', aName)
    print msg.getMessage()

#create the auth alias
def createAlias(p):
    aName=p.get("DBMS_ALIAS")
    uName=p.get("DBMS_ADMIN_USER")
    uPass=p.get("DBMS_ADMIN_PASSWORD")
    msg=RFIDICGetMessage.getMessage('RFID07067I', aName)
    print msg.getMessage()
    cell = AdminConfig.list("Cell")
    cellName = AdminConfig.showAttribute(cell, "name")
    sec = AdminConfig.getid("/Cell:"+cellName+"/Security:/")
    attrs = [["alias", aName], ["userId", uName], ["password", uPass],
             ["description", "Database alias"]]
    AdminConfig.create( "JAASAuthData", sec, attrs )
    msg=RFIDICGetMessage.getMessage('RFID07068I', aName)
    print msg.getMessage()

#find the jdbc provider template
def getTemplate(p):
    type=p.get("DB_TYPE")
    tstr=''
    if( type=="DB2" ):
        tstr='DB2 Universal JDBC Driver Provider Only (XA)'
    elif( type=="ORACLE" ):
        tstr='Oracle JDBC Driver Provider Only'

    tstr=AdminConfig.listTemplates('JDBCProvider', tstr)
    tlist=AdminUtilities.convertToList(tstr)

    msg=RFIDICGetMessage.getMessage('RFID07076I', tlist[0])
    print msg.getMessage()
    
    return tlist[0]

#get the impl class
def getImplClass(p,xa):
    type=p.get("DB_TYPE")
    ret=''
    if( type=="DB2" ):
        if(xa=="true"):
            ret='com.ibm.db2.jcc.DB2XADataSource'
        else:
            ret='com.ibm.db2.jcc.DB2ConnectionPoolDataSource'
    elif( type=="ORACLE" ):
        if(xa=="true"):
            ret='oracle.jdbc.xa.client.OracleXADataSource'
        else:
            ret='oracle.jdbc.pool.OracleConnectionPoolDataSource'

    return ret

#get the scope
def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'

    return ret

#create the jdbc provider
def createJDBCProvider( p, jdbcProv, jdbcDesc, xaFlag ):
    msg=RFIDICGetMessage.getMessage('RFID07073I', jdbcProv)
    print msg.getMessage()
    
    template=getTemplate(p)
    implClass=getImplClass(p,xaFlag)
    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    attrs=[['description', jdbcDesc], ['name', jdbcProv],
           ["implementationClassName", implClass]]

    msg=RFIDICGetMessage.getMessage('RFID07077I', jdbcProv)
    print msg.getMessage()
    
    provider=AdminConfig.createUsingTemplate("JDBCProvider", scopeObj, attrs, template )
    
    msg=RFIDICGetMessage.getMessage('RFID07078I', jdbcProv)
    print msg.getMessage()

    return provider

#find the existing jdbc provider
def findJDBCProvider(p,provName):
    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    jdbcProvs=AdminConfig.list('JDBCProvider', scopeObj)
    jdbcProvList=AdminUtilities.convertToList(jdbcProvs)

    for thisProv in jdbcProvList:
        thisName=AdminConfig.showAttribute(thisProv, 'name')
        if( thisName==provName ):
            return thisProv

    msg=RFIDICGetMessage.getMessage('RFID07072I', provName)
    print msg.getMessage()
    
    return ''

#remove the jdbc provider
def removeJDBCProvider(p,jdbcProv):
    provObj=findJDBCProvider(p,jdbcProv)
    if( provObj=='' ):
        return
    AdminConfig.remove(provObj)
    msg=RFIDICGetMessage.getMessage('RFID07071I')
    print msg.getMessage()

#get the datastore helper class
def getDsHelper(p):
    type=p.get("DB_TYPE")
    helper=''
    if( type=="DB2" ):
        helper='com.ibm.websphere.rsadapter.DB2UniversalDataStoreHelper'
    elif( type=="ORACLE" ):
        oracleVers=p.get("oraVersion")
        if( oracleVers=="11g" ):
            helper='com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper'
        else:
            helper='com.ibm.websphere.rsadapter.Oracle10gDataStoreHelper'
        
    return helper

#build the config properties string for the datasource
def getConfigProps(p):
    dbType=p.get("DB_TYPE")
    dbPref=dbType
    out='[ '
    if( dbType=="ORACLE" ):
        out=out+'[URL java.lang.String '+p.get("JDBC_URL")+'] '
    elif( dbType=="DB2"):
        out=out+'[databaseName java.lang.String '+p.get("DBMS_DB_NAME")+'] '
        out=out+'[portNumber java.lang.Integer '+p.get("DBMS_PORT_NUMBER")+'] '
        out=out+'[serverName java.lang.String '+p.get("DBMS_HOST")+'] '
        out=out+'[driverType java.lang.Integer 4] '

    out=out+']'
    return out

def createDataSource(p, provider, dsName, dsDesc, jndi):
    dsHelper=getDsHelper(p)
    configProps=getConfigProps(p)
    args=[ '-name', dsName, '-jndiName', jndi, '-dataStoreHelperClassName',
           dsHelper, '-componentManagedAuthenticationAlias',
           p.get("DBMS_ALIAS"), '-description', dsDesc,
           '-configureResourceProperties', configProps]
    dsId=AdminTask.createDatasource( provider, args )
    msg=RFIDICGetMessage.getMessage('RFID07082I', dsName, dsId)
    print msg.getMessage()    

def removeDataSource(p, provName, dsName):
    scope=getScope(p)
    dsScope=scope+'JDBCProvider:'+provName+'/DataSource:'+dsName+'/'
    dsObj=AdminConfig.getid(dsScope)
    if( dsObj != '' ):
        AdminConfig.remove(dsObj)
        msg=RFIDICGetMessage.getMessage('RFID07080I', provName, dsName)
        print msg.getMessage()
    else:
        msg=RFIDICGetMessage.getMessage('RFID07081I', provName, dsName)
        print msg.getMessage()

def reload(p, servers):
    print "Saving..."
    AdminConfig.save()
    for server in servers:
        dshs=AdminControl.queryNames('WebSphere:type=DataSourceCfgHelper,node='+server[0]+',process='+server[1]+',*')
        dshList=AdminUtilities.convertToList(dshs)
        if( len(dshList) > 0 ):
            dsh=dshList[0]
            print 'Reloading datasource cfg for '+server[1]+' on node '+server[0]
            AdminControl.invoke(dsh, 'reload')
        else:
            print 'No DataSourceCfgHelper for '+server[1]+' on node '+server[0]
            
def run(p, doAlias, jdbcProv, jdbcDesc, xaFlag, dsName, dsDesc, dsJndi):
    dbType=p.get("DB_TYPE")
    if( doAlias=="true" ):
        removeAlias(p)
    removeDataSource(p, jdbcProv, dsName)
    removeJDBCProvider(p,jdbcProv)
    
    if( p.get("CONFIG_OPTION")=="configure" ):
        if( doAlias=="true" ):
            createAlias(p)
        provider=createJDBCProvider(p, jdbcProv, jdbcDesc, xaFlag)
#        if( dbType=='DB2' ):
#            removeDataSource( p, jdbcProv,
#                              'DB2 Universal JDBC Driver XA DataSource' )
        createDataSource(p, provider, dsName, dsDesc, dsJndi)
