#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

def getServerId( p, server ):
    sid=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/Server:'+server[1])
    return sid

#get the scope
def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'

    return ret

def getArgs( p, Qname, Qdesc, Qjndi, Qmqname, Qmqqm ):
    args=[]
    args=args+['-name', Qname]
    args=args+['-jndiName', Qjndi]
    args=args+['-description', Qdesc]
    args=args+['-queueName', Qmqname]
    args=args+['-qmgr', Qmqqm]

    return args

def removeMQQOnServer( p, server, Qjndi ):
    msg=RFIDICGetMessage.getMessage('RFID07108I', Qjndi)
    print msg.getMessage()

    sid=getServerId(p, server)
    qObjs=AdminConfig.list('MQQueue', sid)
    qList=AdminUtilities.convertToList(qObjs)
    for q in qList:
        jndi=AdminConfig.showAttribute(q, "jndiName")
        if( Qjndi==jndi ):
            AdminTask.deleteWMQQueue(q)
            msg=RFIDICGetMessage.getMessage('RFID07109I', Qjndi)
            print msg.getMessage()
            return

def removeMQQ( p, servers, Qjndi ):
    for server in servers:
        removeMQQOnServer( p, server, Qjndi )

def createMQQOnServer( p, server, Qname, Qdesc, Qjndi, Qmqname ):
    msg=RFIDICGetMessage.getMessage('RFID07110I', Qjndi)
    print msg.getMessage()

    sid=getServerId(p, server)
    Qmqqm=server[2][1]
    args=getArgs( p, Qname, Qdesc, Qjndi, Qmqname, Qmqqm )
    AdminTask.createWMQQueue( sid, args )

    msg=RFIDICGetMessage.getMessage('RFID07112I', Qjndi)
    print msg.getMessage()
    
def createMQQ( p, servers, Qname, Qdesc, Qjndi, Qmqname ):
    for server in servers:
        createMQQOnServer( p, server, Qname, Qdesc, Qjndi, Qmqname )
    
def run( p, servers, Qname, Qdesc, Qjndi, Qmqname ):
    removeMQQ( p, servers, Qjndi )
    
    if( p.get("CONFIG_OPTION")=="configure" ):
        createMQQ( p, servers, Qname, Qdesc, Qjndi, Qmqname )
