#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

#get the scope
def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/CacheProvider:/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/CacheProvider:/'

    return ret

def createReplicationDomain(p,domainName):
    #XXX - bundle
    print "Creating Replication Domain: "+domainName
    cell=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/')
    theDomain=AdminConfig.create('DataReplicationDomain', cell,
                                 [['name', domainName]])
    AdminConfig.create('DataReplication', theDomain,
                       [['numberOfReplicas', '-1'],
                        ['encryptionType', 'NONE'],
                        ['requestTimeout', '5']])
    #XXX - bundle
    print "Created Replication Domain: "+domainName
    
def deleteReplicationDomain(p,domainName):
    #XXX - bundle
    print "Deleting Replication Domain: "+domainName
    theDomain=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+
                                '/DataReplicationDomain:'+domainName+'/')
    if( theDomain != '' ):
        AdminConfig.remove(theDomain)
        #XXX - bundle
        print "Deleted Replication Domain: "+domainName
        return

    #XXX - bundle
    print "Did not find Replication Domain: "+domainName

def getArgs(p, cName, cDesc, cJndi, size, priority):
    args=[]
    args=args+[['name', cName]]
    args=args+[['jndiName', cJndi]]
    args=args+[['description', cDesc]]
    args=args+[['cacheSize', size]]
    args=args+[['defaultPriority', priority]]
    if( p.get("ISCLUSTER")=='true' ):
        args=args+[['enableCacheReplication', 'false']]
        args=args+[['replicationType', 'PUSH_PULL']]
        args=args+[['pushFrequency', '1']]

    return args

def createCache( p, cName, cDesc, cJndi, size, priority, domainName ):
    msg=RFIDICGetMessage.getMessage('RFID07171I', cJndi)
    print msg.getMessage()

    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    args=getArgs( p, cName, cDesc, cJndi, size, priority )
    theCache=AdminConfig.create( 'ObjectCacheInstance', scopeObj, args )

    if( p.get("ISCLUSTER")=='true' ):
        theDRS=AdminConfig.create('DRSSettings', theCache,
                                  [['messageBrokerDomainName', domainName]])

    msg=RFIDICGetMessage.getMessage('RFID07173I', cJndi)
    print msg.getMessage()

def deleteCache( p, cJndi ):
    msg=RFIDICGetMessage.getMessage('RFID07172I', cJndi)
    print msg.getMessage()
    
    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    ciObjs=AdminConfig.list('ObjectCacheInstance', scopeObj)
    ciList=AdminUtilities.convertToList(ciObjs)
    for ci in ciList:
        jndi=AdminConfig.showAttribute(ci, 'jndiName')
        if( jndi==cJndi ):
            msg=RFIDICGetMessage.getMessage('RFID07174I', cJndi)
            print msg.getMessage()
            AdminConfig.remove(ci)
            return
    
def run( p, doDomain, domainName, cName, cDesc, cJndi, size, priority ):
    if( doDomain=='true' ):
        if( p.get("ISCLUSTER")=='true' ):
            deleteReplicationDomain(p,domainName)
    deleteCache( p, cJndi )
    if( p.get("CONFIG_OPTION")=="configure" ):
        if( doDomain=='true' ):
            if( p.get("ISCLUSTER")=='true' ):
                createReplicationDomain(p,domainName)
        createCache( p, cName, cDesc, cJndi, size, priority, domainName )
