#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

#get the scope
def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'

    return ret

def getWmAttrs( wmName, wmJndi ):
    attrs=[]
    attrs=attrs+[ ['isGrowable', 'false'] ]
    attrs=attrs+[ ['jndiName', wmJndi] ]
    attrs=attrs+[ ['maxThreads', '1'] ]
    attrs=attrs+[ ['minThreads', '0'] ]
    attrs=attrs+[ ['name', wmName] ]
    attrs=attrs+[ ['numAlarmThreads', 10] ]
    attrs=attrs+[ ['serviceNames', 'com.ibm.ws.i18n;security;UserWorkArea;zos.wlm'] ]
    attrs=attrs+[ ['threadPriority', '5'] ]

    return attrs

def getSAttrs(schedName, dataSource, pollInterval, prefix, wmInfo):
    attrs=[]
    attrs=attrs+[ ['name', schedName] ]
    attrs=attrs+[ ['datasourceJNDIName', dataSource] ]
    attrs=attrs+[ ['jndiName', schedName] ]
    attrs=attrs+[ ['pollInterval', pollInterval] ]
    attrs=attrs+[ ['tablePrefix', prefix] ]
    attrs=attrs+[ ['workManagerInfo', wmInfo] ]

    return attrs

def removeScheduler(p, schedName, wmName):
    scope=getScope(p)
    sScope=scope+'SchedulerProvider:SchedulerProvider/SchedulerConfiguration:'+schedName+'/'
    
    msg=RFIDICGetMessage.getMessage('RFID07084I')
    print msg.getMessage()

    sched=AdminConfig.getid(sScope)
    if( sched!='' ):
        msg=RFIDICGetMessage.getMessage('RFID07085I')
        print msg.getMessage()
        print schedName

        AdminConfig.remove(sched)
    else:
        msg=RFIDICGetMessage.getMessage('RFID07036E', schedName)
        print msg.getMessage()

    wmScope=scope+'WorkManagerProvider:WorkManagerProvider/WorkManagerInfo:'+wmName+'/'
    wrkMgr=AdminConfig.getid(wmScope)
    if( wrkMgr!='' ):
        AdminConfig.remove(wrkMgr)
        msg=RFIDICGetMessage.getMessage('RFID07089I', wmName)
        print msg.getMessage()
    else:
        msg=RFIDICGetMessage.getMessage('RFID07088I', wmName)
        print msg.getMessage()
        
def createScheduler(p, schedName, dataSource, pollInterval,
                    prefix, workManagerName, workManagerJndi):

    scope=getScope(p)
    spScope=scope+'SchedulerProvider:SchedulerProvider/'
    schedProv=AdminConfig.getid(spScope)
    if( schedProv=='' ):
        msg=RFIDICGetMessage.getMessage('RFID07042E', scope)
        print msg.getMessage()
        exit

    msg=RFIDICGetMessage.getMessage('RFID07090I')
    print msg.getMessage()

    wmScope=scope+'WorkManagerProvider:WorkManagerProvider/'
    wmProv=AdminConfig.getid(wmScope)
    if( wmProv=='' ):
        msg=RFIDICGetMessage.getMessage('RFID07044I', wmScope)
        print msg.getMessage()

    msg=RFIDICGetMessage.getMessage('RFID07091I')
    print msg.getMessage()

    wmAttrs=getWmAttrs(workManagerName, workManagerJndi)

    msg=RFIDICGetMessage.getMessage('RFID07092I')
    print msg.getMessage()

    wmInfo=AdminConfig.create('WorkManagerInfo', wmProv, wmAttrs)

    msg=RFIDICGetMessage.getMessage('RFID07093I')
    print msg.getMessage()

    sAttrs=getSAttrs(schedName, dataSource, pollInterval, prefix,
                     wmInfo)
    
    msg=RFIDICGetMessage.getMessage('RFID07094I')
    print msg.getMessage()

    AdminConfig.create('SchedulerConfiguration', schedProv, sAttrs)

    msg=RFIDICGetMessage.getMessage('RFID07095I')
    print msg.getMessage()

def run(p, schedName, dataSource, pollInterval, prefix, wmName, wmJndi):
    removeScheduler(p, schedName, wmName)

    if( p.get("CONFIG_OPTION")=="configure" ):
        createScheduler(p, schedName, dataSource, pollInterval, prefix,
                        wmName, wmJndi)
    
