#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage

#Set the genericJvmArguments from the server to value
def updateGenericJvm(serverName, nodeName, value):
    arg='[-nodeName '+nodeName+' -serverName '+serverName+' -genericJvmArguments '+value+']'
    AdminTask.setJVMProperties(arg)
    
def updateJVMMemorySettings(serverName, nodeName):
    initialHS='1024'
    maxHS='2048'
    AdminTask.setJVMInitialHeapSize('-serverName '+serverName+' -nodeName '+nodeName+' -initialHeapSize '+initialHS)
    AdminTask.setJVMMaxHeapSize('-serverName '+serverName+' -nodeName '+nodeName+' -maximumHeapSize '+maxHS)

#Remove the RFIDIC_HOME property
def removeVariables(servers):
    msg=RFIDICGetMessage.getMessage('RFID07059I')
    print msg.getMessage()
    
    for server in servers:
        updateGenericJvm( server[1], server[0], '""' )

#Add the java system properties
def setVariables(p, servers):
    value='"-DRFIDIC_HOME='+p.get("RFIDIC_HOME")
    value=value+' -DTS_HOME='+p.get("TS_HOME")
    value=value+' -Djava.awt.headless=true"'
    
    msg=RFIDICGetMessage.getMessage('RFID07058I', value)
    print msg.getMessage()
    
    for server in servers:
        updateGenericJvm( server[1], server[0], value )
        updateJVMMemorySettings( server[1], server[0] )

def removeWebsphereVariableServerScope(serverName, nodeName, varName):
    arg='[-variableName '+varName+' -scope Node='+nodeName+',Server='+serverName+']'
    AdminTask.removeVariable(arg)

def removeWebsphereVariable(servers, varName):
    #XXX - bundle
    print "Removing: "+varName
    for server in servers:
        removeWebsphereVariableServerScope( server[1], server[0], varName )
        
#Set the WebSphere variable for the given node/server
def setWebsphereVariableServerScope(serverName, nodeName, varName, varValue):
    arg='[-variableName '+varName+' -scope Node='+nodeName+',Server='+serverName+' -variableValue '+varValue+']'
    AdminTask.setVariable(arg)

def setWebsphereVariableNodeScope(nodeName, varName, varValue):
    arg='[-variableName '+varName+' -scope Node='+nodeName+' -variableValue '+varValue+']'
    AdminTask.setVariable(arg)

#Set the Websphere variable for all servers
def setWebsphereVariable(servers, varName, varValue):
    msg=RFIDICGetMessage.getMessage('RFID07060I', varName)
    print msg.getMessage()
    for server in servers:
        setWebsphereVariableServerScope( server[1], server[0], varName, varValue )

def setWebsphereVariableNode(servers, varName, varValue):
    msg=RFIDICGetMessage.getMessage('RFID07060I', varName)
    print msg.getMessage()
    for server in servers:
        setWebsphereVariableNodeScope( server[0], varName, varValue )

#Set the JDBC Driver classpath for the servers
def setJdbcDriverClasspath(p, servers):
    dbHome=p.get("DBMS_JDBC_LIB_PATH")
    dbType=p.get("DB_TYPE")
    if( dbType=="ORACLE" ):
        setWebsphereVariable(servers, "ORACLE_JDBC_DRIVER_PATH", dbHome)
        setWebsphereVariableNode(servers, "ORACLE_JDBC_DRIVER_PATH", dbHome)
    elif( dbType=="DB2" ):
        setWebsphereVariable(servers, "DB2UNIVERSAL_JDBC_DRIVER_PATH", dbHome)
        setWebsphereVariableNode(servers, "DB2UNIVERSAL_JDBC_DRIVER_PATH", dbHome)
        setWebsphereVariable(servers, "UNIVERSAL_JDBC_DRIVER_PATH", dbHome)
        setWebsphereVariableNode(servers, "UNIVERSAL_JDBC_DRIVER_PATH", dbHome)

def setRfidicVars(p, servers):
    rfidicHome=p.get("RFIDIC_HOME")
    rfidicLib=rfidicHome+'/lib/'
    setWebsphereVariable(servers, "RFIDIC_LIB", rfidicLib)
    rfidicME=p.get("RFIDIC_FILE_STORE")
    setWebsphereVariable(servers, "RFIDIC_FILE_STORE", rfidicME)
    
def removeRfidicVars(servers):
    removeWebsphereVariable(servers, "RFIDIC_LIB")
    removeWebsphereVariable(servers, "RFIDIC_FILE_STORE")
    
#Clear the genericJvmArguments from a server or cluster
def run(p, servers):
    removeVariables(servers)
    removeRfidicVars(servers)
    #Process runas skipped
    
    if( p.get("CONFIG_OPTION")=="configure" ):
        setVariables(p, servers)
        setJdbcDriverClasspath(p, servers)
        setRfidicVars(p, servers)
