#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

def getServerPath(p, server):
    path='/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/Server:'+server[1]+'/'
    return path

def setLibraryOnServer(p, server, libName, classPath, desc):
    msg=RFIDICGetMessage.getMessage('RFID07103I', libName)
    print msg.getMessage()
    
    path=getServerPath(p, server)
    server=AdminConfig.getid(path)
    attrs=[['name', libName], ['classPath', classPath], ['description', desc]]
    
    msg=RFIDICGetMessage.getMessage('RFID07105I', libName)
    print msg.getMessage()
    
    AdminConfig.create('Library', server, attrs)

def setLibrary(p, servers, libName, libDesc):
    classPath=p.get("RFIDIC_JARS_PATH")
    for server in servers:
        setLibraryOnServer(p, server, libName, classPath, libDesc)

def createClassLoaderOnServer(p, server, libName):
    msg=RFIDICGetMessage.getMessage('RFID07106I', libName)
    print msg.getMessage()

    spath=getServerPath(p, server)
    aspath=spath+'ApplicationServer:/'
    appServer=AdminConfig.getid(aspath)
    classloaders=AdminConfig.list('Classloader', appServer)
    classloaderList=AdminUtilities.convertToList(classloaders)
    cl=''
    if( len(classloaderList)==0 ):
        cl=AdminConfig.create('Classloader', appServer,
                              [['mode', 'PARENT_FIRST']])
    else:
        cl=clasloaderList[0]
    AdminConfig.create('LibraryRef', cl, [ ['libraryName', libName] ])

def removeLibraryFromServer(p, server, libName):
    msg=RFIDICGetMessage.getMessage('RFID07158I', libName)
    print msg.getMessage()
    
    spath=getServerPath(p, server)
    lpath=spath+'Library:'+libName+'/'
    lib=AdminConfig.getid(lpath)
    if( lib != '' ):
        msg=RFIDICGetMessage.getMessage('RFID07159I',
                                        p.get("CELLNAME"), server[0], libName)
        print msg.getMessage()
        AdminConfig.remove(lib)
        return

    msg=RFIDICGetMessage.getMessage('RFID07160I', libName)
    print msg.getMessage()
        
def removeLibrary(p, servers, libName):
    for server in servers:
        removeLibraryFromServer(p, server, libName)
        
def createClassLoader(p, servers, libName):
    for server in servers:
        createClassLoaderOnServer(p, server, libName)

def resetClassLoaderOnServer(p, server, libName):
    msg=RFIDICGetMessage.getMessage('RFID07161I', libName)
    print msg.getMessage()

    spath=getServerPath(p, server)
    aspath=spath+'ApplicationServer:/'
    appServer=AdminConfig.getid(aspath)
    classloaders=AdminConfig.list('Classloader', appServer)
    classloaderList=AdminUtilities.convertToList(classloaders)
    for cl in classloaderList:
        libs=AdminConfig.list('LibraryRef', cl)
        libList=AdminUtilities.convertToList(libs)
        if( len(libList)==0 ):
            msg=RFIDICGetMessage.getMessage('RFID07163I', cl)
            print msg.getMessage()
            AdminConfig.remove(cl)
        else:
            for lib in libList:
                name=AdminConfig.showAttribute(lib, 'libraryName')
                if( name==libName ):
                    AdminConfig.remove(lib)
                    if( len(libList)==1 ):
                        msg=RFIDICGetMessage.getMessage('RFID07163I', cl)
                        print msg.getMessage()
                        AdminConfig.remove(cl)

def resetClassLoader(p, servers, libName):
    for server in servers:
        resetClassLoaderOnServer(p, server, libName)
        
def run(p, servers, libName, libDesc):
    removeLibrary(p, servers, libName)
    

    if( p.get("CONFIG_OPTION")=="configure" ):
        setLibrary(p, servers, libName, libDesc)
       
