#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

def getVH(p):
    cell=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/')
    vhosts=AdminConfig.list('VirtualHost', cell)
    vhostList=AdminUtilities.convertToList(vhosts)
    for vhost in vhostList:
        name=AdminConfig.showAttribute(vhost, 'name')
        if( name=='default_host' ):
            #XXX -bundle
            print "Got vhost; "+vhost
            return vhost
    #XXX -bundle
    print "Couldn't find default host"
    return ''

def addHA(p):
    host=p.get('WS_EP_IP')
    port=p.get('WS_EP_PORT')

    vhost=getVH(p)
    if( vhost=='' ):
        return
    has=AdminConfig.list('HostAlias', vhost)
    haList=AdminUtilities.convertToList(has)
    for ha in haList:
        hname=AdminConfig.showAttribute(ha, 'hostname')
        hport=AdminConfig.showAttribute(ha, 'port')
        if( hname==host and hport==port ):
            #XXX -bundle
            print "Host alias for host "+host+" port "+port+" already exists"
            return
        
    #XXX - bundle
    print 'Adding host '+host+' port '+port+' host alias to default_host'
    AdminConfig.create('HostAlias', vhost, [['port', port], ['hostname', host]])
    
def unUpdatePort(p, servers):
    for server in servers:
        #XXX -bundle
        print 'Setting host on WC_defaulthost on '+server[1]+' on node '+server[0]+' to *'
        AdminTask.modifyServerPort(server[1], ['-nodeName', server[0], '-endPointName', 'WC_defaulthost', '-host', '*', '-modifyShared', 'true'])
 
def updatePort(p, servers):
    for server in servers:
        node=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/')
        sis=AdminConfig.list('ServerIndex', node)
        siList=AdminUtilities.convertToList(sis)
        si=siList[0]
        hostname=AdminConfig.showAttribute(si, 'hostName')
        #XXX -bundle
        print 'Setting host on WC_defaulthost on '+server[1]+'on node '+server[0]+' to '+hostname
        AdminTask.modifyServerPort(server[1], ['-nodeName', server[0], '-endPointName', 'WC_defaulthost', '-host', hostname, '-modifyShared', 'true'])
        
def getProp():
    arg=[ ['name', 'enableInProcessConnections'] ]
    arg=arg+[ ['value', 'true'] ]

    return arg

def addWCProperty(p, servers):
    prop=getProp();
    for server in servers:
        #XXX -bundle
        print 'Add enableInProcessConnections for server '+server[1]+'on node '+server[0]
        serv=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/Server:'+server[1]+'/')
        wcs=AdminConfig.list('WebContainer', serv);
        wcList=AdminUtilities.convertToList(wcs);
        wc=wcList[0];
        AdminConfig.create('Property', wc, prop)

def removeWCProperty(p, servers):
    for server in servers:
        serv=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/Server:'+server[1]+'/')
        wcs=AdminConfig.list('WebContainer', serv);
        wcList=AdminUtilities.convertToList(wcs);
        wc=wcList[0];
        props=AdminConfig.list('Property', wc)
        propList=AdminUtilities.convertToList(props)
        for prop in propList:
            name=AdminConfig.showAttribute(prop, 'name')
            if( name=='enableInProcessConnections' ):
                #XXX -bundle
                print 'Remove enableInProcessConnections for server '+server[1]+'on node '+server[0]
                AdminConfig.remove(prop)
                
def run(p, servers):
    removeWCProperty(p, servers)
    unUpdatePort(p, servers)
    #don't remove the host alias, they may want it there
    
    if( p.get("CONFIG_OPTION")=="configure" ):
        addWCProperty(p, servers)
        updatePort(p, servers)
        addHA(p)
