#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2010, 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title: setWebServicesBindingInfoMain.sh	
##   Description: Configures TS WebServices with Security Bindings
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
        . ${RFIDIC_HOME}/bin/tsEnv.sh
        . ${RFIDIC_HOME}/bin/utils.sh
else
        . ${SCRIPT_DIR}/tsEnv.sh
        . ${SCRIPT_DIR}/utils.sh
fi

usage()
{
    $ECHO "Usage: setWebServicesBindingInfoMain.sh"
    $ECHO "                    [-was_admin_user=<user>]"  
    $ECHO "                    [-was_admin_password=<password>]"
    $ECHO "                    [-ws_user=<web services user>"
    $ECHO "                    -ws_password=<web services password>"
    $ECHO "                    -ws_ssl_cfg=<web services ssl configuration name>"
    $ECHO "                    -ws_port=<web services port>]"
}

getWebServicePort()
{
    unset ws_port
    
    portdefFile="$WAS_PROFILE_HOME/properties/portdef.props"
    
    if [ "$securityEnabled" = "$TRUE" ];then
        portName="WC_defaulthost_secure"
    else
        portName="WC_defaulthost"
    fi
    
    ws_port=`grep $portName= $portdefFile |sed 's/'$portName'=//'` >> /dev/null
    
    # If portdef.props file doesn't have the port number, query WAS directly.
    if [ -z "$ws_port" ];then
        getWAScredentials
        RFIDIC_PROPS_FILE=/tmp/cfgProps.$$
        writeProperties
        ws_port=`${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${TS_HOME}/bin/jython/getWebServicesPort.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython | grep port | awk '{print($2)}'`
        rm -f $RFIDIC_PROPS_FILE
    fi
}

updateTSEnv()
{
    searchStr[0]='was_admin_user=.*'
    searchStr[1]='WS_UI_USER=.*'
    searchStr[2]='WS_UI_SSL=.*'
    searchStr[3]='WS_PORT_NO=.*'

    if [ "$securityEnabled" = "$FALSE" ];then
        unset was_admin_user
        export was_admin_user
        replaceStr[0]="was_admin_user=\$was_admin_user"
        replaceStr[1]="WS_UI_USER=\$WS_UI_USER"
        replaceStr[2]="WS_UI_SSL=\$WS_UI_SSL"
    else
        replaceStr[0]="was_admin_user=$was_admin_user"
        replaceStr[1]="WS_UI_USER=$WS_UI_USER"
        replaceStr[2]="WS_UI_SSL=$WS_UI_SSL"
    fi

    replaceStr[3]="WAS_PORT_NO=$WAS_PORT_NO"
    
    asciiUpdate "${TS_HOME}/bin/tsEnv.sh" $searchStr $replaceStr
    chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/bin/tsEnv.sh
    run_command chmod 750 ${TS_HOME}/bin/tsEnv.sh

    export WS_UI_USER
    export WS_UI_SSL
    export was_admin_user
    export WAS_PORT_NO
}

for item in $*
do
    if [ `expr match "$item" '-was_admin_user'` != 0 ]; then
        was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
    elif [ `expr match "$item" '-was_admin_password='` != 0 ]; then
        was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
    elif [ `expr match "$item" '-ws_user='` != 0 ]; then
        WS_UI_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
    elif [ `expr match "$item" '-ws_password='` != 0 ]; then
        WS_UI_PWD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
    elif [ `expr match "$item" '-ws_ssl_cfg='` != 0 ]; then
        WS_UI_SSL=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
    elif [ `expr match "$item" '-ws_port='` != 0 ]; then
        ws_port=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
    else
        $ECHO "Unknown Parameter"
        usage
        exit 1
    fi
done

getWAScredentials
isWASSecurityEnabled
securityEnabled=$?

if [ "$securityEnabled" = "$TRUE" ];then
    if [ -z "$WS_UI_USER" -o  -z "$WS_UI_PWD" -o  -z "$WS_UI_SSL" ];then
        $ECHO "The web service user, password, and/or ssl configuration parameters are missing."
        usage
        exit 1
    fi
fi

if [ -z "$ws_port" -o "$ws_port" = "" ];then
    getWebServicePort
fi

if [ -z "$ws_port" -o "$ws_port" = "" ];then
    $ECHO "Cannot determine the port to use for the web services. Use the -ws_port parameter to specify a port."
    usage
    exit 1
else
    WAS_PORT_NO=$ws_port
    WS_EP_PORT=$ws_port
fi

updateTSEnv

### Set the CONFIG_OPTION parameter to tell the script this is not a clean operation
CONFIG_OPTION=configure

######### Settting the client side WS Binding Info for securing internal webservices####################
RFIDIC_PROPS_FILE=/tmp/cfgProps.$$
writeProperties

getWAScredentials
run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${TS_HOME}/bin/jython/setWebServicesBindings.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython
retCode=$?
rm -f $RFIDIC_PROPS_FILE

exit $retCode
