#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title: stopTS.sh	
##   Description: Script to stop all the prerequisite software of Traceability
##   Server, namely, MQ, TDI and WAS.
##		
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
	. $RFIDIC_HOME/bin/tsEnv.sh
	. $RFIDIC_HOME/bin/utils.sh
    . $RFIDIC_HOME/bin/prereqChecks.sh
else
	. $SCRIPT_DIR/tsEnv.sh
	. $SCRIPT_DIR/utils.sh
	. $SCRIPT_DIR/prereqChecks.sh
fi

usage()
{
	 tsGetMessage.sh RFID05084I "$0"
}

stopMQ()
{
	isHostnameRemote $MQ_HOST
	mq_dist=$?
	
	echo "========================================="

	if [ "$mq_dist" = "$TRUE" ];then
		tsGetMessage.sh TSIN01306I $MQ_HOST
		#echo "Ensure that WebSphere MQ queue manager is stopped on the host $MQ_HOST"
		return
	fi
	if [ -d "$MQ_HOME" ];then		
		tsGetMessage.sh RFID05051I  
		endmqlsr -m ${QUEUE_MANAGER}
        if [ $? -ne 0 ];then
            tsGetMessage.sh RFID05043E "WebSphere MQ"
            exit $FALSE
        fi

		endmqm -w ${QUEUE_MANAGER}
        if [ $? -ne 0 ];then
            tsGetMessage.sh RFID05043E "WebSphere MQ"
            exit $FALSE
        fi
	else
		tsGetMessage.sh RFID05052E "$MQ_HOME"
	fi
	return
}

stopOracle()
{
	isHostnameRemote $DBMS_HOST
	db_dist=$?
	
	echo "========================================="

	if [ "$db_dist" = "$TRUE" ];then
		tsGetMessage.sh TSIN01307I $DBMS_HOST
		#echo "Ensure that the Oracle server instance is stopped on the host $DBMS_HOST"
		return
	fi
	if [ -d "$DBMS_HOME" ];then
		#echo "Stopping Oracle..."
		tsGetMessage.sh RFID05228I
		if [ "$stop_db" != "true" ];then
			tsGetMessage.sh -noid RFID05257E
			promptUserYesNo
			if [ "$?" -eq "$YES" ];then
				stop_db=true
			else
				tsGetMessage.sh -noid RFID05255E
				exit $FALSE
			fi
		fi
		if [ "$stop_db" = "true" ];then
      		runCommandAsUser $ORACLE_OWNER $DBMS_HOME/bin/dbshut $DBMS_HOME
            if [ $? -ne 0 ];then
                tsGetMessage.sh RFID05043E "Oracle"
                exit $FALSE
            fi
		fi
	else
		#echo "Oracle could not be stopped as the RDBMS was not found under, $DBMS_HOME"
		tsGetMessage.sh RFID05229E "$DBMS_HOME"
		return -1
	fi
	return
}

stopDB2()
{
	isHostnameRemote $DBMS_HOST
	db_dist=$?
	
	echo "========================================="

	if [ "$db_dist" = "$TRUE" ];then
		tsGetMessage.sh TSIN01308I $DBMS_HOST
		#echo "Ensure that the DB2 server instance is stopped on the host $DBMS_HOST"
		return
	fi

	if [ -d "$DBMS_HOME" ];then
		#echo "Stopping DB2..."
		tsGetMessage.sh RFID05233I 
		if [ "$stop_db" != "true" ];then
			tsGetMessage.sh -noid RFID05257E
			promptUserYesNo
			if [ "$?" -eq "$YES" ];then
				stop_db=true
			else
				tsGetMessage.sh -noid RFID05255E
				exit $FALSE
			fi
		fi
	
		if [ "$stop_db" = "true" ];then
			runCommandAsUser ${DB2_INSTANCE_OWNER} /home/$DB2_INSTANCE/sqllib/adm/db2stop force
            if [ $? -ne 0 ];then
                tsGetMessage.sh RFID05043E "DB2"
                exit $FALSE
            fi
		fi
	else
		tsGetMessage.sh RFID05054E "$DBMS_HOME" 
		exit $FALSE
	fi
	return
}

stopCapture()
{
	echo "========================================="

	#Stop the listener 
	tsGetMessage.sh RFID05096I

    getWAScredentials

    isWASRunning
    wasRunning=$?

    if [ "$wasRunning" == "$TRUE" ];then
        RFIDIC_PROPS_FILE=/tmp/stopCap.$$
        writeProperties
        ${WAS_PROFILE_HOME}/bin/wsadmin.sh -wsadmin_classpath ${WSADMIN_JARS_PATH} -lang jython ${credentials} -f ${RFIDIC_HOME}/bin/jython/startMessageEndpoints.py ${RFIDIC_PROPS_FILE} ${RFIDIC_HOME}/bin/jython stop
        captureStatus=$?

        /bin/rm -f ${RFIDIC_PROPS_FILE}

        if [ "$captureStatus" -eq "0" ]; then
            tsGetMessage.sh RFID05097I
        else
            tsGetMessage.sh RFID05114I
            tsGetMessage.sh RFID05043E "capture"
            exit $FALSE
        fi
 
    else
        tsGetMessage.sh RFID97082I
    fi
}

stopWAS()
{
	echo "========================================="
    tsGetMessage.sh RFID05056I    

    getWAScredentials

    isWASRunning
    wasRunning=$?
    
    if [ "$wasRunning" == "$TRUE" ];then
        if [ -d "$WAS_HOME" ];then
            RFIDIC_PROPS_FILE=/tmp/stopWAS.$$
            writeProperties
            ${WAS_PROFILE_HOME}/bin/wsadmin.sh -wsadmin_classpath ${WSADMIN_JARS_PATH} -lang jython ${credentials} -f ${RFIDIC_HOME}/bin/jython/stopServers.py ${RFIDIC_PROPS_FILE} ${RFIDIC_HOME}/bin/jython $dev_mode
            wasStatus=$?
            /bin/rm -f ${RFIDIC_PROPS_FILE}

            if [ $wasStatus -ne 0 ];then
                tsGetMessage.sh RFID05043E "WebSphere Application Server"
                exit $FALSE
            fi

            if [ -z "$CLUSTERNAME" ];then
                ${WAS_PROFILE_HOME}/bin/stopServer.sh ${SERVERNAME} ${credentials}
                if [ $? -ne 0 ];then
                    tsGetMessage.sh RFID05043E "WebSphere Application Server"
                    exit $FALSE
                fi
            fi
        else
            tsGetMessage.sh RFID05058E "$WAS_HOME"
        fi
    else
        tsGetMessage.sh RFID97082I
    fi
}

# This function can only be called once per running instance of this script.
stopApps()
{
    if [ -z "$appsAreStopped" ];then
        appsAreStopped=$TRUE
        echo "========================================="
        tsGetMessage.sh RFID05072I

        getWAScredentials

        isWASRunning
        wasRunning=$?
    
        if [ "$wasRunning" == "$TRUE" ];then
            RFIDIC_PROPS_FILE=/tmp/stopApps.$$
            writeProperties
            getWAScredentials
            ${WAS_PROFILE_HOME}/bin/wsadmin.sh -wsadmin_classpath ${WSADMIN_JARS_PATH} -lang jython ${credentials} -f ${RFIDIC_HOME}/bin/jython/stopApplications.py ${RFIDIC_PROPS_FILE} ${RFIDIC_HOME}/bin/jython $*
            appsStatus=$?
            /bin/rm -f ${RFIDIC_PROPS_FILE}

            if [ $appsStatus -ne 0 ];then
                tsGetMessage.sh RFID05269E
                exit $FALSE
            fi
        else
            tsGetMessage.sh RFID97082I
        fi
    fi
}

components="$DB_TYPE,MQ,WAS,CAPTURE,ENGINE,UI,SERIALID"

dev_mode=false

if [ $# -gt 3 ];then
    usage
    exit -1
else
    for item in $*
    do
        if [ `echo $item | wc -c` = 2 ];then
            usage
            exit -1
        elif [ `expr match "$item" '-components='` != 0 ];then
            components=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-was_admin_user='` != 0 ];then
            was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-was_admin_password='` != 0 ];then
            was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
        elif [ `expr match "$item" '-dev_mode'` != 0 ];then
            dev_mode=true
        else
            usage
            exit -1
        fi
    done
fi

#Making input case neutral and ensuring the components are started in the right order
components=`echo "$components" |tr "[a-z]" "[A-Z]"`
components=`echo "$components" | sed "s/ORACLE/AORACLE/g"`
components=`echo "$components" | sed "s/ENGINE/WASA_ENGINE/g"`
components=`echo "$components" | sed "s/UI/WASB_UI/g"`
components=`echo "$components" | sed "s/SERIALID/WASC_SERIALID/g"`
components=`echo "$components" | sed "s/CAPTURE/WASD_CAPTURE/g"`

components=`echo "$components" | tr "," "\n" | sort -r`
components=`echo "$components" | sed "s/AORACLE/ORACLE/g"`
components=`echo "$components" | sed "s/WASA_ENGINE/ENGINE/g"`
components=`echo "$components" | sed "s/WASB_UI/UI/g"`
components=`echo "$components" | sed "s/WASC_SERIALID/SERIALID/g"`
components=`echo "$components" | sed "s/WASD_CAPTURE/CAPTURE/g"`

comp=`echo $components|sed "s/ /|/g"`
tsGetMessage.sh RFID05049I "$comp" 

appList=""

for item in $components
do
	case "$item" in
		DB)
			;;
		ORACLE)
			;;
		DB2)
			;;
		MQ)
			;;
		WAS)
			;;
		CAPTURE)
			;;
        ENGINE)
            appList="$appList $CPAPP_NAME"
            ;;
        UI)
            appList="$appList $UIAPP_NAME"
            ;;
        SERIALID)
            appList="$appList $SIDAPP_NAME"
            ;;
	esac
done

for item in $components
do
	case "$item" in
		DB)
			case "$DB_TYPE" in
				ORACLE)
					stopOracle
	                ;;
				DB2)
					stopDB2
					;;
			esac;;
		ORACLE)
			stopOracle
			;;
		DB2)
			stopDB2
			;;
		MQ)
			stopMQ
			;;
		WAS)
			stopWAS
			;;
		CAPTURE)
			stopCapture
			;;
        ENGINE|UI|SERIALID)
            stopApps $appList
            ;;
		*)
			tsGetMessage.sh RFID05037I $item
	esac
done
