#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title:	updateTS.sh 
##   Description: Utility to reinstall all of the TS ear files
##   usage:  updateTS.sh  [-was_admin_user=<userid>] [was_admin_password=<password>] [ws_user=<user>] [ws_password=<password>]
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
  . ${RFIDIC_HOME}/bin/tsEnv.sh
  . ${RFIDIC_HOME}/bin/utils.sh
else
  . ${SCRIPT_DIR}/tsEnv.sh
  . ${SCRIPT_DIR}/utils.sh
fi

usage()
{
	echo "	USAGE: ./updateTS.sh"
	echo "                          [-was_admin_user=<userid>]"
	echo "                          [-was_admin_password=<password>]"
	echo "                          [-ws_user=<web services userid>]"
	echo "                          [-ws_password=<web services password>]"
	echo "                          [-log=<Path to custom log file>]"
}

# Starting WAS servers (copied from ConfigureWAS)
checkWASStart()
{
    #credentials were already gotten by the checkWASCredentials call
    
    if [ -z "$CLUSTERNAME" ];then
		start_server=$SERVERNAME
    else
		start_server=dmgr
    fi

    server_status=`${WAS_PROFILE_HOME}/bin/serverStatus.sh $start_server $credentials` >> $utilsLogFile 2>&1
    status=$?

    if [ "$status" -ne 0 ];then
    	getMessage TSIN02249E $start_server $status
    	echo $msg
        log $msg
	#echo "Could not get status for $start_server status=$status"
	return $FALSE
    fi

    present=`echo $server_status |grep "ADMU0508I"`
    status=$?

}

# Check if WAS credentials are correct
checkWASCredentials()
{
    getWAScredentials
    serverStatus=`${WAS_HOME}/bin/serverStatus.sh $SERVERNAME $credentials` >> $utilsLogFile 2>&1

    present=`echo "$serverStatus" | grep "ADMN0022E"`
    status=$?
}

#### Input Arguments Verification #####

for item in $*
   do
	if [ `expr match "$item" '-was_admin_user='` != 0 ];then
		was_admin_user=`echo ${item#-was_admin_user=}`
	elif [ `expr match "$item" '-was_admin_password='` != 0 ];then
		was_admin_password=`echo ${item#-was_admin_password=}`
	elif [ `expr match "$item" '-ws_user='` != 0 ];then
		ws_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-ws_password='` != 0 ];then
		ws_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-log='` != 0 ];then
		customLogFile=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	else
		usage
		exit $FALSE
	fi
   done

if [ -n "$customLogFile" ];then
	assignLogFile $customLogFile
else
	logFileName=TSUpdateLog_`date "+%Y%m%d%H%M%S"`
	assignLogFile ${scriptDir}/../logs/$logFileName
fi

echo "Checking WAS credentials"
log "Checking WAS credentials"
checkWASCredentials
if [ $status -eq 0 ];then
  echo
  getMessage RFID50508W
  echo $msg
  log $msg
  exit $FALSE 
fi

# Make sure WAS is started
echo "Making sure WAS is started"
log "Making sure WAS is started"
checkWASStart
if [ $status -ne 0 ];then

  ## check to see if security is being used and if so pass in the parameters
  if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
      parms="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
   else
      parms=""
   fi

   #echo "cmd: $TS_HOME/bin/startTS.sh -components=was $parms"
   getMessage TSIN02117I
   echo $msg
   log $msg
   #log "Starting WAS..."
   run_command $TS_HOME/bin/startTS.sh -components=was $parms >> $utilsLogFile 2>&1
   status=$?
   
   if [ $status -ne 0 ];then
       echo
       echo "WebSphere Application Server failed to start."
       log  "WebSphere Application Server failed to start."
       echo
       getMessage TSIN01144E $utilsLogFile
       echo $msg
       log $msg
       exit $FALSE
   fi

fi

retCode=0
webServices_retCode=0
stopWas_retCode=0
startWas_retCode=0

echo
echo "-------- Reinstalling the TS library and updating TS applications --------"
log  "-------- Reinstalling the TS library and updating TS applications --------"
CONFIG_OPTION=configure
RFIDIC_PROPS_FILE=/tmp/cfgProps.$$
writeProperties

if [ -f $TS_HOME/bin/jython/updateTSFP.py ];then
	#if this file exist, its a rollback and we execute the fixpack version of updateTS.py which will install mdm.ear based on its existanse.
	run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${TS_HOME}/bin/jython/updateTSFP.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython >> $utilsLogFile 2>&1
	retCode=$?
else
	#during update updateTS.py will be the FP version so we can just call it...	
	run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${TS_HOME}/bin/jython/updateTS.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython >> $utilsLogFile 2>&1
	retCode=$?
fi

if [ $retCode -eq 0 ];then
  echo
  echo "-------- Successfully updated TS application and library. --------"
  log  "-------- Successfully updated TS application and library. --------"
  echo
fi

echo
echo "-------- Updating the web services bindings --------"
log "-------- Updating the web services bindings --------"

if [ -z "$WS_UI_SSL" ];then
    WS_UI_SSL=NodeDefaultSSLSettings
fi

run_command $TS_HOME/bin/setWebServicesBindingInfoMain.sh -was_admin_user=$was_admin_user -was_admin_password=$was_admin_password -ws_user=$ws_user -ws_password=$ws_password -ws_ssl_cfg=$WS_UI_SSL >> $utilsLogFile 2>&1
webServices_retCode=$?

if [ $webServices_retCode -eq 0 ];then
  echo
  echo "-------- Successfully updated web services bindings. --------"
  log  "-------- Successfully updated web services bindings. --------"
  echo
fi

#In the stand alone case, restart the app server
#In the ND case, updateTS takes care of restarting the members
if [ -z "$CLUSTERNAME" ];then

   if [ $retCode -eq 0 ];then
       ## check to see if security is being used and if so pass in the parameters
       if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
          parms="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
       else
          parms=""
       fi

       echo
       echo "-------- Restarting WebSphere Application Server -------"
       log "-------- Restarting WebSphere Application Server -------"

       getMessage TSIN02115I
       echo $msg
       log $msg
       #log "Stopping WAS..."
       #echo "cmd: $TS_HOME/bin/stopTS.sh -components=was $parms"
       run_command $TS_HOME/bin/stopTS.sh -components=was $parms >> $utilsLogFile 2>&1
       stopWas_retCode=$?

       getMessage TSIN02117I
       echo $msg
       log $msg
       #log "Starting WAS..."
       #echo "cmd: $TS_HOME/bin/startTS.sh -components=was $parms"
       run_command $TS_HOME/bin/startTS.sh -components=was $parms >> $utilsLogFile 2>&1
       startWas_retCode=$?
   fi

fi

rm -rf $RFIDIC_PROPS_FILE

if [ $retCode -ne 0 ];then
  echo
  echo "--- Update of the TS applications and library failed. ---"
  log  "--- Update of the TS applications and library failed. ---"
  echo
  getMessage TSIN01144E $utilsLogFile
  echo $msg
  log $msg
elif [ $webServices_retCode -ne 0 ];then
  echo
  echo "--- Unable to set the web services credentials. ---"
  log  "--- Unable to set the web services credentials. ---"
  echo
  getMessage TSIN01144E $utilsLogFile
  echo $msg
  log $msg
  retCode=$webServices_retCode
elif [ $stopWas_retCode -ne 0 ];then
  echo
  echo "--- WebSphere Application Server failed to stop. ---"
  log  "--- WebSphere Application Server failed to stop. ---"
  echo
  getMessage TSIN01144E $utilsLogFile
  echo $msg
  log $msg
  retCode=$stopWas_retCode
elif [ $startWas_retCode -ne 0 ];then
  echo
  echo "--- WebSphere Application Server failed to start. ---"
  log  "--- WebSphere Application Server failed to start. ---"
  echo
  getMessage TSIN01144E $utilsLogFile
  echo $msg
  log $msg
  retCode=$startWas_retCode
fi

exit $retCode
