#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title:	tsEnv.sh
##   Description: Sets the environment for other applications to use
##		
##
#############################################################################

version=v3.0.0.0

ECHO="echo"
AWK_PERIOD="awk -F ".""
AWK_EQUAL="awk -F "=""
AWK_QUOTE="awk -F "\'""
AWK_COLON="awk -F ":""
AWK_LESSER="awk -F "\<""
AWK_GREATER="awk -F "\>""
TRUE=0
FALSE=1
YES=$TRUE
NO=$FALSE
HEAD="head -n "
TAIL="tail -n "

log()
{
    if [ -n "$utilsLogFile" ];then
        $ECHO $* >> $utilsLogFile
    fi
	
	if [ "$isVerbose" = "$TRUE" ];then
		$ECHO $*
	fi
}

ID=`id`
CURRENT_USER=`expr "$ID" : ".*uid=[0-9]*(\([^)]*\)*"`
CURRENT_GROUP=`expr "$ID" : ".*gid=[0-9]*(\([^)]*\)*"`

PLATFORM=`uname`
case $PLATFORM in
    AIX)
        HOSTNAME=`hostname -s`
        HOSTNAMEFULL=`hostname`
        ;;
    Linux)
        ECHO="echo -e"
        HOSTNAME=`hostname -s`
        HOSTNAMEFULL=`hostname -f`
        ;;
    SunOS)
        AWK_PERIOD="awk -F."
        AWK_EQUAL="awk -F="
        AWK_QUOTE="awk -F'"
	 AWK_COLON="awk -F:"
	 AWK_LESSER="awk -F<"
	 AWK_GREATER="awk -F>"
        HOSTNAME=`hostname`
		sun_release=`uname -r`
		if [ "$sun_release" = "5.10" ];then
			HOSTNAMEFULL=`/usr/sbin/check-hostname | awk '{print($7)}'`
		else
			HOSTNAMEFULL=`/usr/lib/mail/sh/check-hostname | awk '{print($7)}'`
		fi
		HEAD="head -"
		TAIL="tail -"
        ;;
esac

# Usage: runCommandAsUser <User:password> <Command>
# Note: The password is the password of the user requesting the command to be run, not the user
# which is passed into the function. The requesting user must also be part of the sudoers list.
runCommandAsUser()
{
    unset runUser
    unset runPass
    runUser=`echo $1 | sed "s/:.*//g"`
    containsPassword=`echo $1 | sed "s/[^:]//g"`
    if [ -n "$containsPassword" ];then
        runPass=`echo $1 | sed "s/.*://g"`
    fi
    shift
    command="$*"
    retcode=1
    COUNT=0
    if [ "$CURRENT_USER" = "$runUser" ];then
        sh -c "$command"
        retcode=$?
    elif [ "$CURRENT_USER" != "root" -a -n "$runPass" ];then
        sudo -p "" -S -u $runUser sh -c "$command" << RUNCMD;retcode=$?
$runPass
RUNCMD
    else
    	getMessage TSIN02206I $runUser
    	echo $msg
        #echo "If prompted - enter the password for $runUser"
        while [ $retcode -ne 0 ] && [ $COUNT -lt 2 ]
        do
            if [ "$PLATFORM" = "SunOS" ];then
                /bin/su - ${runUser} -c "${command}"
                retcode=$?
            elif [ "$PLATFORM" = "AIX" ];then
                /bin/su - ${runUser} "-c ${command}"
                retcode=$?
            else
                /bin/su - -c "${command}" ${runUser}
                retcode=$?
            fi
            COUNT=`expr $COUNT + 1`
        done
    fi

    return $retcode
}

run_command()
{
	command="$*"
	"$@"
	retcode=$?
	if [ "$retcode" -ne 0 ]
	then	
		getMessage RFID05138E "$command"
        $ECHO $msg
		return $retcode
	fi
}
appendToPath()
{
        pathName=$1
        pathVariable="$"$1
        newVar=$2

        found=`eval $ECHO $pathVariable | eval grep $newVar`
        if [ -z "$found" ]; then
                ##$ECHO "Adding $newVar to $pathVariable"
                eval $pathName=$pathVariable:$newVar
        fi
}
prependToPath()
{
        pathName=$1
        pathVariable="$"$1
        newVar=$2

        found=`eval $ECHO $pathVariable | eval grep $newVar`
        if [ -z "$found" ]; then
                ##$ECHO "Adding $newVar to $pathVariable"
                eval $pathName=$newVar:$pathVariable
        fi
}
getMessageClasspath()
{   
        unset returnString 
        if [ -z "$message_classpath" ];then
                #Set the message_classpath since it's not set.
                unset tsHome
    
                if [ -z "$TS_HOME" ];then
                        getWASHome
                        tsHome=${returnString}/ts
                else
                        tsHome=$TS_HOME
                fi
        
                if [ -n "$tsHome" -a -d "$tsHome" ];then
                        message_classpath="$tsHome/lib/com.ibm.rfidic.messages.jar:$tsHome/lib/com.ibm.rfidic.utils.messages.jar:$tsHome/lib/com.ibm.rfidic.utils.jar:$tsHome/lib/com.ibm.imc.algorithms.jar:$tsHome/lib/commons-lang-2.4.jar:$tsHome/lib/icu4j-4_4_1.jar:$tsHome/lib/icu4j-charsets-4_4_1.jar:$tsHome/lib/icu4j-localespi-4_4_1.jar"
                fi
        fi  
                
        returnString=$message_classpath
}

getMessage()
{
        msg=""
        
        if [ -z "$WAS_HOME" ];then
            WAS_HOME=$WAS_HOME
            if [ -d "$WAS_HOME" ];then
                log "WAS = $WAS_HOME"
            else
                getWASHome
                if [ -d "$returnString" ];then
                    WAS_HOME=$returnString
                else
                    # Just to spit out the 'cannot open directory' message in the language of the OS, 
                    # since messages cannot be translated without setting the environment.
                    if [ -n "$returnString" ];then
                        file $WAS_HOME
                        return 1
                    fi
                fi
            fi
        fi

        if [ -n "$WAS_HOME" ];then
                getMessageClasspath
                msg=`${WAS_HOME}/java/bin/java -classpath $returnString com.ibm.rfidic.messages.tools.RFIDICGetMessage -noid "$@"`
        fi
}

asciiUpdate()
{
    # Takes an array of search and replace strings for a file, constructs the sed script and performs the update on the file
    index=0
    searchStr=$2
    replaceStr=$3
    count=${#searchStr[*]}
    command="{\n"
    while [ "$index" -lt "$count" ]
    do
        command=$command"s%"${searchStr[$index]}"%"${replaceStr[$index]}"%g\n"
        index=`expr $index + 1`
    done
    command=$command"}"
    $ECHO $command > $1.sed
    run_command sed -f $1.sed $1 > $1.tmp
    sedReturnCode=$?

    if [ $? -eq 0 ];then
        run_command mv -f $1.tmp $1
    else
        rm -f $1.tmp
    fi

    run_command rm -f $1.sed
    unset searchStr
    unset replaceStr

    return $sedReturnCode
}

getDBVersion()
{
	unset returnString
	
	getMessage TSIN02204I
	log $msg
	#log "Query DB version"
    cp=$TS_HOME/lib/commons-lang-2.4.jar:$TS_HOME/lib/icu4j-4_4_1.jar:$TS_HOME/lib/icu4j-charsets-4_4_1.jar:$TS_HOME/lib/icu4j-localespi-4_4_1.jar:$TS_HOME/lib/com.ibm.imc.algorithms.jar:$TS_HOME/lib/com.ibm.rfidic.messages.jar:$TS_HOME/lib/com.ibm.rfidic.utils.messages.jar:$TS_HOME/lib/com.ibm.rfidic.utils.jar:$TS_HOME/lib/commons-dbutils-1.1.jar:$WAS_HOME/lib/j2ee.jar:$WAS_HOME/optionalLibraries/Apache/Struts/1.1/commons-logging.1.1.1.jar:$TS_HOME/lib/commons-codec-1.3.jar:$TS_HOME/lib/commons-httpclient-3.1.jar
	
	if [ -z "$DBMS_ADMIN_USER" ];then
		getMessage TSIN02271I
        $ECHO $msg
		read DBMS_ADMIN_USER
	fi
	if [ -z "$DBMS_ADMIN_PASSWORD" ];then
		getMessage TSIN02272I
        $ECHO $msg
        stty -echo
		read DBMS_ADMIN_PASSWORD
        stty echo
	fi
	
    if [ "$DB_TYPE" = "ORACLE" ];then
		if [ -z "$DBMS_PORT_NUMBER" ];then
            DBMS_PORT_NUMBER=1521
		fi
	
		cp=$cp:$DBMS_JDBC_LIB_PATH/ojdbc5.jar
		
		if [ -n "$ORACLE_JDBC_URL" ];then
			JDBC=$ORACLE_JDBC_URL
		else
			JDBC="jdbc:oracle:thin:@${DBMS_HOST}:${DBMS_PORT_NUMBER}:${DBMS_DB_NAME}"
		fi
		
        JDBCDriver=oracle.jdbc.OracleDriver
        $WAS_HOME/java/bin/java -classpath $cp com.ibm.rfidic.utils.install.SQLFileExecutor ${JDBC} ${JDBCDriver} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PASSWORD} $TS_HOME/bin/Oracle/VersionCheck.sql 1> /tmp/VersionOutput.txt 2>> $utilsLogFile
        if [ "$?" = "1" ];then
        	getMessage TSIN02209E ${DBMS_HOST} $utilsLogFile
            $ECHO $msg
			log $msg
            #log "\n Database version cannot be retrieved on host - ${DBMS_HOST} , Check if the DB is running and try again ."
            return $FALSE
        fi

        returnString=`cat /tmp/VersionOutput.txt | grep "Release" | awk '{print($7)}'`
    elif [ "$DB_TYPE" = "DB2" ];then
		if [ -z "$DBMS_PORT_NUMBER" ];then
            DBMS_PORT_NUMBER=50000
		fi
        
		cp=$cp:$DBMS_JDBC_LIB_PATH/db2jcc.jar:$DBMS_JDBC_LIB_PATH/db2jcc_javax.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cu.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cisuz.jar
        
        JDBC="jdbc:db2://${DBMS_HOST}:${DBMS_PORT_NUMBER}/${DBMS_DB_NAME}"
        JDBCDriver=com.ibm.db2.jcc.DB2Driver
        $WAS_HOME/java/bin/java -classpath $cp com.ibm.rfidic.utils.install.SQLFileExecutor ${JDBC} ${JDBCDriver} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PASSWORD} $TS_HOME/bin/DB2/VersionCheck.sql 1> /tmp/VersionOutput.txt 2>> $utilsLogFile
        if [ "$?" = "1" ];then
        	getMessage TSIN02209E ${DBMS_HOST} $utilsLogFile
            $ECHO $msg
			log $msg 
            #log "\n Database version cannot be retrieved on host - ${DBMS_HOST} , Check if the DB is running and try again ."
            return $FALSE
        fi

        returnString=`cat /tmp/VersionOutput.txt | grep "DB2" | awk '{print($2)}'`
    fi
	
	rm -f /tmp/VersionOutput.txt
}

getIPAddress()
{
    unset returnString

    hostName=$1

    if [ -z "$hostName" ];then
        hostName=$HOSTNAME
    fi

    if [ "$PLATFORM" = "AIX" ];then
        IP=`host -n -t A $hostName`
        if [ $? = 0 ];then
            IP=`echo $IP | awk '{print($4)}'`
        else
            IP=127.0.0.1
        fi
    elif [ "$PLATFORM" = "Linux" ];then
        IP=`host $hostName`
        if [ $? = 0 ];then
            IP=`echo $IP | awk '{print($4)}'`
        else
            IP=127.0.0.1
        fi
    elif [ "$PLATFORM" = "SunOS" ];then
        IP=`getent hosts $hostName`
        if [ $? = 0 ];then
            IP=`echo $IP | awk '{print($1)}'`
        else
            IP=127.0.0.1
        fi
    fi

    returnString=$IP
}

isHostnameRemote()
{
    host=$1
    
    if [ -z "$host" ];then
        return $FALSE
    fi
	
	getIPAddress
    IP=$returnString
    
    if [ "$host" = "$HOSTNAME" -o "$host" = "$HOSTNAMEFULL" -o "$host" = "$IP" ];then
        return $FALSE
    else
        return $TRUE
    fi
}

getWASHome()
{
    ##GETTING THE IM INSTALLATION LOCATION
    if [ "$CURRENT_USER" = "root" ];then
        if [ -f /etc/.ibm/registry/InstallationManager.dat ];then
            IM_LOCATION=`cat /etc/.ibm/registry/InstallationManager.dat | grep "location=" | ${AWK_EQUAL} '{print($2)}'`
        fi
    else
        if [ -f ~/etc/.ibm/registry/InstallationManager.dat ];then
            IM_LOCATION=`cat ~/etc/.ibm/registry/InstallationManager.dat | grep "location=" | ${AWK_EQUAL} '{print($2)}'`
        fi
    fi

    ##GETTING THE APP_DATA_LOCATION
    if [ -d "$IM_LOCATION" ];then
        if [ -f $IM_LOCATION/eclipse/configuration/config.ini ];then
            APP_DATA_LOCATION=`cat $IM_LOCATION/eclipse/configuration/config.ini | grep "cic.appDataLocation" | ${AWK_EQUAL} '{print($2)}'`
        fi
    else
        if [ "$CURRENT_USER" = "root" ];then
            APP_DATA_LOCATION="/var/ibm/InstallationManager"
        else
            APP_DATA_LOCATION=`echo ~/var/ibm/InstallationManager`
        fi
    fi

    ##GETTING WAS LOCATION
    if [ -f $APP_DATA_LOCATION/installRegistry.xml ];then
        WAS_LOCATION=`cat $APP_DATA_LOCATION/installRegistry.xml | sed -n "/<profile id='IBM WebSphere Application Server - /,/<offering id='com.ibm.im.ts'>/p" | grep installLocation | ${TAIL}1 | ${AWK_QUOTE} '{print($4)}'`
    fi

    returnString=$WAS_LOCATION
}

# get CELLNAME and NODENAME from WAS installation. This might override defaults.
getActualWASConfig() 
{
	if [ -z "$WAS_HOME" ];then
        getWASHome
        if [ -d "$returnString" ];then
            WAS_HOME=$returnString
        else
            isVerbose=$TRUE
            getMessage TSIN02205E "WAS_HOME"
			log $msg
            #log "WAS_HOME environment variable is not set"
            return 1
        fi
	fi
	
	if [ -z "$WAS_PROFILE" ];then
		if [ -n "$1" ]; then
			WAS_PROFILE=$1
		else
            isVerbose=$TRUE
            getMessage TSIN02205E "WAS_PROFILE"
			log $msg
			#log "WAS_PROFILE environment variable is not set"
			return 1
		fi
	fi

	WAS_PROFILE_HOME=`${WAS_HOME}/bin/manageprofiles.sh -getPath -profileName ${WAS_PROFILE} 2>/dev/null`
    
    if [ ! -d "$WAS_PROFILE_HOME" ];then
        isVerbose=$TRUE
        getMessage TSIN02213E $WAS_PROFILE
        log $msg
        #log "Could not determine the profile home for the following profile: $WAS_PROFILE"
        return 1
    fi

    log "WAS_HOME = $WAS_HOME"
	log "WAS_PROFILE = $WAS_PROFILE"
	log "WAS_PORT_NO = $WAS_PORT_NO"
	log "CELLNAME = $CELLNAME"
	log "NODENAME = $NODENAME"
	log "SERVERNAME = $SERVERNAME"
	
	WAS_CFG=${WAS_PROFILE_HOME}/config/cells

	if [ ! -d "$WAS_CFG"  ];then
		if [ `ls ${WAS_HOME}/profiles | wc -w` = "1" ]; then
			WAS_PROFILE=`ls ${WAS_HOME}/profiles`
			WAS_CFG=${WAS_HOME}/profiles/${WAS_PROFILE}/config/cells
			log "WAS_PROFILE = $WAS_PROFILE"
		else
			getMessage RFID05035E "$WAS_PROFILE"
            $ECHO $msg
            log $msg
			return 1
		fi
	fi
	
	if [ ! -d $WAS_CFG/$CELLNAME ]; then
		if [ `ls ${WAS_CFG}| wc -w` = "1" ]; then
			CELLNAME=`ls ${WAS_CFG}`
			log "CELLNAME = $CELLNAME"
		else
			getMessage RFID05029E
            $ECHO $msg
            log $msg
			return 1
		fi
	fi
	
	if [ -z "$CLUSTERNAME" ]; then
		if [ ! -d $WAS_CFG/$CELLNAME/nodes/$NODENAME ];then
			if [ `ls ${WAS_CFG}/${CELLNAME}/nodes | wc -w` = "1" ]; then
				NODENAME=`ls ${WAS_CFG}/${CELLNAME}/nodes`
				getMessage RFID05031I "$NODENAME"
                log $msg
			else
				getMessage RFID05032E
                $ECHO $msg
                log $msg
				return 1
			fi
		fi
	
		if [ ! -d $WAS_CFG/$CELLNAME/nodes/$NODENAME/servers/$SERVERNAME ]; then
			if [ `ls ${WAS_CFG}/${CELLNAME}/nodes/${NODENAME}/servers | wc -w` = "1" ]; then
				SERVERNAME=`ls ${WAS_CFG}/${CELLNAME}/nodes/${NODENAME}/servers`
				getMessage RFID05033I "$SERVERNAME"
                log $msg
			else
				getMessage RFID05034E
                $ECHO $msg
                log $msg
				return 1
			fi
		fi
	else
		if [ ! -d ${WAS_CFG}/$CELLNAME/clusters/${CLUSTERNAME} ]; then
			getMessage RFID05034E
            $ECHO $msg
            log $msg
			return 1
		fi
	fi
}

# determine TS_HOME
if [ -f "$0" ];then
    scriptDir=`dirname $0`
fi

if [ -f $scriptDir"/../etc/RFIDICServer.xml" ];then
	TS_HOME="`( cd \"${scriptDir}"/.."\" && pwd )`"
fi

if [ -z "$TS_HOME" -o "$TS_HOME" = "" ];then
    getWASHome
    TS_HOME=$returnString/ts
fi

if [ -d "$TS_HOME" ];then
	log "TS_HOME = $TS_HOME"
else
    isVerbose=$TRUE
    getMessage TSIN02214E
    $ECHO $msg
    log $msg
    #log "Cannot find the directory of Traceability Server. TS_HOME is not set correctly."
    return 1
fi

# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
if [ -n "$TS_HOME" -a ! -d "$TS_HOME" ];then
 	file $TS_HOME
 	return 1
fi

if [ -z "$utilsLogFile" ];then  
    logNumber=0
    while [ -z "$utilsLogFile" ];do
        utilsLogFile=${TS_HOME}/logs/TSLog.$logNumber
        if [ -f "$utilsLogFile" ];then
            utilsLogFile=`find $utilsLogFile -size -1048576c`
        fi
        logNumber=`expr $logNumber + 1`
    done
fi

RFIDIC_INSTALL_HOME=$TS_HOME
RFIDIC_HOME=$TS_HOME

if [ -z "$TS_ADMIN_USER" ];then
    TS_ADMIN_USER=$CURRENT_USER
    export TS_ADMIN_USER
fi

if [ -z "$TS_ADMIN_GROUP" ];then
    TS_ADMIN_GROUP=$CURRENT_GROUP
    export TS_ADMIN_GROUP
fi

############ MQ settings ############
if [ -z "$MQ_HOST" ];then
	MQ_HOST=$HOSTNAMEFULL
fi

isHostnameRemote $MQ_HOST
mq_dist=$?

if [ -z "$MQ_HOME" ];then
	MQ_HOME=$MQ_HOME
    export MQ_HOME
fi

if [ -d "$MQ_HOME" ];then 
	log "MQ_HOME = $MQ_HOME" 
else 
	# Just to spit out the 'cannot open directory' message in the language of the OS, 
	# since messages cannot be translated without setting the environment.
	if [ -n "$MQ_HOME" -a "$mq_dist" = "$FALSE" ];then
 		file $MQ_HOME
	fi
fi
if [ -z "$MQ_LSR_PORT" ];then 
	MQ_LSR_PORT=1414
    export MQ_LSR_PORT
fi
if [ -z "$MQ_USER" ];then
	MQ_USER=mqm
    export MQ_USER
fi
if [ -z "$QUEUE_MANAGER" ];then 
	QUEUE_MANAGER=TS.QUEUE.MANAGER
    export QUEUE_MANAGER
fi
if [ -z "$MQ_CLUSTER" ];then 
	MQ_CLUSTER=$MQ_CLUSTER
fi
if [ -z "$MQ_TS_CHANNEL" ];then 
	MQ_TS_CHANNEL=TS.CHANNEL
fi
if [ -z "$QUEUE_NAME" ];then 
	QUEUE_NAME=EPCEVENT
fi
if [ -z "$ALERTS_ENGINE_INPUT_QUEUE_NAME" ];then 
	ALERTS_ENGINE_INPUT_QUEUE_NAME=AlertsEngineInputQueue
fi
if [ -z "$MDM_CHANGE_NOTIF_QUEUE_NAME" ];then 
	MDM_CHANGE_NOTIF_QUEUE_NAME=MDMChangeNotification
fi
if [ -z "$AS2DELIVERY_QUEUE_NAME" ];then 
	AS2DELIVERY_QUEUE_NAME=AS2Delivery
fi
if [ -z "$AS2REQUEST_QUEUE_NAME" ];then 
	AS2REQUEST_QUEUE_NAME=AS2Request
fi
if [ -z "$AS2RESPONSE_QUEUE_NAME" ];then 
	AS2RESPONSE_QUEUE_NAME=AS2Response
fi
if [ -z "$CAPTURE_NOTIF_QUEUE_NAME" ];then 
	CAPTURE_NOTIF_QUEUE_NAME=RFIDICCAPTURENOTIF
fi
if [ -z "$MQ_LOG_FILE_PAGES" ];then
	MQ_LOG_FILE_PAGES=65535
fi
if [ -z "$MQ_LOG_TYPE" ];then
	MQ_LOG_TYPE=CIRCULAR
fi
if [ -z "$MQ_LOG_PRIMARY_FILES" ];then
	MQ_LOG_PRIMARY_FILES=3
fi
if [ -z "$MQ_LOG_SECONDARY_FILES" ];then
	MQ_LOG_SECONDARY_FILES=2
fi
if [ -z "$R_QUEUE_MANAGER" ];then 
	R_QUEUE_MANAGER=TS.QUEUE.MANAGER
fi
if [ -z "$R_MQ_LSR_PORT" ];then 
	R_MQ_LSR_PORT=1414
fi
if [ -z "$R_MQ_HOST" ];then 
	R_MQ_HOST=$R_MQ_HOST
fi

##Define these to use a CCDT for WAS MQ CFs and Activation specs
MQ_CCDT_URL=$MQ_CCDT_URL
MQ_CCDT_QM=$MQ_CCDT_QM




############ Database settings ############
if [ -z "$DB_TYPE" ];then
	DB_TYPE=$DB_TYPE
fi
if [ -z "$DBMS_DB_NAME" ];then
	DBMS_DB_NAME=$DBMS_DB_NAME
	export DBMS_DB_NAME
fi
if [ -z "$DBMS_ADMIN_USER" ];then
	DBMS_ADMIN_USER=$DBMS_ADMIN_USER
	export DBMS_ADMIN_USER
fi
if [ -z "$DBMS_HOME" ];then
	DBMS_HOME=$DBMS_HOME
    export DBMS_HOME
fi
if [ -z "$DBMS_HOST" ];then
	DBMS_HOST=$HOSTNAMEFULL
	export DBMS_HOST
fi
if [ -z "$DBMS_PORT_NUMBER" ];then
	DBMS_PORT_NUMBER=$DBMS_PORT_NUMBER
	export DBMS_PORT_NUMBER
fi
if [ -z "$DBMS_JDBC_LIB_PATH" ];then
    DBMS_JDBC_LIB_PATH=$DBMS_JDBC_LIB_PATH
    export DBMS_JDBC_LIB_PATH
fi

case $DB_TYPE in
	ORACLE)
		DBMS_ALIAS=RFIDICOracleAlias
        ORACLE_OWNER=$ORACLE_OWNER
		ORACLE_GROUP=$ORACLE_GROUP
		ORACLE_JDBC_URL="jdbc:oracle:thin:@${DBMS_HOST}:${DBMS_PORT_NUMBER}:${DBMS_DB_NAME}"
        oraVersion="11g"

        export DBMS_ALIAS
        export ORACLE_OWNER
		export ORACLE_GROUP
        export ORACLE_JDBC_URL
        export oraVersion

		;;
	DB2)
		DBMS_ALIAS=RFIDICDb2Alias
		DB2_INSTANCE_OWNER=$DB2_INSTANCE_OWNER
		DB2_INSTANCE=$DB2_INSTANCE

        export DBMS_ALIAS
		export DB2_INSTANCE
		export DB2_INSTANCE_OWNER
		;;
	*)
		return 1
		;;
esac

isHostnameRemote $DBMS_HOST
db_dist=$?

if [ -n "$DBMS_HOME" ];then
    if [ ! -d "$DBMS_HOME" ];then
        # Just to spit out the 'cannot open directory' message in the language of the OS, 
        # since messages cannot be translated without setting the environment.
        if [ -n "$DBMS_HOME" -a "$db_dist" = "$FALSE" ];then
            file $DBMS_HOME
            return
        fi
    fi
fi





############ WAS settings ############
if [ -z "$WAS_HOME" ];then
	WAS_HOME=$WAS_HOME
	if [ -d "$WAS_HOME" ];then
		log "WAS = $WAS_HOME"
    else
        getWASHome
        if [ -d "$returnString" ];then
            WAS_HOME=$returnString
        else
            # Just to spit out the 'cannot open directory' message in the language of the OS, 
            # since messages cannot be translated without setting the environment.
            if [ -n "$returnString" ];then
                file $WAS_HOME
                return 1
            fi
        fi
    fi
fi

#Global variables to be used for WAS configuration and installation
#These must be replaced with the values derived from the user input / WAS installation



if [ -z "$was_runas_user" ];then
	was_runas_user=$TS_ADMIN_USER
fi
if [ -z "$was_runas_group" ];then
	was_runas_group=$TS_ADMIN_GROUP
fi
if [ -z "$was_admin_user" ];then
	was_admin_user=$was_admin_user
fi
if [ -z "$was_admin_group" ];then
	was_admin_group=$was_admin_group
fi
if [ -z "$WAS_PROFILE" ];then
	WAS_PROFILE=$WAS_PROFILE
fi
if [ -z "$RFIDIC_BUS_NAME" ];then
	RFIDIC_BUS_NAME=RFIDICBus
fi
if [ -z "$RFIDIC_FILE_STORE" ];then
	RFIDIC_FILE_STORE=$RFIDIC_FILE_STORE
fi
if [ -z "$SERVERNAME" ];then
	SERVERNAME=$SERVERNAME
fi
if [ -z "$CLUSTERNAME" ];then
	CLUSTERNAME=$CLUSTERNAME
fi
if [ -z "$WAS_PORT_NO" ];then
	WAS_PORT_NO=$WAS_PORT_NO
fi
if [ -z "$NODENAME" -a -z "$CLUSTERNAME" ];then
	NODENAME=$NODENAME
fi
if [ -z "$CELLNAME" ];then
	CELLNAME=$CELLNAME
fi

#Set to true to configure a WAS optimization to keep web service
#calls to/from the same JVM off of the network
if [ -z "$WAS_LOCAL_WS" ]; then
    WAS_LOCAL_WS=true
fi

#In a clustered environment, these should probably be set to the host/ip
#of the web/proxy server that is placed in front of the application servers
if [ -z "$WS_EP_IP" ]; then
	getIPAddress
    WS_EP_IP=$returnString
fi

if [ -z "$WS_EP_PORT" ]; then
    WS_EP_PORT=${WAS_PORT_NO}
fi

RFIDIC_JARS_PATH_PREFIX='${RFIDIC_LIB}/'
WSADMIN_JARS_PATH_PREFIX="${TS_HOME}/lib/"
RFIDIC_JARS=`cd $TS_HOME/lib;ls *.jar`
WSADMIN_JARS_PATH=''
RFIDIC_JARS_PATH=''

for jar in $RFIDIC_JARS
do
        RFIDIC_JARS_PATH=$RFIDIC_JARS_PATH$RFIDIC_JARS_PATH_PREFIX$jar';'
        WSADMIN_JARS_PATH=${WSADMIN_JARS_PATH}${WSADMIN_JARS_PATH_PREFIX}$jar:
done

#Application info.
if [ -z "$MDMAPP_NAME" ];then
	MDMAPP_NAME=com.ibm.ts.mdmEAR
fi
if [ -z "$MDMAPP_LOCATION" ];then
	MDMAPP_LOCATION=$WAS_HOME/installableApps/com.ibm.ts.mdm.ear
fi
if [ -z "$CPAPP_NAME" ];then
    CPAPP_NAME=com.ibm.ts.webEAR
fi
if [ -z "$CPAPP_LOCATION" ];then
    CPAPP_LOCATION=$WAS_HOME/installableApps/com.ibm.ts.web.ear
fi
if [ -z "$RFAPP_NAME" ];then
	RFAPP_NAME=com.ibm.rfidic.webEAR
fi
if [ -z "$RFAPP_LOCATION" ];then
	RFAPP_LOCATION=$WAS_HOME/installableApps/com.ibm.rfidic.web.ear
fi
if [ -z "$UIAPP_NAME" ];then
	UIAPP_NAME=com.ibm.ts.web.uiEAR
fi
if [ -z "$UIAPP_LOCATION" ];then
	UIAPP_LOCATION=$WAS_HOME/installableApps/com.ibm.ts.web.ui.ear
fi
if [ -z "$RFIDIC_ALERTS_APP_NAME" ];then
	RFIDIC_ALERTS_APP_NAME=com.ibm.rfidic.web.alertsEAR
fi
if [ -z "$RFIDIC_ALERTS_APP_LOCATION" ];then
	RFIDIC_ALERTS_APP_LOCATION=$WAS_HOME/installableApps/com.ibm.rfidic.web.alerts.ear
fi
if [ -z "$SIDAPP_LOCATION" ];then
	SIDAPP_LOCATION=$WAS_HOME/installableApps/com.ibm.rfidic.web.enterprise.serialid.ear
fi
if [ -z "$SIDAPP_NAME" ];then
	SIDAPP_NAME=com.ibm.rfidic.web.enterprise.serialidEAR
fi

SNM_CACHE_NAME="SerialNumberCache"
SNM_CACHE_JNDI="SerialNumberCache"
SNM_CACHE_SIZE="1000"
SNM_CACHE_PRIORITY="1"

# Java Settings
if [ -z "$JAVA_HOME" ];then
	if [ -d "$WAS_HOME" ]; then
		JAVA_HOME=$WAS_HOME/java
	fi
fi
export JAVA_HOME

# Java heap settings. The default is for the OSes we support.
# These settings are to ensure a consistent behaviour acress OSes.
# Maximum heap size of 2GB
RFIDIC_LARGE_JAVA_HEAP=-Xmx2048m
# Medium sized heap size
RFIDIC_MEDIUM_JAVA_HEAP=-Xmx512m


if [ "$mq_dist" = "$FALSE" ];then
	MQ_INSTALL_PATH=$MQ_HOME
	MQ_LIB_PATH=$MQ_HOME/java/lib
else
	MQ_INSTALL_PATH=$WAS_HOME/installedConnectors/wmq.jmsra.rar
	MQ_LIB_PATH=$WAS_HOME/installedConnectors/wmq.jmsra.rar
fi

export MQ_INSTALL_PATH
export MQ_LIB_PATH

# Set PATH and CLASSPATH only if already not set
prependToPath PATH $JAVA_HOME/bin
prependToPath PATH $TS_HOME/bin
prependToPath PATH $MQ_HOME/bin
prependToPath PATH $DBMS_HOME/bin
prependToPath PATH $WAS_HOME/bin
PATH=.:$PATH
export PATH

#CLASSPATH Setting
for i in $TS_HOME/lib/*.jar 
do
	appendToPath CLASSPATH $i
done
appendToPath CLASSPATH $MQ_LIB_PATH/com.ibm.mqjms.jar
appendToPath CLASSPATH $MQ_LIB_PATH/com.ibm.mq.jar
appendToPath CLASSPATH $WAS_HOME/lib/j2ee.jar
if [ "$DB_TYPE" = "ORACLE" ];then
	appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/ojdbc5.jar
elif [ "$DB_TYPE" = "DB2" ];then
	appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/db2jcc.jar
	appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/db2jcc_javax.jar
	appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/db2jcc_license_cu.jar
	appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/db2jcc_license_cisuz.jar
fi
export CLASSPATH

#The path currently points to the main WAS installation.
#If it needs to point to the target profile, add the path to the /profiles/default/bin folder here
#export PATH=$WAS_HOME/profiles/default/bin:$PATH

log "PATH = $PATH"
log "CLASSPATH = $CLASSPATH"

getActualWASConfig
returnCode=$?
if [ "$returnCode" != "0" ];then
    return $returnCode
fi

#User settings for internal webservices access
WS_UI_USER=$WS_UI_USER
WS_UI_SSL=$WS_UI_SSL


if [ "$RFIDIC_NOPROMPT" != "true" ] && [ "$RFIDIC_NOPROMPT" != "TRUE" ] && [ -z "$drop_tables" ];then
	drop_tables=false
	stop_db=false
	stop_was=false
else
	drop_tables=true
	stop_db=true
	stop_was=true
fi

appendClassPathWithWASJars()
{
	if [ -n  "$wascpathdone" ]; then
		log "CLASSPATH = $CLASSPATH"
	else
		#Classpath for WAS 7.0
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/runtimes/com.ibm.ws.webservices.thinclient_7.0.0.jar
		CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.security.crypto.jar
		CLASSPATH=$CLASSPATH:$WAS_HOME/lib/bootstrap.jar:$WAS_HOME/plugins/com.ibm.ws.runtime.jar
		CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.prereq.wsdl4j.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.equinox.common_.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.bootstrap.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.equinox.registry.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.core.runtime_.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ffdc.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.osgi_.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.admin.core.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/javax.j2ee.management.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.wlm.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.prereq.soap.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/runtimes/com.ibm.ws.admin.client_7.0.0.jar

		export CLASSPATH
		wascpathdone=yes
		export wascpathdone
	fi
}

# check if log directory exists and create it otherwise
checkLogs()
{
	if [ ! -d $TS_HOME/logs ]; then
		mkdir -p $TS_HOME/logs
	fi
}

sslWASSettings()
{
	echo "-Djava.protocol.handler.pkgs=com.ibm.net.ssl.internal.www2.protocol -Djavax.net.ssl.trustStore="$WAS_PROFILE_HOME/etc/trust.p12" -Djavax.net.ssl.trustStorePassword=WebAS -Djavax.net.ssl.keyStore="$WAS_PROFILE_HOME/etc/key.p12" -Djavax.net.ssl.keyStorePassword=WebAS -Djavax.net.ssl.keyStoreType=PKCS12 -Djavax.net.ssl.trustStoreType=PKCS12 -Djavax.net.ssl.protocol=SSL"
}

echo_msg()
{
	$ECHO $1 | tee -a $LOG
}

writeProperties()
{
	echo '' > ${RFIDIC_PROPS_FILE}
	chmod 600 ${RFIDIC_PROPS_FILE}
	
	if [ -n "$ORACLE_JDBC_URL" ];then
		JDBC_URL=$ORACLE_JDBC_URL
	else
		JDBC_URL="jdbc:oracle:thin:@${DBMS_HOST}:${DBMS_PORT_NUMBER}:${DBMS_DB_NAME}"
	fi
    
    WAS_ADMIN_USER=$was_admin_user

	partial_MQ_HOST=`cat $TS_HOME/etc/RFIDICServer.xml | grep "<QueueManagerName>" | head -1 | ${AWK_COLON} '{print($1)}' | ${AWK_GREATER} '{print($2)}'`
	partial_MQ_LSR_PORT=`cat $TS_HOME/etc/RFIDICServer.xml | grep "<QueueManagerName>" | head -1 | ${AWK_COLON} '{print($2)}' | ${AWK_LESSER} '{print($1)}'`

	props="WAS_ADMIN_USER RFAPP_NAME RFIDIC_HOME TS_HOME SIDAPP_LOCATION SNM_CACHE_PRIORITY RFIDIC_BUS_NAME AS2RESPONSE_QUEUE_NAME DBMS_DB_NAME CPAPP_NAME SNM_CACHE_JNDI DBMS_HOST DBMS_PORT_NUMBER RFAPP_LOCATION CONFIG_OPTION WS_EP_IP WS_EP_PORT CPAPP_LOCATION SNM_CACHE_SIZE DBMS_ALIAS MQ_USER_PASSWORD MQ_HOST MQ_LSR_PORT CELLNAME SNM_CACHE_NAME DB_TYPE UIAPP_LOCATION SIDAPP_NAME AS2DELIVERY_QUEUE_NAME JDBC_URL AS2REQUEST_QUEUE_NAME QUEUE_MANAGER DBMS_ADMIN_USER CLUSTERNAME ALERTS_ENGINE_INPUT_QUEUE_NAME WS_UI_SSL RFIDIC_FILE_STORE DBMS_ADMIN_PASSWORD CAPTURE_NOTIF_QUEUE_NAME MQ_USER QUEUE_NAME DBMS_JDBC_LIB_PATH WS_UI_PWD WS_UI_USER UIAPP_NAME NODENAME SERVERNAME MEMBERONLY MQ_CCDT_URL MQ_CCDT_QM WAS_LOCAL_WS RFIDIC_JARS_PATH MDMAPP_NAME MDMAPP_LOCATION TS_ADMIN_USER TS_ADMIN_GROUP DBMS_HOME DB2_INSTANCE DB2_INSTANCE_OWNER ORACLE_GROUP MQ_HOME MQ_LOG_TYPE MQ_LOG_PRIMARY_FILES MQ_LOG_SECONDARY_FILES MQ_LOG_FILE_PAGES MQ_LSR_PORT MQ_TS_CHANNEL MDM_CHANGE_NOTIF_QUEUE_NAME was_admin_group was_runas_user was_runas_group WAS_HOME WAS_PROFILE WAS_PORT_NO MQ_CLUSTER partial_MQ_HOST partial_MQ_LSR_PORT oraVersion"
    
	for prop in $props
	do
		val=`eval echo '$'$prop`
		echo $prop=$val >> ${RFIDIC_PROPS_FILE}
	done

	if [ -f $TS_HOME/MQScripts/cluster.properties ]; then
		cat $TS_HOME/MQScripts/cluster.properties >> ${RFIDIC_PROPS_FILE}
	fi
}
