#!/bin/sh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2008, 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
## 
## The following sample of source code ("Sample Code") is owned by 
## International Business Machines Corporation or one of its subsidiaries 
## ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
## modify, and distribute the Sample Code in any form without payment to IBM, 
## for the purpose of assisting you in the development of your applications.
##
## The Sample Code is provided to you on an "AS IS" basis, without warranty of 
## any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
## IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
## MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
## not allow for the exclusion or limitation of implied warranties, so the 
## above limitations or exclusions may not apply to you. IBM shall not be 
## liable for any damages you suffer as a result of using, copying, modifying 
## or distributing the Sample Code, even if IBM has been advised of the 
## possibility of such damages.
##
##   Title: redeploy_alerts.sh
##   Description: Optionally compiles and Updates alerts subscriptions
## Usage:  createAlertsTSAR.sh [-nocompile] 
#############################################################################


# Call run_command and capture return code 
callRunCommand() {

   run_command $*

   if [ $? -ne 0 ]
   then
     exit 1
   fi
}

# Include the Traceability Server environment settings
setEnvironment() {
    echo ""
    echo "Environment setup"
    echo "================="

    SCRIPT_DIR=`dirname $0`

    if [ -n "$TS_HOME" -a -d $TS_HOME"/bin" ]
    then
        . $TS_HOME/bin/tsEnv.sh
    else
        . $SCRIPT_DIR/../../../bin/tsEnv.sh
    fi
}

# Print usage
usage(){

    echo "Usage: $0 [-nocompile|-help]"
    exit 1
}

# Create the JAR 
compileSource(){
    echo ""
    echo "Compiling source"
    echo "================"

    if [ -d  $bin_dir ] 
    then
        echo "Bin directory exists."
        callRunCommand rm -fr $bin_dir/com
        echo "Bin directory contents deleted."
    else
        echo "Creating bin directory."
        callRunCommand mkdir $bin_dir
    fi

    echo "Compiling source into bin directory."
    callRunCommand find . -name "*.java" -exec javac -d $bin_dir {} \;
}

# Create the JAR 
createJar(){
    echo ""
    echo "Building JAR"
    echo "============"

    if [ -r $JAR_FILE ]
    then
        callRunCommand rm $JAR_FILE
    fi
    callRunCommand touch $JAR_FILE
    callRunCommand cd $bin_dir
    callRunCommand find . -name "*.class" -exec jar uvf $JAR_FILE {} \;
}

# Copy version info file into tsar_source/info
copyVersionInfo(){
    echo ""
    echo "Copying version info. "
    echo "======================"

    if [ -d  $info_dir ] 
    then
        echo "Info directory exists."
    else
        echo "Creating info directory."
        callRunCommand mkdir $info_dir
    fi


    if [ -r $INFO_FILE ]
    then
        callRunCommand rm $INFO_FILE
    fi
    callRunCommand cp $TS_HOME/VersionInfo/versionInfo.properties $INFO_FILE

    echo "VersionInfo.properties copied OK."
}

# Create the TSAR file 
createTSAR(){
    echo ""
    echo "Building TSAR file"
    echo "=================="

    echo "Calling deployment code to create TSAR"
    callRunCommand java -classpath $CLASSPATH -DTS_HOME=$TS_HOME com.ibm.ts.deployment.application.Deployment $tsar_source_dir $TSAR_FILE 

    echo ""
    echo "TSAR file was created successfully."
    echo "==================================="
}


#### Main starts here #########

MODE="compile"

if [ $# -gt 1 ]
then
    usage
    exit 1
else
    for item in $*
    do
        if [ "$item" = "-nocompile" ];then
            MODE="nocompile";
        elif [ "$item" = "-help" ];then
            usage
        else
            usage
        fi
    done
fi

setEnvironment

script_location=`dirname $0 2>/dev/null`

if [ -z "$script_location" ]
then
    script_location="."
fi

alerts_dir="`( cd \"${script_location}"/.."\" && pwd )`"
echo "alerts_dir=$alerts_dir"

tsar_source_dir="$alerts_dir/tsar_source"
echo "tsar_source_dir=$tsar_source_dir"

lib_dir="$tsar_source_dir/lib"
echo "lib_dir=$lib_dir"

src_dir="$tsar_source_dir/src"
echo "src_dir=$src_dir"

bin_dir="$tsar_source_dir/bin"
echo "bin_dir=$bin_dir"

info_dir="$tsar_source_dir/info"
echo "info_dir=$info_dir"

echo "TS_HOME=$TS_HOME"

if [ -d  $lib_dir ] 
then
    echo "Lib directory exists."
else
    echo "Creating lib directory."
    mkdir $lib_dir
fi


if [ -d $src_dir ]
then
    callRunCommand cd $src_dir

    INFO_FILE=$info_dir/versionInfo.properties
    JAR_FILE=$lib_dir/ts_developed_alerts.jar
    TSAR_FILE=$alerts_dir/alerts.tsar

    echo "INFO_FILE = $INFO_FILE"
    echo "JAR_FILE  = $JAR_FILE"
    echo "TSAR_FILE = $TSAR_FILE"

    CLASSPATH=$CLASSPATH:.
    CLASSPATH=$CLASSPATH:$JAVA_HOME/../plugins/com.ibm.ws.runtime.jar
    CLASSPATH=$CLASSPATH:$JAVA_HOME/../plugins/com.ibm.ws.emf.jar
    
    if [ $MODE = "compile" ]
    then
        compileSource
        createJar
    fi

    copyVersionInfo

    createTSAR    
        
else
	echo "Error: The source directory cannot be found."
fi
