#!/bin/sh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2008, 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
## 
## The following sample of source code ("Sample Code") is owned by 
## International Business Machines Corporation or one of its subsidiaries 
## ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
## modify, and distribute the Sample Code in any form without payment to IBM, 
## for the purpose of assisting you in the development of your applications.
##
## The Sample Code is provided to you on an "AS IS" basis, without warranty of 
## any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
## IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
## MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
## not allow for the exclusion or limitation of implied warranties, so the 
## above limitations or exclusions may not apply to you. IBM shall not be 
## liable for any damages you suffer as a result of using, copying, modifying 
## or distributing the Sample Code, even if IBM has been advised of the 
## possibility of such damages.
##
##   Title: redeploy_alerts.sh
##   Description: Optionally compiles and Updates alerts subscriptions
## Usage:  importAlertsTSAR.sh [-was_admin_user <was_admin_user> 
##                              -was_admin_password <was_admin_password>] 
##                             [-was_runas_user <was_runas_user>]
#############################################################################


# Include the Traceability Server environment settings
setEnvironment() {
    echo ""
    echo "Environment setup"
    echo "================="

    SCRIPT_DIR=`dirname $0`

    if [ -n "$TS_HOME" -a -d $TS_HOME"/bin" ];then
        . $TS_HOME/bin/tsEnv.sh
    else
        . $SCRIPT_DIR/../../../bin/tsEnv.sh
    fi
}

# Print usage
usage(){

    echo "Usage: $0 [[-help] | "
    echo "           [-was_admin_user <was_admin_user>"
    echo "            -was_admin_password <was_admin_password>]"
    echo "           [-was_runas_user <was_runas_user>]]"
    exit 1
}

#### Main starts here #########

MODE="compile"

if [ $# -gt 6 ]
then
    usage
    exit 1
else
    for item in $*
    do
        if [ "$item" = "-help" ];then
            usage
        fi
    done
fi

setEnvironment

script_location=`dirname $0 2>/dev/null`

if [ -z "$script_location" ];then
    script_location="."
fi

alerts_dir="`( cd \"${script_location}"/.."\" && pwd )`"
echo "alerts_dir=$alerts_dir"

echo ""
echo "Importing TSAR file to Traceability Server. "
echo "============================================"

run_command cd $alerts_dir
TSAR_FILE=$alerts_dir/alerts.tsar
echo "TSAR_FILE = $TSAR_FILE"

../../bin/importReplaceTSAR.sh -file $TSAR_FILE $*

