/**
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-O98
 * (c)  Copyright IBM Corp. 2006, 2011 All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with
 * IBM Corp.
 * 
 * The following sample of source code ("Sample Code") is owned by 
 * International Business Machines Corporation or one of its subsidiaries 
 * ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
 * modify, and distribute the Sample Code in any form without payment to IBM, 
 * for the purpose of assisting you in the development of your applications.
 *
 * The Sample Code is provided to you on an "AS IS" basis, without warranty of 
 * any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
 * IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
 * not allow for the exclusion or limitation of implied warranties, so the 
 * above limitations or exclusions may not apply to you. IBM shall not be 
 * liable for any damages you suffer as a result of using, copying, modifying 
 * or distributing the Sample Code, even if IBM has been advised of the 
 * possibility of such damages.
 */

package com.ibm.ts.alerts.templates;

import java.util.ArrayList;
import java.util.List;

import com.ibm.rfidic.alerts.INotification;
import com.ibm.rfidic.alerts.IParameter;
import com.ibm.rfidic.alerts.IParameterValue;
import com.ibm.rfidic.alerts.ISubscription;
import com.ibm.rfidic.alerts.Notification;
import com.ibm.rfidic.alerts.Parameter;
import com.ibm.rfidic.alerts.ParameterValue;
import com.ibm.rfidic.common.epcis.EventConstants;
import com.ibm.rfidic.event.IEvent;
import com.ibm.rfidic.value.IAttributeValue;
import com.ibm.rfidic.value.TypeFactory;
import com.ibm.rfidic.value.ValueFactory;
import com.ibm.ts.alerts.nativealerts.SuperNativeAlert;

/** 
 * This class is a template class for a Native Alert . A Solution Developer
 * can use it as a starting point for building a Native Alert which is to be deployed 
 * to the RFIDIC Alerts Component.
 */
//  <-- Solution Developer: Rename this class to reflect your alert name.
public class NativeAlertTemplate extends SuperNativeAlert
{
	
  /* Declare arrays for the input and output parameters. */
  private IParameter[] inputParameters;
  private IParameter[] outputParameters;

  public NativeAlertTemplate()
  {
    /* Call the super class constructor passing in the name and description of the 
     * alert. This text will appear in the Alerts Subscription wizard pages. */
    //  <-- Solution Developer: Edit the line below
    super("Sample native alert", "Always notifies about the bizstep of the captured event");  //$NON-NLS-1$ //$NON-NLS-2$
    
    /* Declare an input parameter array for our alert definition. These parameters will
     * be provided by the subscription and entered by the user into the third page 
     * of the Alerts Subscription wizard. Notes: These parameters are retrieved when 
     * the Alert is registered not just at run time so you must ensure this code is
     * correct before registering the Alert. */
    //  <-- Solution Developer: Edit the lines below to specify the number of input parameters
    this.inputParameters  = new IParameter[1];    
    
    this.inputParameters[0] = new Parameter(
        "inputParamName",                           // Name  //$NON-NLS-1$
        TypeFactory.getInstance().getIntegerType(), // Type
        true,                                       // Required or not
        null);                                      // Default value
    
    /* Declare an output parameter array for the Alert. These parameters will
     * be placed in the returned Notification and optionally used by the 
     * Delivery Method. Note: These parameters are retrieved when 
     * the Alert is registered not just at run time so you must ensure this code is
     * correct before registering the Alert. */
    //  <-- Solution Developer: Edit the line below to specify the number of output parameters
    this.outputParameters = new IParameter[1];
    
    this.outputParameters[0] = new Parameter(
        "outputParamName",                          // Name //$NON-NLS-1$
    		TypeFactory.getInstance().getIntegerType(), // Type
    		true,                                       // Required or not 
    		null);                                      // Default value
  }

  /**
   * This method contains the condition to be evaluated for this Alert. It
   * returns a list of INotification objects or null if the alert condition 
   * is false.
   */
  //  <-- Solution Developer: Edit the this method to implement the condition of 
  //                         your alert. If necessary, this method and the 
  //                         evaluateConditions method below can be altered to 
  //                         return more than one notification per call but 
  //                         typically that will not be necessary.
  
  protected List<INotification> evaluateCondition(IEvent event, ISubscription subscription)
  {
    final List<INotification> returnNotifications = new ArrayList<INotification>();
    
    /* The following code can be used to retrieve values from the incoming 
     * EPCIS event that caused the Alert to be triggered. */
    // <-- Solution developer: Edit and add to the lines below to read event data
    //     Standard EPCIS attributes can be accessed using the EventConstants static
    //     variables. Extended (non standard EPCIS) attributes should be referred to 
    //     by whatever name they were given in the event metadata definition.
    IAttributeValue attributeValue = getAttributeValue(event,EventConstants.bizStep);
    String          bizStep        = (String)attributeValue.getSQLValue();
    
    //  <-- Solution Developer: Add your alert condition processing here. 
    
    //  <-- Solution developer: Edit and add to the lines below to create output
    try
    {
      /* The following code creates an output value for the alert. */
      IAttributeValue outAttrValue = 
    	  ValueFactory.getValue(TypeFactory.getInstance().getIntegerType(), // Type
    			                "1");                             // Value //$NON-NLS-1$
      
      /* The following code can be used to create an output parameter and values
       * array and populate it with the output attribute value. */
      final IParameterValue[] paramValues = new ParameterValue[1];
      paramValues[0] = new ParameterValue(outputParameters[0], outAttrValue);
        
      /* Create and return the notification for this subscription. */  
      INotification notif = new Notification(subscription, paramValues);
      returnNotifications.add(notif);
      
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
    return returnNotifications;
  }

  /** This method just returns the input parameters. 
   * There is no need to alter this method for Native Alerts. */
  public IParameter[] getInputParameters()
  {
    return inputParameters;
  }

  /** This method just returns the output parameters. 
   * There is no need to alter this method for Native Alerts. */
  public IParameter[] getOutputParameters()
  {
    return outputParameters;
  }
}
